@@ -24,7 +24,7 @@
 # This file is part of libSBML.  Please visit http://sbml.org for more
 # information about SBML, and the latest version of libSBML.
 #
-# Copyright (C) 2013-2014 jointly by the following organizations:
+# Copyright (C) 2013-2017 jointly by the following organizations:
 #     1. California Institute of Technology, Pasadena, CA, USA
 #     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
 #     3. University of Heidelberg, Heidelberg, Germany
@@ -56,17 +56,16 @@ from libsbmlutils import find_classes
 
 color_table = [
     # Name,   red,   green,   blue
-    ['comp',  '205',   '200',   '230'],
-    ['fbc',  '190',   '230',  '215'],
-    ['layout',  '240',  '195',  '160'],
-    ['qual',  '160',   '185',  '235'],
-    ['multi',  '223',  '189',  '30'],
+    ['comp',    '205',  '200',  '230'],
+    ['fbc',     '190',  '230',  '215'],
+    ['layout',  '250',  '230',  '170'],
+    ['qual',    '160',  '185',  '235'],
+    ['multi',   '120',  '120',  '120'],
     ['groups',  '250',  '170',  '210'],
-    ['arrays',  '55',  '221',  '177'],
-    ['distrib',  '243',  '250',  '134'],
-    ['spatial',  '0',  '150',  '132'],
-    ['req',  '100',  '100',  '100'],
-    ['render',  '225',  '225',  '225']
+    ['arrays',  '0',    '150',  '132'],
+    ['distrib', '243',  '250',  '134'],
+    ['spatial', '223',  '170',  '20'],
+    ['render',  '55',   '221',  '177'],
 ]
 
 
@@ -75,7 +74,7 @@ header_template = '''/**
  *
  * @file    libsbml-package-stylesheet.css
  * @brief   Stylesheet used by libSBML for L3 package plug-in docs.
- * @author  libSBML Team <libsbml-team@caltech.edu>
+ * @author  libSBML Team <libsbml-team@googlegroups.com>
  *
  * This file is generated by generate-pkg-stylesheet.py in the libSBML
  * documentation source directory.  DO NOT EDIT THIS FILE DIRECTLY
@@ -100,6 +99,14 @@ pkg_style_template = '''.pkg-color-{0}
 '''
 
 
+group_page_ref_template = '''{
+    font-family: "Noto Sans", Verdana, Helvetica, Arial, Sans, sans-serif !important;
+    font-weight: normal;
+    font-size: 12px;
+}
+'''
+
+
 safari_bugfix_template = '''{
     display: inline-block;
     margin-left: 0px;
@@ -122,16 +129,16 @@ after_template = '''{{
     font-size: 80%;
     font-style: italic;
     font-weight: normal;
-    line-height: 130%;
+    line-height: 100%;
     text-align: center;
-    color: #333 !important;
+    color: #000 !important;
     background-color: rgba({1}, {2}, {3}, 0.35);
     border: 1px solid rgb({1}, {2}, {3});
     border-radius: 5px;
     -moz-border-radius: 5px;
     -webkit-border-radius: 5px;
     margin-left: 1em;
-    padding: 0px 3px;
+    padding: 1px 3px;
     min-width: 40px;
     width: 40px;
 }}
@@ -152,6 +159,12 @@ def main(args):
     for entry in color_table:
         print (pkg_style_template.format(entry[0], entry[1], entry[2], entry[3]))
 
+    # Next, write rules for general references to the summary pages for packages.
+    print ('/* Styles for references to the package summary pages. */\n')
+    for entry in color_table:
+        print ('p a.el[href="group__{}.html"]'.format(entry[0]))
+        print (group_page_ref_template)
+
     # Next, read the source dir to find out the L3 packages available, and
     # extract the names of the libSBML object classes in each package.
     known_pkgs = [entry[0] for entry in color_table]
@@ -176,19 +189,28 @@ def main(args):
         # benign bit of CSS that doesn't change anything.  See
         # http://stackoverflow.com/a/8988418/743730
         for c in classes:
+            # This next format works for Javadoc version 1.6:
+            print ('.FrameItemFont a[href$="{}.html"],'.format(c))
+            # This next format works for Javadoc versions after version 1.6:
             comma = (',' if c != last else '')
-            print ('.FrameItemFont a[href$="{}.html"]{}'.format(c, comma))
+            print ('.indexContainer a[href$="{}.html"]{}'.format(c, comma))
         print (safari_bugfix_template)
 
         # With that out of the way, we can write the real CSS.
         for c in classes:
+            # This next format works for Javadoc version 1.6:
+            print ('.FrameItemFont a[href$="{}.html"]:before,'.format(c))
+            # This next format works for Javadoc versions after version 1.6:
             comma = (',' if c != last else '')
-            print ('.FrameItemFont a[href$="{}.html"]:before{}'.format(c, comma))
+            print ('.indexContainer a[href$="{}.html"]:before{}'.format(c, comma))
         print (before_template.format(pkg, color[1], color[2], color[3]))
 
         for c in classes:
+            # This next format works for Javadoc version 1.6:
+            print ('.FrameItemFont a[href$="{}.html"]:after,'.format(c))
+            # This next format works for Javadoc versions after version 1.6:
             comma = (',' if c != last else '')
-            print ('.FrameItemFont a[href$="{}.html"]:after{}'.format(c, comma))
+            print ('.indexContainer a[href$="{}.html"]:after{}'.format(c, comma))
         print (after_template.format(pkg, color[1], color[2], color[3]))
 
     # A final bit of styling for Doxygen output.
