@@ -8,7 +8,7 @@
  * This sample program is distributed under a different license than the rest
  * of libSBML.  This program uses the open-source MIT license, as follows:
  *
- * Copyright (c) 2013-2016 by the California Institute of Technology
+ * Copyright (c) 2013-2017 by the California Institute of Technology
  * (California, USA), the European Bioinformatics Institute (EMBL-EBI, UK)
  * and the University of Heidelberg (Germany), with support from the National
  * Institutes of Health (USA) under grant R01GM070923.  All rights reserved.
@@ -125,7 +125,7 @@ main (int argc, char* argv[])
         }
         else if (line[0] == 'F' && line[1] == 'I' && line[2]=='L' 
           && line[3]=='E' && line[4]==':') {
-		  int len = strlen(line);
+		  size_t len = strlen(line);
 		  char *filename = (char*) malloc(len-5+1);
 		  strncpy(filename, line+5, len-5);
 		  SBMLDocument_free(doc);
