@@ -8,7 +8,7 @@
 ## This sample program is distributed under a different license than the rest
 ## of libSBML.  This program uses the open-source MIT license, as follows:
 ##
-## Copyright (c) 2013-2016 by the California Institute of Technology
+## Copyright (c) 2013-2017 by the California Institute of Technology
 ## (California, USA), the European Bioinformatics Institute (EMBL-EBI, UK)
 ## and the University of Heidelberg (Germany), with support from the National
 ## Institutes of Health (USA) under grant R01GM070923.  All rights reserved.
@@ -43,44 +43,44 @@ import os.path
 import libsbml
 
 def main (args):
-  """usage: promoteParameters.py input-filename output-filename
-  """
-  if len(args) != 3:
-    print(main.__doc__)
-    sys.exit(1)
+    """usage: promoteParameters.py input-filename output-filename
+    """
+    if len(args) != 3:
+        print(main.__doc__)
+        sys.exit(1)
 
-  infile  = args[1]
-  outfile = args[2]
+    infile  = args[1]
+    outfile = args[2]
 
-  if not os.path.exists(infile):
-    print("[Error] %s : No such file." % (infile))
-    sys.exit(1)
+    if not os.path.exists(infile):
+        print("[Error] %s : No such file." % (infile))
+        sys.exit(1)
 
-  reader  = libsbml.SBMLReader()
-  writer  = libsbml.SBMLWriter()
-  sbmldoc = reader.readSBML(infile)
+    reader  = libsbml.SBMLReader()
+    writer  = libsbml.SBMLWriter()
+    sbmldoc = reader.readSBML(infile)
 
-  if sbmldoc.getNumErrors() > 0:
-    if sbmldoc.getError(0).getErrorId() == libsbml.XMLFileUnreadable:
-      # Handle case of unreadable file here.
-      sbmldoc.printErrors()
-    elif sbmldoc.getError(0).getErrorId() == libsbml.XMLFileOperationError:
-      # Handle case of other file error here.
-      sbmldoc.printErrors()
-    else:
-      # Handle other error cases here.
-      sbmldoc.printErrors()
+    if sbmldoc.getNumErrors() > 0:
+        if sbmldoc.getError(0).getErrorId() == libsbml.XMLFileUnreadable:
+            # Handle case of unreadable file here.
+            sbmldoc.printErrors()
+        elif sbmldoc.getError(0).getErrorId() == libsbml.XMLFileOperationError:
+            # Handle case of other file error here.
+            sbmldoc.printErrors()
+        else:
+            # Handle other error cases here.
+            sbmldoc.printErrors()
 
-    sys.exit(1)
-    
-  props = libsbml.ConversionProperties()
-  props.addOption("promoteLocalParameters", True, "Promotes all Local Parameters to Global ones")
-  if (sbmldoc.convert(props) != libsbml.LIBSBML_OPERATION_SUCCESS):
-	print("[Error] Conversion failed...")
-	sys.exit(1)
-  
-  writer.writeSBML(sbmldoc, outfile)
-  print("[OK] wrote %s" % (package, infile, outfile))
+        sys.exit(1)
+
+    props = libsbml.ConversionProperties()
+    props.addOption("promoteLocalParameters", True, "Promotes all Local Parameters to Global ones")
+    if (sbmldoc.convert(props) != libsbml.LIBSBML_OPERATION_SUCCESS):
+        print("[Error] Conversion failed...")
+        sys.exit(1)
+
+    writer.writeSBML(sbmldoc, outfile)
+    print("[OK] wrote {}".format(outfile))
 
 if __name__ == '__main__':
-  main(sys.argv)  
+    main(sys.argv)  
