@@ -1,6 +1,7 @@
 function Totalfail = testVersionInformation(FbcEnabled)
 
 Totalfail = 0;
+test = 9;
 
 filename = fullfile(pwd,'test-data', 'errors.xml');
 
@@ -17,6 +18,7 @@ Totalfail = Totalfail + fail_unless(~isempty(v.XML_parser_version));
 Totalfail = Totalfail + fail_unless(~isempty(v.isFBCEnabled));
 
 if (FbcEnabled == 1)
+    test = 10;
     Totalfail = Totalfail + fail_unless(strcmp(v.isFBCEnabled, 'enabled'));
 else
     Totalfail = Totalfail + fail_unless(strcmp(v.isFBCEnabled, 'disabled'));
@@ -24,6 +26,11 @@ end;
 
 v
 
+disp('TestingVersionInformation:');
+disp(sprintf('Number tests: %d', test));
+disp(sprintf('Number fails: %d', Totalfail));
+disp(sprintf('Pass rate: %d%%\n', ((test-Totalfail)/test)*100));
+
 function y = fail_unless(arg)
 
 if (~arg)
