@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -156,20 +156,11 @@ InitialAssignment::getSymbol () const
 }
 
 
-/** @cond doxygenLibsbmlInternal */
-/**
- * @return the string of symbol attribute of this object.
- * 
- * @note this function is an alias for getSymbol()
- * 
- * @see getSymbol()
- */
 const std::string& 
 InitialAssignment::getId() const
 {
   return getSymbol();
 }
-/** @endcond */
 
 
 /*
@@ -205,7 +196,7 @@ InitialAssignment::isSetMath () const
 
 
 /*
- * Sets the symbol of this InitialAssignment to a copy of sid.
+ * Sets the symbol of this InitialAssignment to a copy of @p sid.
  */
 int
 InitialAssignment::setSymbol (const std::string& sid)
@@ -449,14 +440,315 @@ InitialAssignment::hasRequiredElements() const
   bool allPresent = true;
 
   /* required attributes for initialAssignment: math */
+  /* l3v2 removed that requirement */
 
-  if (!isSetMath())
-    allPresent = false;
+  if ((getLevel() < 3 ) || (getLevel() == 3 && getVersion() == 1))
+  {
+    if (!isSetMath())
+      allPresent = false;
+  }
 
   return allPresent;
 }
 
 
+
+
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this InitialAssignment.
+ */
+int
+InitialAssignment::getAttribute(const std::string& attributeName,
+                                bool& value) const
+{
+  int return_value = SBase::getAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this InitialAssignment.
+ */
+int
+InitialAssignment::getAttribute(const std::string& attributeName,
+                                int& value) const
+{
+  int return_value = SBase::getAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this InitialAssignment.
+ */
+int
+InitialAssignment::getAttribute(const std::string& attributeName,
+                                double& value) const
+{
+  int return_value = SBase::getAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this InitialAssignment.
+ */
+int
+InitialAssignment::getAttribute(const std::string& attributeName,
+                                unsigned int& value) const
+{
+  int return_value = SBase::getAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this InitialAssignment.
+ */
+int
+InitialAssignment::getAttribute(const std::string& attributeName,
+                                std::string& value) const
+{
+  int return_value = SBase::getAttribute(attributeName, value);
+
+  if (return_value == LIBSBML_OPERATION_SUCCESS)
+  {
+    return return_value;
+  }
+
+  if (attributeName == "symbol")
+  {
+    value = getSymbol();
+    return_value = LIBSBML_OPERATION_SUCCESS;
+  }
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this InitialAssignment.
+ */
+int
+InitialAssignment::getAttribute(const std::string& attributeName,
+                                const char* value) const
+{
+  int return_value = SBase::getAttribute(attributeName, value);
+
+  if (return_value == LIBSBML_OPERATION_SUCCESS)
+  {
+    return return_value;
+  }
+
+  if (attributeName == "symbol")
+  {
+    value = getSymbol().c_str();
+    return_value = LIBSBML_OPERATION_SUCCESS;
+  }
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Predicate returning @c true if this InitialAssignment's attribute
+ * "attributeName" is set.
+ */
+bool
+InitialAssignment::isSetAttribute(const std::string& attributeName) const
+{
+  bool value = SBase::isSetAttribute(attributeName);
+
+  if (attributeName == "symbol")
+  {
+    value = isSetSymbol();
+  }
+
+  return value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this InitialAssignment.
+ */
+int
+InitialAssignment::setAttribute(const std::string& attributeName, bool value)
+{
+  int return_value = SBase::setAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this InitialAssignment.
+ */
+int
+InitialAssignment::setAttribute(const std::string& attributeName, int value)
+{
+  int return_value = SBase::setAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this InitialAssignment.
+ */
+int
+InitialAssignment::setAttribute(const std::string& attributeName,
+                                double value)
+{
+  int return_value = SBase::setAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this InitialAssignment.
+ */
+int
+InitialAssignment::setAttribute(const std::string& attributeName,
+                                unsigned int value)
+{
+  int return_value = SBase::setAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this InitialAssignment.
+ */
+int
+InitialAssignment::setAttribute(const std::string& attributeName,
+                                const std::string& value)
+{
+  int return_value = SBase::setAttribute(attributeName, value);
+
+  if (attributeName == "symbol")
+  {
+    return_value = setSymbol(value);
+  }
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this InitialAssignment.
+ */
+int
+InitialAssignment::setAttribute(const std::string& attributeName,
+                                const char* value)
+{
+  int return_value = SBase::setAttribute(attributeName, value);
+
+  if (attributeName == "symbol")
+  {
+    return_value = setSymbol(value);
+  }
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Unsets the value of the "attributeName" attribute of this InitialAssignment.
+ */
+int
+InitialAssignment::unsetAttribute(const std::string& attributeName)
+{
+  int value = SBase::unsetAttribute(attributeName);
+
+  if (attributeName == "symbol")
+  {
+    value = unsetSymbol();
+  }
+
+  return value;
+}
+
+/** @endcond */
+
+
+
+
 void
 InitialAssignment::renameSIdRefs(const std::string& oldid, const std::string& newid)
 {
@@ -523,7 +815,7 @@ InitialAssignment::multiplyAssignmentsToSIdByFunction(const std::string& id, con
 /** @cond doxygenLibsbmlInternal */
 /*
  * Subclasses should override this method to write out their contained
- * SBML objects as XML elements.  Be sure to call your parents
+ * SBML objects as XML elements.  Be sure to call your parent's
  * implementation of this method as well.
  */
 void
@@ -630,7 +922,7 @@ InitialAssignment::addExpectedAttributes(ExpectedAttributes& attributes)
 /*
  * Subclasses should override this method to read values from the given
  * XMLAttributes set into their specific fields.  Be sure to call your
- * parents implementation of this method as well.
+ * parent's implementation of this method as well.
  */
 void
 InitialAssignment::readAttributes (const XMLAttributes& attributes,
@@ -671,7 +963,7 @@ InitialAssignment::readAttributes (const XMLAttributes& attributes,
 /*
  * Subclasses should override this method to read values from the given
  * XMLAttributes set into their specific fields.  Be sure to call your
- * parents implementation of this method as well.
+ * parent's implementation of this method as well.
  */
 void
 InitialAssignment::readL2Attributes (const XMLAttributes& attributes)
@@ -705,7 +997,7 @@ InitialAssignment::readL2Attributes (const XMLAttributes& attributes)
 /*
  * Subclasses should override this method to read values from the given
  * XMLAttributes set into their specific fields.  Be sure to call your
- * parents implementation of this method as well.
+ * parent's implementation of this method as well.
  */
 void
 InitialAssignment::readL3Attributes (const XMLAttributes& attributes)
@@ -737,7 +1029,7 @@ InitialAssignment::readL3Attributes (const XMLAttributes& attributes)
 /** @cond doxygenLibsbmlInternal */
 /*
  * Subclasses should override this method to write their XML attributes
- * to the XMLOutputStream.  Be sure to call your parents implementation
+ * to the XMLOutputStream.  Be sure to call your parent's implementation
  * of this method as well.
  */
 void
