@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -69,8 +69,8 @@
  * <li> In SBML Level&nbsp;2, the value assigned to the parameter's "units"
  * attribute must be chosen from one of the following possibilities: one of
  * the base unit identifiers defined in SBML; one of the built-in unit
- * identifiers @c "substance", @c "time", @c "volume", @c "area" or @c
- * "length"; or the identifier of a new unit defined in the list of unit
+ * identifiers @c "substance", @c "time", @c "volume", @c "area" or
+ * @c "length"; or the identifier of a new unit defined in the list of unit
  * definitions in the enclosing Model structure.  There are no constraints
  * on the units that can be chosen from these sets.  There are no default
  * units for local parameters.
@@ -78,6 +78,16 @@
  *
  * As with all other major SBML components, LocalParameter is derived from
  * SBase, and the methods defined on SBase are available on LocalParameter.
+ *
+ * In SBML Level&nbsp;3 Version&nbsp;2, the scope of the LocalParameter 
+ * was expanded slightly to officially encompass the entire Reaction
+ * instead of just the KineticLaw in which it appears.  This has no
+ * effect on models using only SBML Level&nbsp;3 Core constructs,
+ * but has the potential to allow SBML Level&nbsp;3 Packages to
+ * include elements in a Reaction that could reference a
+ * LocalParameter from that Reaction's KineticLaw.  It also means that
+ * no LocalParameter may have the same @c "id" as a referenced Species
+ * in any SimpleSpeciesReference in that Reaction. 
  * 
  * @warning <span class="warning">LibSBML derives LocalParameter from
  * Parameter; however, this does not precisely match the object hierarchy
@@ -126,8 +136,8 @@
  * identifier.  It does this by constructing an appropriate
  * UnitDefinition.  For SBML Level&nbsp;2 models, it will do this even
  * when the value of the "units" attribute is one of the predefined SBML
- * units @c "substance", @c "volume", @c "area", @c "length" or @c
- * "time".  Callers may find this useful in conjunction with the helper
+ * units @c "substance", @c "volume", @c "area", @c "length" or
+ * @c "time".  Callers may find this useful in conjunction with the helper
  * methods provided by the UnitDefinition class for comparing different
  * UnitDefinition objects.
  *
@@ -225,7 +235,7 @@ public:
   /**
    * Assignment operator for LocalParameter.
    *
-   * @param rhs The object whose values are used as the basis of the
+   * @param rhs the object whose values are used as the basis of the
    * assignment.
    */
   LocalParameter& operator=(const LocalParameter& rhs);
@@ -346,6 +356,286 @@ public:
 
   /** @endcond */
 
+
+
+  #ifndef SWIG
+
+
+
+  /** @cond doxygenLibsbmlInternal */
+
+  /**
+   * Gets the value of the "attributeName" attribute of this LocalParameter.
+   *
+   * @param attributeName, the name of the attribute to retrieve.
+   *
+   * @param value, the address of the value to record.
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+   */
+  virtual int getAttribute(const std::string& attributeName, bool& value)
+    const;
+
+  /** @endcond */
+
+
+
+  /** @cond doxygenLibsbmlInternal */
+
+  /**
+   * Gets the value of the "attributeName" attribute of this LocalParameter.
+   *
+   * @param attributeName, the name of the attribute to retrieve.
+   *
+   * @param value, the address of the value to record.
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+   */
+  virtual int getAttribute(const std::string& attributeName, int& value) const;
+
+  /** @endcond */
+
+
+
+  /** @cond doxygenLibsbmlInternal */
+
+  /**
+   * Gets the value of the "attributeName" attribute of this LocalParameter.
+   *
+   * @param attributeName, the name of the attribute to retrieve.
+   *
+   * @param value, the address of the value to record.
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+   */
+  virtual int getAttribute(const std::string& attributeName,
+                           double& value) const;
+
+  /** @endcond */
+
+
+
+  /** @cond doxygenLibsbmlInternal */
+
+  /**
+   * Gets the value of the "attributeName" attribute of this LocalParameter.
+   *
+   * @param attributeName, the name of the attribute to retrieve.
+   *
+   * @param value, the address of the value to record.
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+   */
+  virtual int getAttribute(const std::string& attributeName,
+                           unsigned int& value) const;
+
+  /** @endcond */
+
+
+
+  /** @cond doxygenLibsbmlInternal */
+
+  /**
+   * Gets the value of the "attributeName" attribute of this LocalParameter.
+   *
+   * @param attributeName, the name of the attribute to retrieve.
+   *
+   * @param value, the address of the value to record.
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+   */
+  virtual int getAttribute(const std::string& attributeName,
+                           std::string& value) const;
+
+  /** @endcond */
+
+
+
+  /** @cond doxygenLibsbmlInternal */
+
+  /**
+   * Gets the value of the "attributeName" attribute of this LocalParameter.
+   *
+   * @param attributeName, the name of the attribute to retrieve.
+   *
+   * @param value, the address of the value to record.
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+   */
+  virtual int getAttribute(const std::string& attributeName,
+                           const char* value) const;
+
+  /** @endcond */
+
+
+
+  /** @cond doxygenLibsbmlInternal */
+
+  /**
+   * Predicate returning @c true if this LocalParameter's attribute
+   * "attributeName" is set.
+   *
+   * @param attributeName, the name of the attribute to query.
+   *
+   * @return @c true if this LocalParameter's attribute "attributeName" has
+   * been set, otherwise @c false is returned.
+   */
+  virtual bool isSetAttribute(const std::string& attributeName) const;
+
+  /** @endcond */
+
+
+
+  /** @cond doxygenLibsbmlInternal */
+
+  /**
+   * Sets the value of the "attributeName" attribute of this LocalParameter.
+   *
+   * @param attributeName, the name of the attribute to set.
+   *
+   * @param value, the value of the attribute to set.
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+   */
+  virtual int setAttribute(const std::string& attributeName, bool value);
+
+  /** @endcond */
+
+
+
+  /** @cond doxygenLibsbmlInternal */
+
+  /**
+   * Sets the value of the "attributeName" attribute of this LocalParameter.
+   *
+   * @param attributeName, the name of the attribute to set.
+   *
+   * @param value, the value of the attribute to set.
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+   */
+  virtual int setAttribute(const std::string& attributeName, int value);
+
+  /** @endcond */
+
+
+
+  /** @cond doxygenLibsbmlInternal */
+
+  /**
+   * Sets the value of the "attributeName" attribute of this LocalParameter.
+   *
+   * @param attributeName, the name of the attribute to set.
+   *
+   * @param value, the value of the attribute to set.
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+   */
+  virtual int setAttribute(const std::string& attributeName, double value);
+
+  /** @endcond */
+
+
+
+  /** @cond doxygenLibsbmlInternal */
+
+  /**
+   * Sets the value of the "attributeName" attribute of this LocalParameter.
+   *
+   * @param attributeName, the name of the attribute to set.
+   *
+   * @param value, the value of the attribute to set.
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+   */
+  virtual int setAttribute(const std::string& attributeName,
+                           unsigned int value);
+
+  /** @endcond */
+
+
+
+  /** @cond doxygenLibsbmlInternal */
+
+  /**
+   * Sets the value of the "attributeName" attribute of this LocalParameter.
+   *
+   * @param attributeName, the name of the attribute to set.
+   *
+   * @param value, the value of the attribute to set.
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+   */
+  virtual int setAttribute(const std::string& attributeName,
+                           const std::string& value);
+
+  /** @endcond */
+
+
+
+  /** @cond doxygenLibsbmlInternal */
+
+  /**
+   * Sets the value of the "attributeName" attribute of this LocalParameter.
+   *
+   * @param attributeName, the name of the attribute to set.
+   *
+   * @param value, the value of the attribute to set.
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+   */
+  virtual int setAttribute(const std::string& attributeName, const char*
+    value);
+
+  /** @endcond */
+
+
+
+  /** @cond doxygenLibsbmlInternal */
+
+  /**
+   * Unsets the value of the "attributeName" attribute of this LocalParameter.
+   *
+   * @param attributeName, the name of the attribute to query.
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+   */
+  virtual int unsetAttribute(const std::string& attributeName);
+
+  /** @endcond */
+
+
+
+
+  #endif /* !SWIG */
+
+
 protected:
   /** @cond doxygenLibsbmlInternal */
   /**
@@ -360,7 +650,7 @@ protected:
   /**
    * Subclasses should override this method to read values from the given
    * XMLAttributes set into their specific fields.  Be sure to call your
-   * parents implementation of this method as well.
+   * parent's implementation of this method as well.
    */
   virtual void readAttributes (const XMLAttributes& attributes,
                                const ExpectedAttributes& expectedAttributes);
@@ -370,7 +660,7 @@ protected:
 
   /**
    * Subclasses should override this method to write their XML attributes
-   * to the XMLOutputStream.  Be sure to call your parents implementation
+   * to the XMLOutputStream.  Be sure to call your parent's implementation
    * of this method as well.
    */
   virtual void writeAttributes (XMLOutputStream& stream) const;
@@ -407,9 +697,9 @@ public:
    * The object is constructed such that it is valid for the given SBML
    * Level and Version combination.
    *
-   * @param level the SBML Level
+   * @param level the SBML Level.
    * 
-   * @param version the Version within the SBML Level
+   * @param version the Version within the SBML Level.
    *
    * @copydetails doc_throw_exception_lv
    *
@@ -540,7 +830,7 @@ public:
    * returned from this function (and is the reason we override the base
    * ListOf::getElementBySId function here).
    *
-   * @param id string representing the id of objects to find
+   * @param id string representing the id of the object to find.
    *
    * @return pointer to the first element found with the given @p id.
    */
@@ -551,7 +841,7 @@ public:
    * Removes the nth item from this ListOfLocalParameters, and returns a
    * pointer to it.
    *
-   * @param n the index of the item to remove.  
+   * @param n the index of the item to remove.
    *
    * @return the item removed.  The caller owns the returned object and is
    * responsible for deleting it.  If the index number @p n is out of
@@ -595,6 +885,8 @@ public:
   /** @endcond */
 
 
+
+
 protected:
   /** @cond doxygenLibsbmlInternal */
   /**
@@ -624,20 +916,14 @@ BEGIN_C_DECLS
  * and @p version values.
  *
  * @param level an unsigned int, the SBML Level to assign to this
- * LocalParameter_t
+ * LocalParameter_t.
  *
  * @param version an unsigned int, the SBML Version to assign to this
- * LocalParameter_t
+ * LocalParameter_t.
  *
  * @return a pointer to the newly created LocalParameter_t structure.
  *
- * @note Once a LocalParameter_t has been added to an SBMLDocument_t, the @p
- * level and @p version for the document @em override those used to create
- * the LocalParameter_t.  Despite this, the ability to supply the values at
- * creation time is an important aid to creating valid SBML.  Knowledge of
- * the intended SBML Level and Version  determine whether it is valid to
- * assign a particular value to an attribute, or whether it is valid to add
- * a structure to an existing SBMLDocument_t.
+ * @copydetails doc_note_setting_lv
  *
  * @memberof LocalParameter_t
  */
@@ -651,17 +937,11 @@ LocalParameter_create (unsigned int level, unsigned int version);
  * SBMLNamespaces_t structure.
  *
  * @param sbmlns SBMLNamespaces_t, a pointer to an SBMLNamespaces_t structure
- * to assign to this LocalParameter_t
+ * to assign to this LocalParameter_t.
  *
  * @return a pointer to the newly created LocalParameter_t structure.
  *
- * @note Once a LocalParameter_t has been added to an SBMLDocument_t, the
- * @p sbmlns namespaces for the document @em override those used to create
- * the LocalParameter_t.  Despite this, the ability to supply the values at creation time
- * is an important aid to creating valid SBML.  Knowledge of the intended SBML
- * Level and Version determine whether it is valid to assign a particular value
- * to an attribute, or whether it is valid to add a structure to an existing
- * SBMLDocument_t.
+ * @copydetails doc_note_setting_lv
  *
  * @memberof LocalParameter_t
  */
@@ -685,7 +965,7 @@ LocalParameter_free (LocalParameter_t *p);
 /**
  * Creates a deep copy of the given LocalParameter_t structure
  * 
- * @param p the LocalParameter_t structure to be copied
+ * @param p the LocalParameter_t structure to be copied.
  * 
  * @return a (deep) copy of the given LocalParameter_t structure.
  *
@@ -699,7 +979,7 @@ LocalParameter_clone (const LocalParameter_t *p);
 /**
  * Does nothing:  this function initializes structures according to their defaults in SBML Level 2, but Local Parameters did not exist in SBML Level 2.
  * 
- * @param p the LocalParameter_t structure to be ignored
+ * @param p the LocalParameter_t structure to be ignored.
  * 
  * @memberof LocalParameter_t
  */
@@ -712,7 +992,7 @@ LocalParameter_initDefaults (LocalParameter_t *p);
  * Returns a list of XMLNamespaces_t associated with this LocalParameter_t
  * structure.
  *
- * @param p the LocalParameter_t structure
+ * @param p the LocalParameter_t structure.
  * 
  * @return pointer to the XMLNamespaces_t structure associated with 
  * this structure
@@ -727,7 +1007,7 @@ LocalParameter_getNamespaces(LocalParameter_t *p);
 /**
  * Takes a LocalParameter_t structure and returns its identifier.
  *
- * @param p the LocalParameter_t structure whose identifier is sought
+ * @param p the LocalParameter_t structure whose identifier is sought.
  * 
  * @return the identifier of this LocalParameter_t, as a pointer to a string.
  *
@@ -786,7 +1066,7 @@ LocalParameter_getUnits (const LocalParameter_t *p);
  *
  * @param p the LocalParameter_t to ignore.
  *
- * @return @c non-zero (true).
+ * @return @c 1 (true), or @c 0 (false) if @p p is @c NULL.
  *
  * @memberof LocalParameter_t
  */
@@ -796,13 +1076,13 @@ LocalParameter_getConstant (const LocalParameter_t *p);
 
 
 /**
- * Predicate returning @c true or @c false depending on whether the given
+ * Predicate returning @c 1 (true) or @c 0 (false) depending on whether the given
  * LocalParameter_t structure's identifier is set.
  *
- * @param p the LocalParameter_t structure to query
+ * @param p the LocalParameter_t structure to query.
  * 
- * @return @c non-zero (true) if the "id" attribute of the given
- * LocalParameter_t structure is set, zero (false) otherwise.
+ * @return @c 1 (true) if the "id" attribute of the given
+ * LocalParameter_t structure is set, @c 0 (false) otherwise.
  *
  * @memberof LocalParameter_t
  */
@@ -812,13 +1092,13 @@ LocalParameter_isSetId (const LocalParameter_t *p);
 
 
 /**
- * Predicate returning @c true or @c false depending on whether the given
+ * Predicate returning @c 1 (true) or @c 0 (false) depending on whether the given
  * LocalParameter_t structure's name is set.
  *
- * @param p the LocalParameter_t structure to query
+ * @param p the LocalParameter_t structure to query.
  * 
- * @return @c non-zero (true) if the "name" attribute of the given
- * LocalParameter_t structure is set, zero (false) otherwise.
+ * @return @c 1 (true) if the "name" attribute of the given
+ * LocalParameter_t structure is set, @c 0 (false) otherwise.
  *
  * @memberof LocalParameter_t
  */
@@ -828,17 +1108,13 @@ LocalParameter_isSetName (const LocalParameter_t *p);
 
 
 /**
- * Predicate returning @c true or @c false depending on whether the given
+ * Predicate returning @c 1 (true) or @c 0 (false) depending on whether the given
  * LocalParameter_t structure's value is set.
  * 
- * @param p the LocalParameter_t structure to query
+ * @param p the LocalParameter_t structure to query.
  * 
- * @return @c non-zero (true) if the "value" attribute of the given
- * LocalParameter_t structure is set, zero (false) otherwise.
- *
- * @note In SBML Level 1 Version 1, a LocalParameter_t value is required and
- * therefore <em>should always be set</em>.  In Level 1 Version 2 and
- * later, the value is optional, and as such, may or may not be set.
+ * @return @c 1 (true) if the "value" attribute of the given
+ * LocalParameter_t structure is set, @c 0 (false) otherwise.
  *
  * @memberof LocalParameter_t
  */
@@ -848,13 +1124,13 @@ LocalParameter_isSetValue (const LocalParameter_t *p);
 
 
 /**
- * Predicate returning @c true or @c false depending on whether the given
+ * Predicate returning @c 1 (true) or @c 0 (false) depending on whether the given
  * LocalParameter_t structure's units have been set.
  *
- * @param p the LocalParameter_t structure to query
+ * @param p the LocalParameter_t structure to query.
  * 
- * @return @c non-zero (true) if the "units" attribute of the given
- * LocalParameter_t structure is set, zero (false) otherwise.
+ * @return @c 1 (true) if the "units" attribute of the given
+ * LocalParameter_t structure is set, @c 0 (false) otherwise.
  *
  * @memberof LocalParameter_t
  */
@@ -866,7 +1142,7 @@ LocalParameter_isSetUnits (const LocalParameter_t *p);
 /**
  * Assigns the identifier of a LocalParameter_t structure.
  *
- * This makes a copy of the string passed in the param @p sid.
+ * This makes a copy of the string passed in the parameter @p sid.
  *
  * @param p the LocalParameter_t structure to set.
  * @param sid the string to use as the identifier.
@@ -875,7 +1151,7 @@ LocalParameter_isSetUnits (const LocalParameter_t *p);
  * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
  * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
  *
- * @note Using this function with an id of NULL is equivalent to
+ * @note Using this function with an @p sid of NULL is equivalent to
  * unsetting the "id" attribute.
  *
  * @memberof LocalParameter_t
@@ -915,6 +1191,7 @@ LocalParameter_setName (LocalParameter_t *p, const char *name);
  *
  * @copydetails doc_returns_success_code
  * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
  *
  * @memberof LocalParameter_t
  */
@@ -946,16 +1223,16 @@ LocalParameter_setUnits (LocalParameter_t *p, const char *units);
 
 /**
  * Because LocalParameter_t structures don't have a 'constant' attribute, this function always
- * returns @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}.
+ * returns @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}, or 
+ * @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t} if
+ * @p p is @c NULL.
  *
  * @param p the LocalParameter_t structure to leave unchanged.
- * @param value The boolean value to ignore.
+ * @param value the integer value to ignore.
  *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible value
- * returned by this function is:
+ * @copydetails doc_returns_success_code
  * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
  *
  * @memberof LocalParameter_t
  */
@@ -983,15 +1260,11 @@ LocalParameter_unsetName (LocalParameter_t *p);
 /**
  * Unsets the value of this LocalParameter_t structure.
  *
- * In SBML Level 1 Version 1, a parameter is required to have a value and
- * therefore this attribute <em>should always be set</em>.  In Level 1
- * Version 2 and beyond, a value is optional, and as such, may or may not be
- * set.
- *
  * @param p the LocalParameter_t structure whose value is to be unset.
  *
  * @copydetails doc_returns_success_code
  * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
  *
  * @memberof LocalParameter_t
  */
@@ -1018,15 +1291,15 @@ LocalParameter_unsetUnits (LocalParameter_t *p);
 
 /**
  * Because LocalParameter_t structures don't have a 'constant' attribute, this function always
- * returns @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}.
+ * returns @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}, 
+ * or @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t} if
+ * @p p is @c NULL.
  *
  * @param p the LocalParameter_t structure to leave unchanged.
  *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible value
- * returned by this function is:
+ * @copydetails doc_returns_success_code
  * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
  *
  * @memberof LocalParameter_t
  */
@@ -1036,7 +1309,7 @@ LocalParameter_unsetConstant (LocalParameter_t *p);
 
 
 /**
- * Predicate returning @c true or @c false depending on whether
+ * Predicate returning @c 1 (true) or @c 0 (false) depending on whether
  * all the required attributes for this LocalParameter object
  * have been set.
  *
@@ -1045,8 +1318,8 @@ LocalParameter_unsetConstant (LocalParameter_t *p);
  * The required attributes for a LocalParameter object are:
  * @li id (name in L1)
  *
- * @return @c 1 if all the required attributes for this object have been
- * defined, @c 0 otherwise.
+ * @return @c 1 (true) if all the required attributes for this object have been
+ * defined, @c 0 (false) otherwise.
  *
  * @memberof LocalParameter_t
  */
@@ -1099,7 +1372,7 @@ ListOfLocalParameters_getById (ListOf_t *lo, const char *sid);
  * The caller owns the returned item and is responsible for deleting it.
  *
  * @param lo the list of LocalParameter_t structures to search.
- * @param sid the "id" attribute value of the structure to remove
+ * @param sid the "id" attribute value of the structure to remove.
  *
  * @return The LocalParameter_t structure removed, or a null pointer if no such
  * item exists in @p lo.
