@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -365,6 +365,50 @@ SBMLDocument::getModel ()
   return mModel;
 }
 
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Returns the number of "elementName" in this Reaction.
+ */
+unsigned int
+SBMLDocument::getNumObjects(const std::string& elementName)
+{
+  unsigned int n = 0;
+
+  if (elementName == "model")
+  {
+    if (isSetModel())
+    {
+      return 1;
+    }
+  }
+
+  return n;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Returns the nth object of "objectName" in this Reaction.
+ */
+SBase*
+SBMLDocument::getObject(const std::string& elementName, unsigned int index)
+{
+  SBase* obj = NULL;
+
+  if (elementName == "model")
+  {
+    return getModel();
+  }
+
+  return obj;
+}
+
+/** @endcond */
 
 SBase* 
 SBMLDocument::getElementBySId(const std::string& id)
@@ -502,6 +546,23 @@ SBMLDocument::setLevelAndVersion (unsigned int level, unsigned int version,
     return false;
 }
 
+/** @cond doxygenLibsbmlInternal */
+
+/* 
+* function to set level to 0 on a doc that was just been created to read in to
+* the SBMLReader will only do this if the file is found to be invalid
+* this will allow for testing for an SBMLDocument without
+* relying on it having a model to be valid 
+* (in L3V2 a missing model will be valid) 
+*/
+void 
+SBMLDocument::setInvalidLevel()
+{
+  mLevel = 0;
+  mVersion = 0;
+}
+
+/** @endcond */
 
 /** @cond doxygenLibsbmlInternal */
 void 
@@ -559,9 +620,12 @@ SBMLDocument::updateSBMLNamespace(const std::string&, unsigned int level,
       switch (mVersion)
       {
       case 1:
-      default:
         uri = SBML_XMLNS_L3V1;
         break;
+      case 2:
+      default:
+        uri = SBML_XMLNS_L3V2;
+        break;
       }
       break;
   }
@@ -625,7 +689,7 @@ SBMLDocument::setModel (const Model* m)
       mModel->connectToParent(this);
     }
 
-    if (getURI() != mModel->getURI()) 
+    if (mModel != NULL && getURI() != mModel->getURI()) 
     {
       mModel->setElementNamespace(getURI());
     }
@@ -1119,7 +1183,21 @@ SBMLDocument::checkL2v4Compatibility ()
 
 /*
  * Performs a set of semantic consistency checks on the document to establish
- * whether it is compatible with L2v1 and can be converted.  Query
+ * whether it is compatible with L2v4 and can be converted.  Query
+ * the results by calling getNumErrors() and getError().
+ *
+ * @return the number of failed checks (errors) encountered.
+ */
+unsigned int
+SBMLDocument::checkL2v5Compatibility ()
+{
+  return mInternalValidator->checkL2v5Compatibility();
+}
+
+
+/*
+ * Performs a set of semantic consistency checks on the document to establish
+ * whether it is compatible with L3v1 and can be converted.  Query
  * the results by calling getNumErrors() and getError().
  *
  * @return the number of failed checks (errors) encountered.
@@ -1131,6 +1209,20 @@ SBMLDocument::checkL3v1Compatibility ()
 }
 
 
+/*
+* Performs a set of semantic consistency checks on the document to establish
+* whether it is compatible with L3v2 and can be converted.  Query
+* the results by calling getNumErrors() and getError().
+*
+* @return the number of failed checks (errors) encountered.
+*/
+unsigned int
+SBMLDocument::checkL3v2Compatibility()
+{
+  return mInternalValidator->checkL3v2Compatibility();
+}
+
+
 /*
  * @return the nth error encountered during the parse of this
  * SBMLDocument or @c NULL if n > getNumErrors() - 1.
@@ -1451,9 +1543,7 @@ SBMLDocument::addUnknownPackageRequired(const std::string& pkgURI,
 {
   std::string value = (flag) ? "true" : "false";
 
-  mRequiredAttrOfUnknownPkg.add("required", value, pkgURI, prefix);
-
-  return LIBSBML_OPERATION_SUCCESS;
+  return mRequiredAttrOfUnknownPkg.add("required", value, pkgURI, prefix);
 }
 /** @endcond */
 
@@ -1572,7 +1662,7 @@ SBMLDocument::isDisabledIgnoredPackage(const std::string& pkgURI)
 bool
 SBMLDocument::hasUnknownPackage(const std::string& pkgURI)
 {
-  // has this package been added to teh list of unknown required attributes
+  // has this package been added to the list of unknown required attributes
   std::string req = mRequiredAttrOfUnknownPkg.getValue("required", pkgURI);
   if (!req.empty()) return true;
 
@@ -1657,7 +1747,7 @@ SBMLDocument::addExpectedAttributes(ExpectedAttributes& attributes)
 /*
  * Subclasses should override this method to read values from the given
  * XMLAttributes set into their specific fields.  Be sure to call your
- * parents implementation of this method as well.
+ * parent's implementation of this method as well.
  */
 void
 SBMLDocument::readAttributes (const XMLAttributes& attributes,
@@ -1794,7 +1884,7 @@ SBMLDocument::readAttributes (const XMLAttributes& attributes,
   }
   else if (mLevel == 3)
   {
-    if (mVersion > 1)
+    if (mVersion > 2)
     {
       logError(InvalidSBMLLevelVersion);
     }
@@ -1914,6 +2004,20 @@ SBMLDocument::readAttributes (const XMLAttributes& attributes,
         }
         break;
       }
+      else if (!strcmp(ns->getURI(n).c_str(), 
+                "http://www.sbml.org/sbml/level3/version2/core"))
+      {
+        match = 1;
+        if (mLevel != 3 || !levelRead)
+        {
+          logError(MissingOrInconsistentLevel);
+        }
+        if (mVersion != 2 || !versionRead)
+        {
+          logError(MissingOrInconsistentVersion);
+        }
+        break;
+      }
     }
     if (match == 0)
     {
@@ -1962,7 +2066,7 @@ SBMLDocument::readAttributes (const XMLAttributes& attributes,
 /** @cond doxygenLibsbmlInternal */
 /*
  * Subclasses should override this method to write their XML attributes
- * to the XMLOutputStream.  Be sure to call your parents implementation
+ * to the XMLOutputStream.  Be sure to call your parent's implementation
  * of this method as well.
  */
 void
@@ -2033,7 +2137,7 @@ SBMLDocument::writeAttributes (XMLOutputStream& stream) const
 /*
  *
  * Subclasses should override this method to write their xmlns attriubutes
- * (if any) to the XMLOutputStream.  Be sure to call your parents implementation
+ * (if any) to the XMLOutputStream.  Be sure to call your parent's implementation
  * of this method as well.
  *
  */
@@ -2097,7 +2201,7 @@ SBMLDocument::writeXMLNS (XMLOutputStream& stream) const
 /** @cond doxygenLibsbmlInternal */
 /*
  * Subclasses should override this method to write out their contained
- * SBML objects as XML elements.  Be sure to call your parents
+ * SBML objects as XML elements.  Be sure to call your parent's
  * implementation of this method as well.
  */
 void
@@ -2444,6 +2548,14 @@ SBMLDocument_checkL2v4Compatibility (SBMLDocument_t *d)
 }
 
 
+LIBSBML_EXTERN
+unsigned int 
+SBMLDocument_checkL2v5Compatibility (SBMLDocument_t *d)
+{
+  return (d != NULL) ? d->checkL2v5Compatibility() : SBML_INT_MAX;
+}
+
+
 LIBSBML_EXTERN
 unsigned int 
 SBMLDocument_checkL3v1Compatibility (SBMLDocument_t *d)
@@ -2452,6 +2564,14 @@ SBMLDocument_checkL3v1Compatibility (SBMLDocument_t *d)
 }
 
 
+LIBSBML_EXTERN
+unsigned int
+SBMLDocument_checkL3v2Compatibility(SBMLDocument_t *d)
+{
+  return (d != NULL) ? d->checkL3v2Compatibility() : SBML_INT_MAX;
+}
+
+
 LIBSBML_EXTERN
 const SBMLError_t *
 SBMLDocument_getError (SBMLDocument_t *d, unsigned int n)
