@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -89,6 +89,9 @@ SBMLNamespaces::initSBMLNamespace()
     case 1:
       mNamespaces->add(SBML_XMLNS_L3V1);
       break;
+    case 2:
+      mNamespaces->add(SBML_XMLNS_L3V2);
+      break;
     }
     break;
   }
@@ -194,6 +197,7 @@ SBMLNamespaces::getSupportedNamespaces()
   result->add(new SBMLNamespaces(2,4));
   result->add(new SBMLNamespaces(2,5));
   result->add(new SBMLNamespaces(3,1));
+  result->add(new SBMLNamespaces(3,2));
   return result;
 }
 
@@ -256,9 +260,12 @@ SBMLNamespaces::getSBMLNamespaceURI(unsigned int level,
     switch(version)
     {
     case 1:
-    default:
       uri = SBML_XMLNS_L3V1;
       break;
+    case 2:
+    default:
+      uri = SBML_XMLNS_L3V2;
+      break;
     }
     break;
   case 2:
@@ -390,7 +397,7 @@ SBMLNamespaces::addPackageNamespace(const std::string &pkgName, unsigned int pkg
     const std::string prefix = (pkgPrefix.empty()) ? pkgName : pkgPrefix;
     if (!uri.empty() && mNamespaces != NULL)
     {
-      mNamespaces->add(uri,prefix);
+      return mNamespaces->add(uri,prefix);
     }
     else
     {
@@ -402,7 +409,7 @@ SBMLNamespaces::addPackageNamespace(const std::string &pkgName, unsigned int pkg
     return LIBSBML_INVALID_ATTRIBUTE_VALUE;
   }
 
-  return LIBSBML_OPERATION_SUCCESS;
+//  return LIBSBML_OPERATION_SUCCESS;
 }
 
 
@@ -547,6 +554,7 @@ SBMLNamespaces::isSBMLNamespace(const std::string& uri)
   if (uri == SBML_XMLNS_L2V4) return true;
   if (uri == SBML_XMLNS_L2V5) return true;
   if (uri == SBML_XMLNS_L3V1) return true;
+  if (uri == SBML_XMLNS_L3V2) return true;
 
   return false;
 }
@@ -569,6 +577,12 @@ SBMLNamespaces::isValidCombination()
     //
     int numNS = 0;
 
+    if (xmlns->hasURI(SBML_XMLNS_L3V2))
+    {
+      ++numNS;
+      declaredURI.assign(SBML_XMLNS_L3V2);
+    }
+
     if (xmlns->hasURI(SBML_XMLNS_L3V1))
     {
       ++numNS;
@@ -733,6 +747,17 @@ SBMLNamespaces::isValidCombination()
             }
           }
           break;
+        case 2:
+         // the namespaces contains the sbml namespaces
+          // check it is the correct ns for the level/version
+          if (sbmlDeclared)
+          {
+            if (declaredURI != string(SBML_XMLNS_L3V2))
+            {
+              valid = false;
+            }
+          }
+          break;
         default:
           valid = false;
           break;
@@ -849,10 +874,11 @@ SBMLNamespaces_getSupportedNamespaces(int *length)
    const List* supported = SBMLNamespaces::getSupportedNamespaces();
   
    *length = (int) supported->getSize();
-  SBMLNamespaces_t ** result = (SBMLNamespaces_t**)malloc(sizeof(SBMLNamespaces_t*)*((unsigned long)*length));
-  memset(result, 0, sizeof(SBMLNamespaces_t*)*((unsigned long)*length));
+  SBMLNamespaces_t ** result = (SBMLNamespaces_t**)safe_malloc(sizeof(SBMLNamespaces_t*)*((unsigned long)(*length)));
+  //memset(result, 0, sizeof(SBMLNamespaces_t*)*((unsigned long)*length));
   for (int i = 0; i < *length; i++)
   {
+    result[i] = (SBMLNamespaces_t*)safe_malloc(sizeof(SBMLNamespaces_t*));
     result[i] = ((SBMLNamespaces*)supported->get((unsigned int)i))->clone();
   }
   SBMLNamespaces::freeSBMLNamespaces(const_cast<List*>(supported));
