@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -190,6 +190,7 @@ isCriticalError(const unsigned int errorId)
   case UnclosedXMLToken:
   case XMLTagMismatch:
   case BadXMLPrefix:
+  case BadXMLPrefixValue:
   case MissingXMLAttributeValue:
   case BadXMLComment:
   case XMLUnexpectedEOF:
@@ -207,9 +208,39 @@ isCriticalError(const unsigned int errorId)
   }
 }
 /** @endcond */
+/** @cond doxygenLibsbmlInternal */
+void sortReportedErrors(SBMLDocument* d)
+{
+  // If we encountered an error, some parsers will report it sooner
+  // than others.  Unfortunately, those that fail sooner do it in an
+  // opaque call, so we can't change the behavior.  Since we don't want
+  // different parsers to report different validation errors, we bring
+  // all parsers back to the same point.
 
+  d->setModel(NULL);
+
+  for (unsigned int i = 0; i < d->getNumErrors(); ++i)      
+  {
+    if (isCriticalError(d->getError(i)->getErrorId()))
+    {
+      // If we find even one critical error, all other errors are
+      // suspect and may be bogus.  Remove them.
+
+      for (int n = (int)d->getNumErrors()-1; n >= 0; --n)
+        if (!isCriticalError(d->getError((unsigned int)n)->getErrorId()))
+        {
+          d->getErrorLog()->remove(d->getError((unsigned int)n)->getErrorId());
+        }
+
+      break;
+    }
+  }
+}
+
+/** @endcond */
 
 /** @cond doxygenLibsbmlInternal */
+
 /*
  * Used by readSBML() and readSBMLFromString().
  */
@@ -229,11 +260,32 @@ SBMLReader::readInternal (const char* content, bool isFile)
   {
     XMLInputStream stream(content, isFile, "", d->getErrorLog());
 
-    if (stream.peek().isStart() && stream.peek().getName() != "sbml")
+    if (stream.peek().isStart())
     {
-      // the root element ought to be an sbml element. 
-      d->getErrorLog()->logError(NotSchemaConformant);
-	  return d;
+      // so we have got an xml based document
+      //check that it is an sbml element
+      if (stream.peek().getName() != "sbml")
+      {
+        // the root element ought to be an sbml element. 
+        d->getErrorLog()->logError(NotSchemaConformant);
+
+        d->setInvalidLevel();
+
+	      return d;
+      }
+    }
+    else
+    {
+      // here we do not have an xml document at all
+//      d->getErrorLog()->logError(NotSchemaConformant);
+
+      if (stream.isError())
+      {
+        sortReportedErrors(d);    
+      }
+      d->setInvalidLevel();
+      
+      return d;
     }
 	
     d->read(stream);
@@ -246,24 +298,7 @@ SBMLReader::readInternal (const char* content, bool isFile)
       // different parsers to report different validation errors, we bring
       // all parsers back to the same point.
 
-      d->setModel(NULL);
-
-      for (unsigned int i = 0; i < d->getNumErrors(); ++i)      
-      {
-        if (isCriticalError(d->getError(i)->getErrorId()))
-        {
-          // If we find even one critical error, all other errors are
-          // suspect and may be bogus.  Remove them.
-
-          for (int n = (int)d->getNumErrors()-1; n >= 0; --n)
-            if (!isCriticalError(d->getError((unsigned int)n)->getErrorId()))
-            {
-              d->getErrorLog()->remove(d->getError((unsigned int)n)->getErrorId());
-            }
-
-          break;
-        }
-      }
+      sortReportedErrors(d);    
     }
     else
     {
@@ -291,8 +326,12 @@ SBMLReader::readInternal (const char* content, bool isFile)
 
       if (d->getModel() == NULL)
       {
-        d->getErrorLog()->logError(MissingModel, 
-                                   d->getLevel(), d->getVersion());
+        // L3V2 removed the restriction that a model was necessary
+        if (d->getLevel() < 3 ||(d->getLevel() == 3 && d->getVersion() == 1))
+        {
+          d->getErrorLog()->logError(MissingModel, 
+                                     d->getLevel(), d->getVersion());
+        }
       }
       else if (d->getLevel() == 1)
       {
