@@ -431,7 +431,7 @@ SBMLTransforms::getComponentValuesForModel(const Model * m, IdValueMap& values)
           !( sr->isSetStoichiometryMath() && sr->getStoichiometryMath()->isSetMath() ) )
       {
         /* not set by assignment */
-        if (!(sr->isSetStoichiometry()))
+        if (sr->isSetStoichiometry() == false && m->getLevel() > 2 )
         {
           ids.append(sr->getId());
           ValueSet v = make_pair(numeric_limits<double>::quiet_NaN(), false);
@@ -527,6 +527,10 @@ SBMLTransforms::clearComponentValues()
 double
 SBMLTransforms::evaluateASTNode(const ASTNode *node, const Model *m)
 {
+  if (mValues.size() == 0)
+  {
+    mapComponentValues(m);
+  }
   return evaluateASTNode(node, mValues, m);
 }
 
@@ -1082,18 +1086,18 @@ SBMLTransforms::evaluateASTNode(const ASTNode * node, const IdValueMap& values,
 
   case AST_FUNCTION_MIN:
     result = evaluateASTNode(node->getChild(0), values);
-    for (unsigned int i = 1; i < node->getNumChildren(); i++)
+    for (unsigned int j = 1; j < node->getNumChildren(); j++)
     {
-      double nextValue = evaluateASTNode(node->getChild(i), values);
+      double nextValue = evaluateASTNode(node->getChild(j), values);
       if (nextValue < result) result = nextValue;
     }
     break;
 
   case AST_FUNCTION_MAX:
     result = evaluateASTNode(node->getChild(0), values);
-    for (unsigned int i = 1; i < node->getNumChildren(); i++)
+    for (unsigned int j = 1; j < node->getNumChildren(); j++)
     {
-      double nextValue = evaluateASTNode(node->getChild(i), values);
+      double nextValue = evaluateASTNode(node->getChild(j), values);
       if (nextValue > result) result = nextValue;
     }
     break;
