@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -294,6 +294,27 @@ StoichiometryMath::replaceSIDWithFunction(const std::string& id, const ASTNode*
 }
 /** @endcond */
 
+/** @cond doxygenLibsbmlInternal */
+/*
+* Function to set/get an identifier for unit checking
+*/
+std::string 
+StoichiometryMath::getInternalId() const
+{ 
+  return mInternalId; 
+}
+
+
+void 
+StoichiometryMath::setInternalId(std::string id)
+{ 
+  mInternalId = id; 
+}
+
+/** @endcond */
+
+
+
 /** @cond doxygenLibsbmlInternal */
 /*
  * Subclasses should override this method to read (and store) XHTML,
@@ -313,7 +334,7 @@ StoichiometryMath::readOtherXML (XMLInputStream& stream)
     if (getLevel() == 1) 
     {
       logError(NotSchemaConformant, getLevel(), getVersion(),
-	       "SBML Level 1 does not support MathML.");
+         "SBML Level 1 does not support MathML.");
       delete mMath;
       return false;
     }
@@ -369,7 +390,7 @@ StoichiometryMath::addExpectedAttributes(ExpectedAttributes& attributes)
 /*
  * Subclasses should override this method to read values from the given
  * XMLAttributes set into their specific fields.  Be sure to call your
- * parents implementation of this method as well.
+ * parent's implementation of this method as well.
  */
 void
 StoichiometryMath::readAttributes (const XMLAttributes& attributes,
@@ -384,7 +405,7 @@ StoichiometryMath::readAttributes (const XMLAttributes& attributes,
   {
   case 1:
     logError(NotSchemaConformant, level, version,
-	      "StoichiometryMath is not a valid component for this level/version.");
+        "StoichiometryMath is not a valid component for this level/version.");
     break;
   case 2:
     readL2Attributes(attributes);
@@ -392,7 +413,7 @@ StoichiometryMath::readAttributes (const XMLAttributes& attributes,
   case 3:
   default:
     logError(NotSchemaConformant, level, version,
-	      "StoichiometryMath is not a valid component for this level/version.");
+        "StoichiometryMath is not a valid component for this level/version.");
     break;
   }
 }
@@ -403,7 +424,7 @@ StoichiometryMath::readAttributes (const XMLAttributes& attributes,
 /*
  * Subclasses should override this method to read values from the given
  * XMLAttributes set into their specific fields.  Be sure to call your
- * parents implementation of this method as well.
+ * parent's implementation of this method as well.
  */
 void
 StoichiometryMath::readL2Attributes (const XMLAttributes& attributes)
@@ -412,7 +433,7 @@ StoichiometryMath::readL2Attributes (const XMLAttributes& attributes)
   const unsigned int version = getVersion();
   if (version == 2) 
     mSBOTerm = SBO::readTerm(attributes, this->getErrorLog(), level, version,
-				getLine(), getColumn());
+        getLine(), getColumn());
 }
 /** @endcond */
 
@@ -420,7 +441,7 @@ StoichiometryMath::readL2Attributes (const XMLAttributes& attributes)
 /** @cond doxygenLibsbmlInternal */
 /*
  * Subclasses should override this method to write their XML attributes
- * to the XMLOutputStream.  Be sure to call your parents implementation
+ * to the XMLOutputStream.  Be sure to call your parent's implementation
  * of this method as well.
  */
 void
@@ -586,7 +607,7 @@ StoichiometryMath::containsUndeclaredUnits() const
 /** @cond doxygenLibsbmlInternal */
 /*
  * Subclasses should override this method to write out their contained
- * SBML objects as XML elements.  Be sure to call your parents
+ * SBML objects as XML elements.  Be sure to call your parent's
  * implementation of this method as well.
  */
 void
