@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -158,8 +158,8 @@ START_TEST (test_L3ModelHistory_parseModelHistory)
 
   const XMLNode_t * creator = XMLNode_getChild(desc, 0);
   fail_unless(!strcmp(XMLNode_getName(creator), "creator"));
-  fail_unless(!strcmp(XMLNode_getPrefix(creator), "dc"));
-  fail_unless(!strcmp(XMLNode_getURI(creator), "http://purl.org/dc/elements/1.1/"));
+  fail_unless(!strcmp(XMLNode_getPrefix(creator), "dcterms"));
+  fail_unless(!strcmp(XMLNode_getURI(creator), "http://purl.org/dc/terms/"));
   fail_unless(XMLNode_getNumChildren(creator) == 1);
 
   const XMLNode_t * Bag = XMLNode_getChild(creator, 0);
@@ -496,8 +496,8 @@ START_TEST (test_L3ModelHistory_parseModelHistory_Model)
 
   const XMLNode_t * creator = XMLNode_getChild(desc, 0);
   fail_unless(!strcmp(XMLNode_getName(creator), "creator"));
-  fail_unless(!strcmp(XMLNode_getPrefix(creator), "dc"));
-  fail_unless(!strcmp(XMLNode_getURI(creator), "http://purl.org/dc/elements/1.1/"));
+  fail_unless(!strcmp(XMLNode_getPrefix(creator), "dcterms"));
+  fail_unless(!strcmp(XMLNode_getURI(creator), "http://purl.org/dc/terms/"));
   fail_unless(XMLNode_getNumChildren(creator) == 1);
 
   const XMLNode_t * Bag = XMLNode_getChild(creator, 0);
