@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -1782,15 +1782,15 @@ START_TEST (test_RDFAnnotation_testCreateAnnotations)
   fail_unless(ann1->getNumChildren() == 0);
   fail_unless(ann1->getNamespaces().getLength() == 6);
   fail_unless(ann1->getNamespaceURI(0) == "http://www.w3.org/1999/02/22-rdf-syntax-ns#");
-  fail_unless(ann1->getNamespaceURI(1) == "http://purl.org/dc/elements/1.1/");
-  fail_unless(ann1->getNamespaceURI(2) == "http://purl.org/dc/terms/");
-  fail_unless(ann1->getNamespaceURI(3) == "http://www.w3.org/2001/vcard-rdf/3.0#");
+  fail_unless(ann1->getNamespaceURI(1) == "http://purl.org/dc/terms/");
+  fail_unless(ann1->getNamespaceURI(2) == "http://www.w3.org/2001/vcard-rdf/3.0#");
+  fail_unless(ann1->getNamespaceURI(3) == "http://www.w3.org/2006/vcard/ns#");
   fail_unless(ann1->getNamespaceURI(4) == "http://biomodels.net/biology-qualifiers/");
   fail_unless(ann1->getNamespaceURI(5) == "http://biomodels.net/model-qualifiers/");
   fail_unless(ann1->getNamespacePrefix(0) == "rdf");
-  fail_unless(ann1->getNamespacePrefix(1) == "dc");
-  fail_unless(ann1->getNamespacePrefix(2) == "dcterms");
-  fail_unless(ann1->getNamespacePrefix(3) == "vCard");
+  fail_unless(ann1->getNamespacePrefix(1) == "dcterms");
+  fail_unless(ann1->getNamespacePrefix(2) == "vCard");
+  fail_unless(ann1->getNamespacePrefix(3) == "vCard4");
   fail_unless(ann1->getNamespacePrefix(4) == "bqbiol");
   fail_unless(ann1->getNamespacePrefix(5) == "bqmodel");
 
