@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -329,9 +329,9 @@ START_TEST (test_SyncAnnotation_modifyHistory_1)
   const char * expected =
     "<compartment metaid=\"_000004\" id=\"C\" constant=\"true\">\n"
     "  <annotation>\n"
-		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
+		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:vCard4=\"http://www.w3.org/2006/vcard/ns#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 		"      <rdf:Description rdf:about=\"#_000004\">\n"
-    "        <dc:creator>\n"
+    "        <dcterms:creator>\n"
 		"          <rdf:Bag>\n"
 		"            <rdf:li rdf:parseType=\"Resource\">\n"
     "              <vCard:N rdf:parseType=\"Resource\">\n"
@@ -344,7 +344,7 @@ START_TEST (test_SyncAnnotation_modifyHistory_1)
 		"              </vCard:ORG>\n"
 		"            </rdf:li>\n"
 		"          </rdf:Bag>\n"
-		"        </dc:creator>\n"
+		"        </dcterms:creator>\n"
 		"        <dcterms:created rdf:parseType=\"Resource\">\n"
 		"          <dcterms:W3CDTF>2005-02-02T14:56:11Z</dcterms:W3CDTF>\n"
 		"        </dcterms:created>\n"
@@ -400,7 +400,7 @@ START_TEST (test_SyncAnnotation_modifyHistory_3)
     "<annotation>\n"
 		"  <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 		"    <rdf:Description rdf:about=\"#_000001\">\n"
-    "      <dc:creator>\n"
+    "      <dcterms:creator>\n"
 		"        <rdf:Bag>\n"
 		"          <rdf:li rdf:parseType=\"Resource\">\n"
     "            <vCard:N rdf:parseType=\"Resource\">\n"
@@ -413,7 +413,7 @@ START_TEST (test_SyncAnnotation_modifyHistory_3)
 		"            </vCard:ORG>\n"
 		"          </rdf:li>\n"
 		"        </rdf:Bag>\n"
-		"      </dc:creator>\n"
+		"      </dcterms:creator>\n"
 		"      <dcterms:created rdf:parseType=\"Resource\">\n"
 		"        <dcterms:W3CDTF>2005-02-02T14:56:11Z</dcterms:W3CDTF>\n"
 		"      </dcterms:created>\n"
@@ -446,9 +446,9 @@ START_TEST (test_SyncAnnotation_modifyHistory_4)
   const char * expected =
     "<compartment metaid=\"_000002\" id=\"comp1\" constant=\"true\">\n"
     "  <annotation>\n"
-		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
+		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:vCard4=\"http://www.w3.org/2006/vcard/ns#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 		"      <rdf:Description rdf:about=\"#_000002\">\n"
-    "        <dc:creator>\n"
+    "        <dcterms:creator>\n"
 		"          <rdf:Bag>\n"
 		"            <rdf:li rdf:parseType=\"Resource\">\n"
     "              <vCard:N rdf:parseType=\"Resource\">\n"
@@ -461,7 +461,7 @@ START_TEST (test_SyncAnnotation_modifyHistory_4)
 		"              </vCard:ORG>\n"
 		"            </rdf:li>\n"
 		"          </rdf:Bag>\n"
-		"        </dc:creator>\n"
+		"        </dcterms:creator>\n"
 		"        <dcterms:created rdf:parseType=\"Resource\">\n"
 		"          <dcterms:W3CDTF>2005-02-02T14:56:11Z</dcterms:W3CDTF>\n"
 		"        </dcterms:created>\n"
@@ -496,7 +496,7 @@ START_TEST (test_SyncAnnotation_modifyHistory_5)
     "  <annotation>\n"
 		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 		"      <rdf:Description rdf:about=\"#_000032\">\n"
-    "        <dc:creator>\n"
+    "        <dcterms:creator>\n"
 		"          <rdf:Bag>\n"
 		"            <rdf:li rdf:parseType=\"Resource\">\n"
     "              <vCard:N rdf:parseType=\"Resource\">\n"
@@ -509,7 +509,7 @@ START_TEST (test_SyncAnnotation_modifyHistory_5)
 		"              </vCard:ORG>\n"
 		"            </rdf:li>\n"
 		"          </rdf:Bag>\n"
-		"        </dc:creator>\n"
+		"        </dcterms:creator>\n"
 		"        <dcterms:created rdf:parseType=\"Resource\">\n"
 		"          <dcterms:W3CDTF>2005-02-02T14:56:11Z</dcterms:W3CDTF>\n"
 		"        </dcterms:created>\n"
@@ -543,7 +543,7 @@ START_TEST (test_SyncAnnotation_modifyCVTerms_1)
   const char * expected =
     "<compartment metaid=\"_000012\" id=\"cc\" constant=\"true\">\n"
     "  <annotation>\n"
-		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
+		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:vCard4=\"http://www.w3.org/2006/vcard/ns#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 		"      <rdf:Description rdf:about=\"#_000012\">\n"
     "        <bqbiol:is>\n"
 		"          <rdf:Bag>\n"
@@ -661,7 +661,7 @@ START_TEST (test_SyncAnnotation_modifyCVTerms_4)
   const char * expected =
     "<compartment metaid=\"_000002\" id=\"comp1\" constant=\"true\">\n"
     "  <annotation>\n"
-		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
+		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:vCard4=\"http://www.w3.org/2006/vcard/ns#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 		"      <rdf:Description rdf:about=\"#_000002\">\n"
 		"        <bqbiol:is>\n"
 		"          <rdf:Bag>\n"
@@ -733,9 +733,9 @@ START_TEST (test_SyncAnnotation_modifyBoth_1)
   const char * expected =
     "<compartment metaid=\"_000002\" id=\"comp1\" constant=\"true\">\n"
     "  <annotation>\n"
-		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
+		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:vCard4=\"http://www.w3.org/2006/vcard/ns#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 		"      <rdf:Description rdf:about=\"#_000002\">\n"
-    "        <dc:creator>\n"
+    "        <dcterms:creator>\n"
 		"          <rdf:Bag>\n"
 		"            <rdf:li rdf:parseType=\"Resource\">\n"
     "              <vCard:N rdf:parseType=\"Resource\">\n"
@@ -748,7 +748,7 @@ START_TEST (test_SyncAnnotation_modifyBoth_1)
 		"              </vCard:ORG>\n"
 		"            </rdf:li>\n"
 		"          </rdf:Bag>\n"
-		"        </dc:creator>\n"
+		"        </dcterms:creator>\n"
 		"        <dcterms:created rdf:parseType=\"Resource\">\n"
 		"          <dcterms:W3CDTF>2005-02-02T14:56:11Z</dcterms:W3CDTF>\n"
 		"        </dcterms:created>\n"
@@ -772,7 +772,7 @@ START_TEST (test_SyncAnnotation_modifyBoth_1)
   const char * expected1 =
     "<compartment metaid=\"_000002\" id=\"comp1\" constant=\"true\">\n"
     "  <annotation>\n"
-		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
+		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:vCard4=\"http://www.w3.org/2006/vcard/ns#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 		"      <rdf:Description rdf:about=\"#_000002\">\n"
 		"        <bqbiol:is>\n"
 		"          <rdf:Bag>\n"
@@ -798,9 +798,9 @@ START_TEST (test_SyncAnnotation_modifyBoth_1)
   const char * expected2 =
     "<compartment metaid=\"_000002\" id=\"comp1\" constant=\"true\">\n"
     "  <annotation>\n"
-		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
+		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:vCard4=\"http://www.w3.org/2006/vcard/ns#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 		"      <rdf:Description rdf:about=\"#_000002\">\n"
-    "        <dc:creator>\n"
+    "        <dcterms:creator>\n"
 		"          <rdf:Bag>\n"
 		"            <rdf:li rdf:parseType=\"Resource\">\n"
     "              <vCard:N rdf:parseType=\"Resource\">\n"
@@ -813,7 +813,7 @@ START_TEST (test_SyncAnnotation_modifyBoth_1)
 		"              </vCard:ORG>\n"
 		"            </rdf:li>\n"
 		"          </rdf:Bag>\n"
-		"        </dc:creator>\n"
+		"        </dcterms:creator>\n"
 		"        <dcterms:created rdf:parseType=\"Resource\">\n"
 		"          <dcterms:W3CDTF>2005-02-02T14:56:11Z</dcterms:W3CDTF>\n"
 		"        </dcterms:created>\n"
@@ -857,7 +857,7 @@ START_TEST (test_SyncAnnotation_modifyBoth_2)
   const char * expected =
     "<compartment metaid=\"_000002\" id=\"comp1\" constant=\"true\">\n"
     "  <annotation>\n"
-		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
+		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:vCard4=\"http://www.w3.org/2006/vcard/ns#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 		"      <rdf:Description rdf:about=\"#_000002\">\n"
 		"        <bqbiol:is>\n"
 		"          <rdf:Bag>\n"
@@ -895,9 +895,9 @@ START_TEST (test_SyncAnnotation_modifyBoth_3)
   const char * expected =
     "<compartment metaid=\"_000002\" id=\"comp1\" constant=\"true\">\n"
     "  <annotation>\n"
-		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
+		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:vCard4=\"http://www.w3.org/2006/vcard/ns#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 		"      <rdf:Description rdf:about=\"#_000002\">\n"
-    "        <dc:creator>\n"
+    "        <dcterms:creator>\n"
 		"          <rdf:Bag>\n"
 		"            <rdf:li rdf:parseType=\"Resource\">\n"
     "              <vCard:N rdf:parseType=\"Resource\">\n"
@@ -910,7 +910,7 @@ START_TEST (test_SyncAnnotation_modifyBoth_3)
 		"              </vCard:ORG>\n"
 		"            </rdf:li>\n"
 		"          </rdf:Bag>\n"
-		"        </dc:creator>\n"
+		"        </dcterms:creator>\n"
 		"        <dcterms:created rdf:parseType=\"Resource\">\n"
 		"          <dcterms:W3CDTF>2005-02-02T14:56:11Z</dcterms:W3CDTF>\n"
 		"        </dcterms:created>\n"
@@ -989,7 +989,7 @@ START_TEST (test_SyncAnnotation_modifyBoth_4)
 		"    </jd2:JDesignerLayout>\n"
 		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 		"      <rdf:Description rdf:about=\"#_000003\">\n"
-    "        <dc:creator>\n"
+    "        <dcterms:creator>\n"
 		"          <rdf:Bag>\n"
 		"            <rdf:li rdf:parseType=\"Resource\">\n"
     "              <vCard:N rdf:parseType=\"Resource\">\n"
@@ -1002,7 +1002,7 @@ START_TEST (test_SyncAnnotation_modifyBoth_4)
 		"              </vCard:ORG>\n"
 		"            </rdf:li>\n"
 		"          </rdf:Bag>\n"
-		"        </dc:creator>\n"
+		"        </dcterms:creator>\n"
 		"        <dcterms:created rdf:parseType=\"Resource\">\n"
 		"          <dcterms:W3CDTF>2005-02-02T14:56:11Z</dcterms:W3CDTF>\n"
 		"        </dcterms:created>\n"
@@ -1075,7 +1075,7 @@ START_TEST (test_SyncAnnotation_modifyBoth_4)
 		"    </jd2:JDesignerLayout>\n"
 		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 		"      <rdf:Description rdf:about=\"#_000003\">\n"
-    "        <dc:creator>\n"
+    "        <dcterms:creator>\n"
 		"          <rdf:Bag>\n"
 		"            <rdf:li rdf:parseType=\"Resource\">\n"
     "              <vCard:N rdf:parseType=\"Resource\">\n"
@@ -1088,7 +1088,7 @@ START_TEST (test_SyncAnnotation_modifyBoth_4)
 		"              </vCard:ORG>\n"
 		"            </rdf:li>\n"
 		"          </rdf:Bag>\n"
-		"        </dc:creator>\n"
+		"        </dcterms:creator>\n"
 		"        <dcterms:created rdf:parseType=\"Resource\">\n"
 		"          <dcterms:W3CDTF>2005-02-02T14:56:11Z</dcterms:W3CDTF>\n"
 		"        </dcterms:created>\n"
@@ -1252,9 +1252,9 @@ START_TEST (test_SyncAnnotation_stringChangesMetaid)
   const char * expected =
     "<compartment metaid=\"_000005\" id=\"A\">\n"
     "  <annotation>\n"
-		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
+		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:vCard4=\"http://www.w3.org/2006/vcard/ns#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 		"      <rdf:Description rdf:about=\"#_000005\">\n"
-    "        <dc:creator>\n"
+    "        <dcterms:creator>\n"
 		"          <rdf:Bag>\n"
 		"            <rdf:li rdf:parseType=\"Resource\">\n"
     "              <vCard:N rdf:parseType=\"Resource\">\n"
@@ -1267,7 +1267,7 @@ START_TEST (test_SyncAnnotation_stringChangesMetaid)
 		"              </vCard:ORG>\n"
 		"            </rdf:li>\n"
 		"          </rdf:Bag>\n"
-		"        </dc:creator>\n"
+		"        </dcterms:creator>\n"
 		"        <dcterms:created rdf:parseType=\"Resource\">\n"
 		"          <dcterms:W3CDTF>2005-02-02T14:56:11Z</dcterms:W3CDTF>\n"
 		"        </dcterms:created>\n"
@@ -1470,9 +1470,9 @@ START_TEST (test_SyncAnnotation_stringChangesMetaid3)
   const char * expected =
     "<model metaid=\"_000005\" id=\"A\">\n"
     "  <annotation>\n"
-		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dc=\"http://purl.org/dc/elements/1.1/\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
+		"    <rdf:RDF xmlns:rdf=\"http://www.w3.org/1999/02/22-rdf-syntax-ns#\" xmlns:dcterms=\"http://purl.org/dc/terms/\" xmlns:vCard=\"http://www.w3.org/2001/vcard-rdf/3.0#\" xmlns:vCard4=\"http://www.w3.org/2006/vcard/ns#\" xmlns:bqbiol=\"http://biomodels.net/biology-qualifiers/\" xmlns:bqmodel=\"http://biomodels.net/model-qualifiers/\">\n"
 		"      <rdf:Description rdf:about=\"#_000005\">\n"
-    "        <dc:creator>\n"
+    "        <dcterms:creator>\n"
 		"          <rdf:Bag>\n"
 		"            <rdf:li rdf:parseType=\"Resource\">\n"
     "              <vCard:N rdf:parseType=\"Resource\">\n"
@@ -1485,7 +1485,7 @@ START_TEST (test_SyncAnnotation_stringChangesMetaid3)
 		"              </vCard:ORG>\n"
 		"            </rdf:li>\n"
 		"          </rdf:Bag>\n"
-		"        </dc:creator>\n"
+		"        </dcterms:creator>\n"
 		"        <dcterms:created rdf:parseType=\"Resource\">\n"
 		"          <dcterms:W3CDTF>2005-02-02T14:56:11Z</dcterms:W3CDTF>\n"
 		"        </dcterms:created>\n"
@@ -1514,7 +1514,7 @@ END_TEST
 
 START_TEST (test_SyncAnnotation_nestedCV_invalid)
 {
-  Compartment* c = new Compartment(3,1);
+  Compartment* c = new Compartment(2,4);
   c->setMetaId("_000012");
   c->setId("cc");
   c->setConstant(true);
