@@ -7,7 +7,7 @@
 * This file is part of libSBML.  Please visit http://sbml.org for more
 * information about SBML, and the latest version of libSBML.
 *
-* Copyright (C) 2013-2016 jointly by the following organizations:
+* Copyright (C) 2013-2017 jointly by the following organizations:
 *     1. California Institute of Technology, Pasadena, CA, USA
 *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
 *     3. University of Heidelberg, Heidelberg, Germany
@@ -163,26 +163,30 @@ SBMLLocalParameterConverter::convert()
     for (unsigned int j = list->size(); j >= 1; --j)
     {
       Parameter* param = list->remove(j-1);
-      const std::string oldId = param->getId();
-      string newId = getNewId(mModel, current->getId(), oldId);
-      LocalParameter* lParam = dynamic_cast<LocalParameter*>(param);
-
-      if (lParam != NULL)
+      if (param != NULL)
       {
-        Parameter newparam(*lParam);
-        newparam.setId(newId);
-        newparam.setConstant(true);
-        mModel->addParameter(&newparam);
-      }
-      else
-      {
-        param->setId(newId);
-        mModel->addParameter(param);
-      }
-      delete param;
+        const std::string oldId = param->getId();
+        string newId = getNewId(mModel, current->getId(), oldId);
+        LocalParameter* lParam = dynamic_cast<LocalParameter*>(param);
 
-      if (law->isSetMath()) 
-        (const_cast<ASTNode*>(law->getMath()))->renameSIdRefs(oldId, newId);
+        if (lParam != NULL)
+        {
+          Parameter newparam(*lParam);
+          newparam.setId(newId);
+          newparam.setConstant(true);
+          mModel->addParameter(&newparam);
+        }
+        else
+        {
+          param->setId(newId);
+          mModel->addParameter(param);
+        }
+        delete param;
+
+
+        if (law->isSetMath())
+          (const_cast<ASTNode*>(law->getMath()))->renameSIdRefs(oldId, newId);
+      }
     }
 
   }
