@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -63,6 +63,7 @@ Suite *create_suite_TestUnitsConverterL2 (void);
 Suite *create_suite_TestInferUnitsConverter (void);
 Suite *create_suite_TestStripPackageConverter (void);
 Suite *create_suite_TestLevelVersionConverter(void);
+Suite *create_suite_TestRateOfConverter(void);
 
 
 /**
@@ -118,6 +119,7 @@ main (void)
   srunner_add_suite( runner, create_suite_TestInferUnitsConverter    () );
   srunner_add_suite( runner, create_suite_TestStripPackageConverter  () );
   srunner_add_suite( runner, create_suite_TestLevelVersionConverter  () );
+  srunner_add_suite( runner, create_suite_TestRateOfConverter        () );
 
   /* srunner_set_fork_status(runner, CK_NOFORK); */
 
