@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -614,12 +614,14 @@ SBMLExtensionRegistry_getSBasePluginCreators(const SBaseExtensionPoint_t* extPoi
     SBMLExtensionRegistry::getInstance().getSBasePluginCreators(*extPoint);
 
   *length = (int)list.size();
-  SBasePluginCreatorBase_t** result = (SBasePluginCreatorBase_t**)malloc(sizeof(SBasePluginCreatorBase_t*)*((unsigned long)*length));
+  SBasePluginCreatorBase_t** result = 
+    (SBasePluginCreatorBase_t**)safe_malloc(sizeof(SBasePluginCreatorBase_t*)*((unsigned long)(*length)));
   
   std::list<const SBasePluginCreatorBase*>::iterator it;
   int count = 0;
   for (it = list.begin(); it != list.end(); it++)
   {
+    result[count] = (SBasePluginCreatorBase_t*)safe_malloc(sizeof(SBasePluginCreatorBase_t*));
     result[count++] = (*it)->clone();
   }
   
@@ -636,12 +638,14 @@ SBMLExtensionRegistry_getSBasePluginCreatorsByURI(const char* uri, int* length)
      SBMLExtensionRegistry::getInstance().getSBasePluginCreators(sUri);
  
    *length = (int)list.size();
-   SBasePluginCreatorBase_t** result = (SBasePluginCreatorBase_t**)malloc(sizeof(SBasePluginCreatorBase_t*)*((unsigned long)*length));
+   SBasePluginCreatorBase_t** result = 
+     (SBasePluginCreatorBase_t**)safe_malloc(sizeof(SBasePluginCreatorBase_t*)*((unsigned long)(*length)));
    
    std::list<const SBasePluginCreatorBase*>::iterator it;
    int count = 0;
    for (it = list.begin(); it != list.end(); it++)
    {
+     result[count] = (SBasePluginCreatorBase_t*)safe_malloc(sizeof(SBasePluginCreatorBase_t*));
      result[count++] = (*it)->clone();
    }
   
@@ -709,7 +713,7 @@ SBMLExtensionRegistry_getNumRegisteredPackages()
 /** 
  * Returns the registered package name at the given index
  * 
- * @param index zero based index of the package name to return
+ * @param index zero based index of the package name to return.
  * 
  * @return the package name with the given index or NULL
  */
