@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -43,6 +43,7 @@
 #include <sbml/xml/XMLNode.h>
 #include <sbml/Model.h>
 #include <sbml/util/IdList.h>
+#include <sbml/extension/SBMLExtensionRegistry.h>
 
 /** @cond doxygenIgnored */
 
@@ -68,7 +69,7 @@ LIBSBML_CPP_NAMESPACE_BEGIN
  * ASTNodeType predicate
  */
 #define ASTNodeType_isFunction(t) \
-  ((t >= AST_FUNCTION) && (t <= AST_FUNCTION_TANH))
+  (((t >= AST_FUNCTION) && (t <= AST_FUNCTION_TANH)) || (t <= AST_FUNCTION_REM && t >= AST_FUNCTION_MAX))
 
 /**
  * ASTNodeType predicate
@@ -80,7 +81,7 @@ LIBSBML_CPP_NAMESPACE_BEGIN
  * ASTNodeType predicate
  */
 #define ASTNodeType_isLogical(t) \
-  ((t >= AST_LOGICAL_AND) && (t <= AST_LOGICAL_XOR))
+  (((t >= AST_LOGICAL_AND) && (t <= AST_LOGICAL_XOR)) || t == AST_LOGICAL_IMPLIES)
 
 /**
  * ASTNodeType predicate
@@ -118,7 +119,12 @@ LIBSBML_CPP_NAMESPACE_BEGIN
 #define ASTNodeType_isNumber(t) \
   (ASTNodeType_isInteger(t) || ASTNodeType_isReal(t))
 
-/**
+ /**
+ * ASTNodeType predicate
+ */
+#define ASTNodeType_isConstantNumber(t) \
+  (t == AST_CONSTANT_E || t == AST_CONSTANT_PI || t == AST_NAME_AVOGADRO)
+ /**
  * ASTNodeType predicate
  */
 #define ASTNodeType_isOperator(t) \
@@ -188,6 +194,15 @@ static const char *AST_FUNCTION_STRINGS[] =
   , "tanh"
 };
 
+static const char *AST_NEW_FUNCTION_STRINGS[] =
+{
+    "max"
+  , "min"
+  , "quotient"
+  , "rateOf"
+  , "rem"
+};
+
 
 static const char *AST_LOGICAL_STRINGS[] =
 {
@@ -198,6 +213,12 @@ static const char *AST_LOGICAL_STRINGS[] =
 };
 
 
+static const char *AST_NEW_LOGICAL_STRINGS[] =
+{
+    "implies"
+};
+
+
 static const char *AST_RELATIONAL_STRINGS[] =
 {
     "eq"
@@ -251,6 +272,12 @@ ASTNode::ASTNode (ASTNodeType_t type)
 
   mChildren             = new List;
   mSemanticsAnnotations = new List;
+  //loadASTPlugins(NULL);
+  //for (unsigned int i = 0; i < getNumPlugins(); i++)
+  //{
+  //  getPlugin(i)->connectToParent(this);
+  //}
+
 }
 
 
@@ -307,8 +334,25 @@ ASTNode::ASTNode (Token_t* token)
       setCharacter(token->value.ch);
     }
   }
+  //loadASTPlugins(NULL);
+  //for (unsigned int i = 0; i < getNumPlugins(); i++)
+  //{
+  //  getPlugin(i)->connectToParent(this);
+  //}
 }
 
+/*
+* Used by the Copy Constructor to clone each item in mPlugins.
+*/
+struct CloneASTPluginEntity : public unary_function<ASTBasePlugin*, ASTBasePlugin*>
+{
+  ASTBasePlugin* operator() (ASTBasePlugin* ast) {
+    if (!ast) return 0;
+    return ast->clone();
+  }
+};
+
+
 /*
  * 
  * Copy constructor; Creates a deep copy of the given ASTNode
@@ -349,6 +393,13 @@ ASTNode::ASTNode (const ASTNode& orig) :
   {
     addSemanticsAnnotation( orig.getSemanticsAnnotation(c)->clone() );
   }
+  mPlugins.resize(orig.mPlugins.size());
+  transform(orig.mPlugins.begin(), orig.mPlugins.end(),
+    mPlugins.begin(), CloneASTPluginEntity());
+  for (size_t i = 0; i < mPlugins.size(); i++)
+  {
+    getPlugin((unsigned int)i)->connectToParent(this);
+  }
 }
 
 /*
@@ -407,6 +458,10 @@ ASTNode& ASTNode::operator=(const ASTNode& rhs)
     
     delete mDefinitionURL;
     mDefinitionURL        = rhs.mDefinitionURL->clone();	
+    clearPlugins();
+    mPlugins.resize(rhs.mPlugins.size());
+    transform(rhs.mPlugins.begin(), rhs.mPlugins.end(),
+      mPlugins.begin(), CloneASTPluginEntity());
   }
   return *this;
 }
@@ -430,6 +485,7 @@ ASTNode::~ASTNode ()
   delete mDefinitionURL;
   
   freeName();
+  clearPlugins();
 }
 
 
@@ -552,6 +608,10 @@ ASTNode::canonicalizeFunction ()
   const int last  = AST_FUNCTION_TANH;
   const int size  = last - first + 1;
 
+  const int new_first = AST_FUNCTION_MAX;
+  const int new_last  = AST_FUNCTION_REM;
+  const int new_size  = new_last - new_first + 1;
+
   int  index;
   bool found;
 
@@ -586,6 +646,19 @@ ASTNode::canonicalizeFunction ()
     }
   }
 
+  // and then the new ones
+  if (!found)
+  {
+    index = util_bsearchStringsI(AST_NEW_FUNCTION_STRINGS, mName, 0, new_size - 1);
+    found = (index < new_size);
+
+    if (found)
+    {
+      setType( static_cast<ASTNodeType_t>(new_first + index) );
+    }
+  }
+
+
   return found;
 }
 /** @endcond */
@@ -698,6 +771,10 @@ ASTNode::canonicalizeLogical ()
   const int last  = AST_LOGICAL_XOR;
   const int size  = last - first + 1;
 
+  const int new_first = AST_LOGICAL_IMPLIES;
+  const int new_last  = AST_LOGICAL_IMPLIES;
+  const int new_size  = new_last - new_first + 1;
+
   int  index;
   bool found;
 
@@ -710,6 +787,17 @@ ASTNode::canonicalizeLogical ()
     setType( static_cast<ASTNodeType_t>(first + index) );
   }
 
+  if (!found)
+  {
+    index = util_bsearchStringsI(AST_NEW_LOGICAL_STRINGS, mName, 0, new_size - 1);
+    found = (index < new_size);
+
+    if (found)
+    {
+      setType( static_cast<ASTNodeType_t>(new_first + index) );
+    }
+  }
+
   return found;
 }
 /** @endcond */
@@ -1130,11 +1218,25 @@ ASTNode::getName () const
     }
     else if ( isFunction() )
     {
-      result = AST_FUNCTION_STRINGS[ mType - AST_FUNCTION_ABS ];
+      if (mType < AST_LOGICAL_IMPLIES && mType >= AST_FUNCTION_MAX)
+      {
+        result = AST_NEW_FUNCTION_STRINGS[mType - AST_FUNCTION_MAX];
+      }
+      else if (mType <= AST_FUNCTION_TANH && mType >= AST_FUNCTION_ABS)
+      {
+        result = AST_FUNCTION_STRINGS[ mType - AST_FUNCTION_ABS ];
+      }
     }
     else if ( isLogical() )
     {
-      result = AST_LOGICAL_STRINGS[ mType - AST_LOGICAL_AND ];
+      if (mType == AST_LOGICAL_IMPLIES)
+      {
+        result = AST_NEW_LOGICAL_STRINGS[0];
+      }
+      else
+      {
+        result = AST_LOGICAL_STRINGS[ mType - AST_LOGICAL_AND ];
+      }
     }
     else if ( isRelational() )
     {
@@ -1362,6 +1464,53 @@ ASTNode::getUnits() const
   return mUnits;
 }
 
+/** @cond doxygenLibsbmlInternal */
+LIBSBML_EXTERN
+bool
+ASTNode::usesL3V2MathConstructs() const
+{
+  bool mathConstructs = false;
+
+  int type = getType();
+  if (type == AST_FUNCTION_RATE_OF ||
+      type == AST_FUNCTION_MIN ||
+      type == AST_FUNCTION_MAX ||
+      type == AST_FUNCTION_REM ||
+      type == AST_FUNCTION_QUOTIENT ||
+      type == AST_LOGICAL_IMPLIES)
+      mathConstructs = true;
+  unsigned int i = 0;
+  while (!mathConstructs && i < getNumChildren())
+  {
+    mathConstructs = getChild(i)->usesL3V2MathConstructs();
+    i++;
+  }
+
+  return mathConstructs;
+}
+/** @endcond */
+
+
+/** @cond doxygenLibsbmlInternal */
+LIBSBML_EXTERN
+bool
+ASTNode::usesRateOf() const
+{
+  bool mathConstructs = false;
+
+  if (getType() == AST_FUNCTION_RATE_OF)
+      mathConstructs = true;
+  unsigned int i = 0;
+  while (!mathConstructs && i < getNumChildren())
+  {
+    mathConstructs = getChild(i)->usesRateOf();
+    i++;
+  }
+
+  return mathConstructs;
+}
+/** @endcond */
+
 /*
  * @return true if this ASTNode is a boolean (a logical operator, a
  * relational operator, or the constants true or false), false otherwise.
@@ -1418,8 +1567,8 @@ ASTNode::returnsBoolean (const Model* givenModel /*=NULL*/) const
 
       if (fd != NULL && fd->isSetMath())
       {
-        return (fd->getMath()->getRightChild() != NULL ? 
-          fd->getMath()->getRightChild()->returnsBoolean() : false);
+        return (fd->getBody() != NULL ? 
+          fd->getBody()->returnsBoolean() : false);
       }
       else
       {
@@ -1457,12 +1606,45 @@ ASTNode::isConstant () const
   return ASTNodeType_isConstant(mType);
 }
 
+/*
+* @return true if this ASTNode is a MathML constant number
+*(pi, exponentiale), false otherwise.
+*/
+LIBSBML_EXTERN
+bool
+ASTNode::isCiNumber() const
+{
+  return (mType == AST_NAME);
+}
+
+
+
 
 /*
- * @return true if this ASTNode is a function in SBML L1, L2 (MathML)
- * (everything from abs() to tanh()) or user-defined, false otherwise.
+ * @return true if this ASTNode is a MathML constant number 
+ *(pi, exponentiale), false otherwise.
  */
 LIBSBML_EXTERN
+bool 
+ASTNode::isConstantNumber() const
+{
+  return ASTNodeType_isConstantNumber(mType);
+}
+
+
+/*
+* @return true if this ASTNode is a MathML constant number
+*(pi, exponentiale), false otherwise.
+*/
+LIBSBML_EXTERN
+bool
+ASTNode::isCSymbolFunction() const
+{
+  return (mType == AST_FUNCTION_DELAY || mType == AST_FUNCTION_RATE_OF);
+}
+
+
+
 bool
 ASTNode::isFunction () const
 {
@@ -1744,6 +1926,13 @@ ASTNode::isUPlus () const
   return uplus;
 }
 
+LIBSBML_EXTERN
+bool
+ASTNode::isUserFunction() const
+{
+  return (mType == AST_FUNCTION);
+}
+
 LIBSBML_EXTERN
 int
 ASTNode::hasTypeAndNumChildren(ASTNodeType_t type, unsigned int numchildren) const
@@ -2697,7 +2886,7 @@ LIBSBML_EXTERN
 void *
 ASTNode::getUserData() const
 {
-	return this->mUserData;
+  return this->mUserData;
 }
 
 
@@ -2705,7 +2894,7 @@ LIBSBML_EXTERN
 int
 ASTNode::setUserData(void *userData)
 {
-	this->mUserData = userData;
+  this->mUserData = userData;
  
   // allow userData to be set to NULL
   if (userData == NULL)
@@ -2911,6 +3100,171 @@ unsigned int ASTNode::getNumVariablesWithUndeclaredUnits(Model * m) const
 }
 /** @endcond */
 
+/** @cond doxygenLibsbmlInternal */
+
+LIBSBML_EXTERN
+void
+ASTNode::loadASTPlugins(const SBMLNamespaces * sbmlns)
+{
+  if (sbmlns == NULL)
+  {
+    const std::vector<std::string>& names = SBMLExtensionRegistry::getAllRegisteredPackageNames();
+    unsigned int numPkgs = (unsigned int)names.size();
+
+    for (unsigned int i = 0; i < numPkgs; i++)
+    {
+      const std::string& uri = names[i];
+      const SBMLExtension* sbmlext = SBMLExtensionRegistry::getInstance().getExtensionInternal(uri);
+
+      if (sbmlext && sbmlext->isEnabled())
+      {
+
+        //const std::string &prefix = xmlns->getPrefix(i);
+        const ASTBasePlugin* astPlugin = sbmlext->getASTBasePlugin();
+        if (astPlugin != NULL)
+        {
+          ASTBasePlugin* myastPlugin = astPlugin->clone();
+          myastPlugin->setSBMLExtension(sbmlext);
+          //            myastPlugin->setPrefix(xmlns->getPrefix(i));
+          myastPlugin->connectToParent(this);
+          mPlugins.push_back(myastPlugin);
+        }
+
+      }
+    }
+  }
+  else
+  {
+    const XMLNamespaces *xmlns = sbmlns->getNamespaces();
+
+    if (xmlns)
+    {
+      int numxmlns = xmlns->getLength();
+      for (int i = 0; i < numxmlns; i++)
+      {
+        const std::string &uri = xmlns->getURI(i);
+        const SBMLExtension* sbmlext = SBMLExtensionRegistry::getInstance().getExtensionInternal(uri);
+
+        if (sbmlext && sbmlext->isEnabled())
+        {
+          const ASTBasePlugin* astPlugin = sbmlext->getASTBasePlugin();
+          if (astPlugin != NULL)
+          {
+            ASTBasePlugin* myastPlugin = astPlugin->clone();
+            myastPlugin->setSBMLExtension(sbmlext);
+            myastPlugin->setPrefix(xmlns->getPrefix(i));
+            myastPlugin->connectToParent(this);
+            mPlugins.push_back(myastPlugin);
+          }
+        }
+      }
+    }
+  }
+}
+
+LIBSBML_EXTERN
+void 
+ASTNode::addPlugin(ASTBasePlugin* plugin)
+{
+  mPlugins.push_back(plugin);
+}
+
+
+/** @endcond */
+
+/** @cond doxygenLibsbmlInternal */
+
+LIBSBML_EXTERN
+ASTBasePlugin*
+ASTNode::getPlugin(const std::string& package)
+{
+  ASTBasePlugin* astPlugin = 0;
+
+  // here we need to load a plugin if there are none
+  if (mPlugins.size() == 0)
+  {
+    loadASTPlugins(NULL);
+  }
+  for (size_t i = 0; i < mPlugins.size(); i++)
+  {
+    std::string uri = mPlugins[i]->getURI();
+    const SBMLExtension* sbmlext = SBMLExtensionRegistry::getInstance().getExtensionInternal(uri);
+    if (uri == package)
+    {
+      astPlugin = mPlugins[i];
+      break;
+    }
+    else if (sbmlext && (sbmlext->getName() == package))
+    {
+      astPlugin = mPlugins[i];
+      break;
+    }
+  }
+
+  return astPlugin;
+}
+
+/** @endcond */
+
+/** @cond doxygenLibsbmlInternal */
+
+LIBSBML_EXTERN
+const ASTBasePlugin*
+ASTNode::getPlugin(const std::string& package) const
+{
+  return const_cast<ASTNode*>(this)->getPlugin(package);
+}
+
+/** @endcond */
+
+/** @cond doxygenLibsbmlInternal */
+
+
+LIBSBML_EXTERN
+ASTBasePlugin*
+ASTNode::getPlugin(unsigned int n)
+{
+  if (n >= getNumPlugins())
+    return NULL;
+  return mPlugins[n];
+}
+
+/** @endcond */
+
+/** @cond doxygenLibsbmlInternal */
+
+LIBSBML_EXTERN
+const ASTBasePlugin*
+ASTNode::getPlugin(unsigned int n) const
+{
+  return const_cast<ASTNode*>(this)->getPlugin(n);
+}
+
+/** @endcond */
+
+/** @cond doxygenLibsbmlInternal */
+
+LIBSBML_EXTERN
+unsigned int
+ASTNode::getNumPlugins() const
+{
+  return (unsigned int)mPlugins.size();
+}
+
+
+/** @endcond */
+
+struct DeleteASTPluginEntity : public unary_function<ASTBasePlugin*, void>
+{
+  void operator() (ASTBasePlugin* ast) { delete ast; }
+};
+
+void ASTNode::clearPlugins()
+{
+  for_each(mPlugins.begin(), mPlugins.end(), DeleteASTPluginEntity());
+  mPlugins.clear();
+}
+
 
 #endif /* __cplusplus */
 
@@ -2974,7 +3328,7 @@ LIBSBML_EXTERN
 int
 ASTNode_addChild (ASTNode_t *node, ASTNode_t *child)
 {
-	if (node == NULL) return LIBSBML_INVALID_OBJECT;
+  if (node == NULL) return LIBSBML_INVALID_OBJECT;
   return static_cast<ASTNode*>(node)->addChild
                                     ( static_cast<ASTNode*>(child) );
 }
@@ -3242,6 +3596,15 @@ ASTNode_isConstant (const ASTNode_t *node)
 }
 
 
+LIBSBML_EXTERN
+int
+ASTNode_isConstantNumber(const ASTNode_t *node)
+{
+  if (node == NULL) return (int)false;
+  return (int) static_cast<const ASTNode*>(node)->isConstantNumber();
+}
+
+
 LIBSBML_EXTERN
 int
 ASTNode_isFunction (const ASTNode_t *node)
