@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -290,7 +290,7 @@ FormulaFormatter_formatReal (StringBuffer_t *sb, const ASTNode_t *node)
   {
     if (ASTNode_getType(node) == AST_REAL_E)
     {
-      StringBuffer_appendExp(sb, value);
+      StringBuffer_appendFullExp(sb, ASTNode_getMantissa(node), ASTNode_getExponent(node), value);
     }
     else
     {
@@ -430,7 +430,7 @@ FormulaFormatter_visitOther ( const ASTNode_t *parent,
                               StringBuffer_t  *sb )
 {
   unsigned int numChildren = ASTNode_getNumChildren(node);
-  unsigned int group       = FormulaFormatter_isGrouped(parent, node);
+  int group       = FormulaFormatter_isGrouped(parent, node);
   unsigned int n;
 
 
@@ -469,6 +469,5 @@ FormulaFormatter_visitOther ( const ASTNode_t *parent,
     StringBuffer_appendChar(sb, ')');
   }
 }
-
 /** @endcond */
 
