@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -35,6 +35,10 @@
 #include <sbml/math/FormulaTokenizer.h>
 #include <sbml/math/FormulaParser.h>
 
+#ifdef _MSC_VER
+#pragma warning( disable: 4311)
+#pragma warning( disable: 4312)
+#endif
 
 /** @cond doxygenLibsbmlInternal */
 
