@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -44,6 +44,12 @@
 #include <sbml/math/ASTNode.h>
 #include <sbml/math/MathML.h>
 
+#include <algorithm>
+
+#ifdef USE_MULTI
+#include <sbml/packages/multi/common/MultiExtensionTypes.h>
+#endif
+
 /** @cond doxygenIgnored */
 
 using namespace std;
@@ -60,6 +66,7 @@ LIBSBML_CPP_NAMESPACE_BEGIN
 static const char* URL_TIME  = "http://www.sbml.org/sbml/symbols/time";
 static const char* URL_DELAY = "http://www.sbml.org/sbml/symbols/delay";
 static const char* URL_AVOGADRO = "http://www.sbml.org/sbml/symbols/avogadro";
+static const char* URL_RATE_OF = "http://www.sbml.org/sbml/symbols/rateOf";
 
 static const char* MATHML_ELEMENTS[] =
 {
@@ -101,6 +108,7 @@ static const char* MATHML_ELEMENTS[] =
   , "floor"
   , "geq"
   , "gt"
+  , "implies"
   , "infinity"
   , "lambda"
   , "leq"
@@ -109,6 +117,8 @@ static const char* MATHML_ELEMENTS[] =
   , "logbase"
   , "lt"
   , "math"
+  , "max"
+  , "min"
   , "minus"
   , "neq"
   , "not"
@@ -120,6 +130,8 @@ static const char* MATHML_ELEMENTS[] =
   , "piecewise"
   , "plus"
   , "power"
+  , "quotient"
+  , "rem"
   , "root"
   , "sec"
   , "sech"
@@ -182,6 +194,11 @@ static const char* MATHML_FUNCTIONS[] =
   , "leq"
   , "lt"
   , "neq"
+  , "max"
+  , "min"
+  , "quotient"
+  , "rem"
+  , "implies"
 };
 
 
@@ -207,7 +224,7 @@ static const ASTNodeType_t MATHML_TYPES[] =
   , AST_UNKNOWN
   , AST_FUNCTION_CEILING
   , AST_NAME
-  , AST_REAL
+  , AST_CSYMBOL_FUNCTION
   , AST_FUNCTION_COS
   , AST_FUNCTION_COSH
   , AST_FUNCTION_COT
@@ -225,6 +242,7 @@ static const ASTNodeType_t MATHML_TYPES[] =
   , AST_FUNCTION_FLOOR
   , AST_RELATIONAL_GEQ
   , AST_RELATIONAL_GT
+  , AST_LOGICAL_IMPLIES
   , AST_REAL
   , AST_LAMBDA
   , AST_RELATIONAL_LEQ
@@ -233,6 +251,8 @@ static const ASTNodeType_t MATHML_TYPES[] =
   , AST_UNKNOWN
   , AST_RELATIONAL_LT
   , AST_UNKNOWN
+  , AST_FUNCTION_MAX
+  , AST_FUNCTION_MIN
   , AST_MINUS
   , AST_RELATIONAL_NEQ
   , AST_LOGICAL_NOT
@@ -244,6 +264,8 @@ static const ASTNodeType_t MATHML_TYPES[] =
   , AST_FUNCTION_PIECEWISE
   , AST_PLUS
   , AST_FUNCTION_POWER
+  , AST_FUNCTION_QUOTIENT
+  , AST_FUNCTION_REM
   , AST_FUNCTION_ROOT
   , AST_FUNCTION_SEC
   , AST_FUNCTION_SECH
@@ -386,7 +408,18 @@ setTypeCI (ASTNode& node, const XMLToken& element, XMLInputStream& stream)
     string url;
     element.getAttributes().readInto("definitionURL", url);
 
-    if (stream.getSBMLNamespaces()->getLevel() < 3)
+    if (stream.getSBMLNamespaces() == NULL)
+    {
+      // non sbml
+      if (url == URL_DELAY) node.setType(AST_FUNCTION_DELAY);
+      else if (url == URL_TIME) node.setType(AST_NAME_TIME);
+      else if (url == URL_AVOGADRO) node.setType(AST_NAME_AVOGADRO);
+      else if (url == URL_RATE_OF) node.setType(AST_FUNCTION_RATE_OF);
+      else node.setType(AST_CSYMBOL_FUNCTION);
+      node.setDefinitionURL(url);
+
+    }
+    else if (stream.getSBMLNamespaces()->getLevel() < 3)
     {
       if ( url == URL_DELAY ) node.setType(AST_FUNCTION_DELAY);
       else if ( url == URL_TIME  ) node.setType(AST_NAME_TIME);
@@ -397,9 +430,24 @@ setTypeCI (ASTNode& node, const XMLToken& element, XMLInputStream& stream)
     }
     else
     {
+      /* level 3 */
+      unsigned int version = stream.getSBMLNamespaces()->getVersion();
       if ( url == URL_DELAY ) node.setType(AST_FUNCTION_DELAY);
       else if ( url == URL_TIME  ) node.setType(AST_NAME_TIME);
       else if ( url == URL_AVOGADRO  ) node.setType(AST_NAME_AVOGADRO);
+      else if ( url == URL_RATE_OF)
+      {
+        if (version > 1) 
+        {
+          node.setType(AST_FUNCTION_RATE_OF);
+        }
+        else
+        {
+          node.setType(AST_FUNCTION);
+          logError(stream, element, BadCsymbolDefinitionURLValue);      
+        }
+
+      }
       else 
       {
         logError(stream, element, BadCsymbolDefinitionURLValue);      
@@ -412,6 +460,29 @@ setTypeCI (ASTNode& node, const XMLToken& element, XMLInputStream& stream)
     {
       node.setDefinitionURL(element.getAttributes());
     }
+#ifdef USE_MULTI
+    if (element.getAttributes().hasAttribute("speciesReference", 
+      "http://www.sbml.org/sbml/level3/version1/multi/version1") == true
+      || element.getAttributes().hasAttribute("representationType",
+        "http://www.sbml.org/sbml/level3/version1/multi/version1") == true)
+    {
+      node.loadASTPlugins(stream.getSBMLNamespaces());
+      MultiASTPlugin * plug = static_cast<MultiASTPlugin*>(node.getPlugin("multi"));
+      if (plug != NULL)
+      {
+        std::string sr = element.getAttributes().getValue("speciesReference");
+        std::string rt = element.getAttributes().getValue("representationType");
+
+        if (!sr.empty())
+          plug->setSpeciesReference(sr);
+
+        if (!rt.empty())
+          plug->setRepresentationType(rt);
+      }
+    }
+
+
+#endif
   }
 
   const string name = trim( stream.next().getCharacters() );
@@ -434,6 +505,11 @@ setTypeCN (ASTNode& node, const XMLToken& element, XMLInputStream& stream)
   // here is the only place we might encounter the sbml:units attribute
   string units = "";
   element.getAttributes().readInto("units", units);
+  if (!SyntaxChecker::isValidInternalUnitSId(units))
+  {
+    std::string msg = "The units attribute '" + units + "' does not conform to the syntax.";
+    logError(stream, element, InvalidUnitIdSyntax, msg);
+  }
 
   if (type == "real")
   {
@@ -637,6 +713,13 @@ static void
 readMathML (ASTNode& node, XMLInputStream& stream, std::string reqd_prefix,
             bool inRead)
 {
+  unsigned int level = 3;
+  unsigned int version = 2;
+  if (stream.getSBMLNamespaces() != NULL)
+  {
+    level = stream.getSBMLNamespaces()->getLevel();
+    version = stream.getSBMLNamespaces()->getVersion();
+  }
 
   std::string prefix;
   bool prefix_reqd = false;
@@ -672,11 +755,25 @@ readMathML (ASTNode& node, XMLInputStream& stream, std::string reqd_prefix,
 
   int  index = util_bsearchStringsI(MATHML_ELEMENTS, name.c_str(), 0, size - 1);
   bool found = (index < size);
+  int l3v2index[] = {38, 47, 48, 60, 61};
+  std::vector<int> l3v2;
+  l3v2.assign(l3v2index, l3v2index+5);
 
   if (!found)
   {
     logError(stream, elem, DisallowedMathMLSymbol);    
   }
+  else if (level != 3 ||(level == 3 && version != 2))
+  {
+    if (std::find(l3v2.begin(), l3v2.end(), index) != l3v2.end())
+    {
+      stringstream message;
+      message << "<" << name << "> is not valid " 
+        << "in SBML Level " << level << " Version "  
+        << version << ".";
+      logError(stream, elem, DisallowedMathMLSymbol, message.str());    
+    }
+  }
 
   // check any reqd prefix is correct
   if (prefix_reqd)
@@ -706,13 +803,13 @@ readMathML (ASTNode& node, XMLInputStream& stream, std::string reqd_prefix,
   elem.getAttributes().readInto( "style"        , style     );
 
   if (!id.empty())
-	  node.setId(id);
+    node.setId(id);
 
   if (!className.empty())
-	  node.setClass(className);
+    node.setClass(className);
 
   if (!style.empty())
-	  node.setStyle(style);
+    node.setStyle(style);
 
   if ( !type.empty() && name != "cn")
   {
@@ -728,15 +825,14 @@ readMathML (ASTNode& node, XMLInputStream& stream, std::string reqd_prefix,
   // and on ci in L3 and L2V5
   if ( !url.empty())
   {      
-    SBMLNamespaces* ns = stream.getSBMLNamespaces();
-    if (ns != NULL && ns->getLevel() > 2)
+    if (level > 2)
     {
       if (name != "csymbol" && name != "semantics" && name != "ci")
       {
         logError(stream, elem, DisallowedDefinitionURLUse);
       }
     }
-    else if (ns != NULL && ns->getLevel() == 2 && ns->getVersion() == 5)
+    else if (level == 2 && version == 5)
     {
       if (name != "csymbol" && name != "semantics" && name != "ci")
       {
@@ -750,14 +846,12 @@ readMathML (ASTNode& node, XMLInputStream& stream, std::string reqd_prefix,
         logError(stream, elem, DisallowedDefinitionURLUse);
       }
     }
-
   }
 
 
   if ( !units.empty())
   {
-    if (stream.getSBMLNamespaces() != NULL
-      && stream.getSBMLNamespaces()->getLevel() > 2)
+    if (level > 2)
     {
       if (name != "cn")
       {
@@ -1050,9 +1144,9 @@ static void writeStartEndElement (const string&, const ASTNode&, XMLOutputStream
 static void 
 writeStartEndElement (const string& name, const ASTNode& node, XMLOutputStream& stream)
 {
-	stream.startElement(name);
-	writeAttributes(node, stream);
-	stream.endElement(name);
+  stream.startElement(name);
+  writeAttributes(node, stream);
+  stream.endElement(name);
 }
 /** @endcond */
 
@@ -1066,7 +1160,7 @@ writeAttributes(const ASTNode& node, XMLOutputStream& stream)
   if (node.isSetId())
     stream.writeAttribute("id", node.getId());
   if (node.isSetClass())
-	  stream.writeAttribute("class", node.getClass());
+    stream.writeAttribute("class", node.getClass());
   if (node.isSetStyle())
     stream.writeAttribute("style", node.getStyle());
 }
@@ -1083,7 +1177,7 @@ writeCI (const ASTNode& node, XMLOutputStream& stream, SBMLNamespaces *sbmlns)
   ASTNodeType_t type = node.getType();
 
   if (type == AST_FUNCTION_DELAY || type == AST_NAME_TIME
-    || type == AST_NAME_AVOGADRO )
+    || type == AST_NAME_AVOGADRO || type == AST_FUNCTION_RATE_OF)
   {
     writeCSymbol(node, stream, sbmlns);
   }
@@ -1091,7 +1185,16 @@ writeCI (const ASTNode& node, XMLOutputStream& stream, SBMLNamespaces *sbmlns)
   {
     stream.startElement("ci");
     stream.setAutoIndent(false);
-	  writeAttributes(node, stream);
+    writeAttributes(node, stream);
+#ifdef USE_MULTI
+    const_cast<ASTNode&>(node).loadASTPlugins(stream.getSBMLNamespaces());
+    MultiASTPlugin * plug = static_cast<MultiASTPlugin*>(const_cast<ASTNode&>(node).getPlugin("multi"));
+    if (plug != NULL)
+    {
+      plug->writeAttributes(stream, (int)(type));
+    }
+
+#endif
     if (node.getDefinitionURL() != NULL)
     {
       stream.writeAttribute("definitionURL", 
@@ -1120,12 +1223,12 @@ writeCN (const ASTNode& node, XMLOutputStream& stream, SBMLNamespaces *sbmlns=NU
 
   if ( node.isNaN() )
   {
-	  writeStartEndElement("notanumber", node, stream);
+    writeStartEndElement("notanumber", node, stream);
     //stream.startEndElement("notanumber");
   }
   else if ( !(node.getType() == AST_REAL_E) && node.isInfinity() )
   {
-	  writeStartEndElement("infinity", node, stream);
+    writeStartEndElement("infinity", node, stream);
     //stream.startEndElement("infinity");
   }
   else if ( node.isNegInfinity() )
@@ -1143,7 +1246,7 @@ writeCN (const ASTNode& node, XMLOutputStream& stream, SBMLNamespaces *sbmlns=NU
   else
   {
     stream.startElement("cn");
-  	writeAttributes(node, stream);
+    writeAttributes(node, stream);
     if (!node.getUnits().empty())
     {
       // we only write out the units iff, we don't know what namespace we 
@@ -1195,7 +1298,7 @@ writeConstant (const ASTNode& node, XMLOutputStream& stream)
 
   switch ( node.getType() )
   {
-	case AST_CONSTANT_PI:    writeStartEndElement("pi", node, stream);           break;
+  case AST_CONSTANT_PI:    writeStartEndElement("pi", node, stream);           break;
     case AST_CONSTANT_TRUE:  writeStartEndElement("true", node, stream);         break;
     case AST_CONSTANT_FALSE: writeStartEndElement("false", node, stream);        break;
     case AST_CONSTANT_E:     writeStartEndElement("exponentiale", node, stream); break;
@@ -1224,6 +1327,8 @@ writeCSymbol (const ASTNode& node, XMLOutputStream& stream, SBMLNamespaces *sbml
        if (type == AST_FUNCTION_DELAY) url = URL_DELAY;
   else if (type == AST_NAME_TIME)      url = URL_TIME;
   else if (type == AST_NAME_AVOGADRO)  url = URL_AVOGADRO;
+  else if (type == AST_FUNCTION_RATE_OF)  url = URL_RATE_OF;
+  else url = node.getDefinitionURLString();
 
   stream.startElement("csymbol");
   stream.setAutoIndent(false);
@@ -1346,8 +1451,19 @@ writeFunctionLog (const ASTNode& node, XMLOutputStream& stream, SBMLNamespaces *
 
     stream.endElement("logbase");
   }
+  /* I wanted to add this as a log can have a default logbase
+   * however the rest of the code relating to log assumes it
+   * has two children so I would break everything
+   */
+  //else if (node.getNumChildren() == 1)
+  //{
+  //  writeNode(*node.getChild(0), stream, sbmlns);
+  //}
 
-  if ( node.getRightChild() ) writeNode(*node.getRightChild(), stream, sbmlns);
+  if ( node.getRightChild() ) 
+  {
+    writeNode(*node.getRightChild(), stream, sbmlns);
+  }
 }
 /** @endcond */
 
@@ -1401,14 +1517,22 @@ writeFunction (const ASTNode& node, XMLOutputStream& stream, SBMLNamespaces *sbm
     {
       writeCI(node, stream,sbmlns);
     }
-    else if (type == AST_FUNCTION_DELAY)
+    else if (type == AST_FUNCTION_DELAY || type == AST_FUNCTION_RATE_OF 
+      || type == AST_CSYMBOL_FUNCTION)
     {
       writeCSymbol(node, stream,sbmlns);
     }
     else
     {
-      const char* name = MATHML_FUNCTIONS[type - AST_FUNCTION_ABS];
-	  writeStartEndElement(name, node, stream);
+      unsigned int index = type - AST_FUNCTION_ABS;
+
+      if (type <= AST_FUNCTION_QUOTIENT && type > AST_RELATIONAL_NEQ)
+        index = type - AST_FUNCTION_ABS - 6;
+      else if (type > AST_FUNCTION_RATE_OF && type <= AST_LOGICAL_IMPLIES)
+        index = type - AST_FUNCTION_ABS - 7;
+        
+      const char* name = MATHML_FUNCTIONS[index];
+      writeStartEndElement(name, node, stream);
       //stream.startEndElement(name);
     }
 
@@ -1557,7 +1681,7 @@ writeOperator (const ASTNode& node, XMLOutputStream& stream, SBMLNamespaces *sbm
     case AST_DIVIDE:  writeStartEndElement( "divide", node, stream );  break;
     case AST_POWER :  writeStartEndElement( "power" , node, stream );  break;
 
-	//case AST_PLUS  :  stream.startEndElement( "plus"   );  break;
+  //case AST_PLUS  :  stream.startEndElement( "plus"   );  break;
     //case AST_TIMES :  stream.startEndElement( "times"  );  break;
     //case AST_MINUS :  stream.startEndElement( "minus"  );  break;
     //case AST_DIVIDE:  stream.startEndElement( "divide" );  break;
@@ -1739,6 +1863,17 @@ readMathML (XMLInputStream& stream, std::string reqd_prefix, bool inRead)
         logError(stream, stream.peek(), BadMathMLNodeType, message);      
     }
 
+    // we may have a legitimate read but the next token is not the end of math
+    // we want to tell the user but allow the astnode as-is
+    stream.skipText();
+    const XMLToken element1 = stream.peek();
+    const string&  name = element1.getName();
+    if (element1.isEndFor(elem) == false && !stream.getErrorLog()->contains(BadMathML))
+    {
+      std::string message = "Unexpected element encountered. The element <" +
+        name + "> should not be encountered here.";
+      logError(stream, elem, InvalidMathElement, message);
+    }
     stream.skipPastEnd(elem);
   }
   else if (name == "apply" )
@@ -1772,15 +1907,22 @@ writeMathML (const ASTNode* node, XMLOutputStream& stream, SBMLNamespaces *sbmln
 
   if (node) 
   {
-	// FIX-ME need to know what level and version
-	if (node->hasUnits())
-	{
-    if (sbmlns == NULL || sbmlns->getLevel() == 3)
-		stream.writeAttribute(XMLTriple("sbml", "", "xmlns"), 
-		                   SBMLNamespaces::getSBMLNamespaceURI(3,1));
-	}
-	
-	writeNode(*node, stream,sbmlns);
+  // FIX-ME need to know what level and version
+  if (node->hasUnits())
+  {
+    unsigned int level = SBML_DEFAULT_LEVEL;
+    unsigned int version = SBML_DEFAULT_VERSION;
+    if (sbmlns != NULL)
+    {
+      level = sbmlns->getLevel();
+      version = sbmlns->getVersion();
+    }
+    
+    stream.writeAttribute(XMLTriple("sbml", "", "xmlns"), 
+      SBMLNamespaces::getSBMLNamespaceURI(level, version));
+  }
+  
+  writeNode(*node, stream,sbmlns);
   }
 
   stream.endElement("math");
@@ -1815,7 +1957,69 @@ readMathMLFromString (const char *xml)
   else
   {
     std::ostringstream oss;
-    const char* dummy_xml = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>";
+
+    oss << dummy_xml;
+    oss << xml;
+
+
+    xmlstr_c = safe_strdup(oss.str().c_str());
+    needDelete = true;
+  }
+
+  XMLInputStream stream(xmlstr_c, false);
+  SBMLErrorLog   log;
+
+  stream.setErrorLog(&log);
+  //SBMLNamespaces sbmlns;
+  //stream.setSBMLNamespaces(&sbmlns);
+
+  ASTNode_t* ast = readMathML(stream);
+  
+  if (needDelete == true)
+  {
+    safe_free((void *)(xmlstr_c));
+  }
+
+  // we only used to log really invalid math errors
+  // but now we might log errors about number of 
+  // children of piece and otherwise (since this the read
+  // is the only place
+  // but dont need to bail for these
+  if (log.getNumErrors() > 0)
+  {
+    if (!log.contains(10218))
+    {
+      delete ast;
+      return NULL;
+    }
+  }
+
+  return ast;
+}
+
+/**
+ * @if conly
+ * @memberof ASTNode_t
+ * @endif
+ */
+LIBSBML_EXTERN
+ASTNode_t *
+readMathMLFromStringWithNamespaces (const char *xml, XMLNamespaces_t * xmlns)
+{
+  if (xml == NULL) return NULL;
+
+  bool needDelete = false;
+
+  const char* dummy_xml = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>";
+  const char* xmlstr_c;
+  
+  if (!strncmp(xml, dummy_xml, 14))
+  {
+    xmlstr_c = xml;
+  }
+  else
+  {
+    std::ostringstream oss;
 
     oss << dummy_xml;
     oss << xml;
@@ -1830,6 +2034,10 @@ readMathMLFromString (const char *xml)
 
   stream.setErrorLog(&log);
   SBMLNamespaces sbmlns;
+  if (xmlns != NULL)
+  {
+    sbmlns.addNamespaces(xmlns);
+  }
   stream.setSBMLNamespaces(&sbmlns);
 
   ASTNode_t* ast = readMathML(stream);
@@ -1864,32 +2072,55 @@ readMathMLFromString (const char *xml)
  */
 LIBSBML_EXTERN
 char *
-writeMathMLToString (const ASTNode* node)
+writeMathMLWithNamespaceToString(const ASTNode_t* node, SBMLNamespaces_t* sbmlns)
 {
   ostringstream   os;
   XMLOutputStream stream(os);
 
   char * result = NULL;
 
-  if (node != NULL)
+  if (node != NULL && sbmlns != NULL)
   {
-    writeMathML(node, stream);
+    writeMathML(node, stream, sbmlns);
     result = safe_strdup( os.str().c_str() );
   }
 
   return result;
 }
 
+/**
+ * @if conly
+ * @memberof ASTNode_t
+ * @endif
+ */
+LIBSBML_EXTERN
+char *
+writeMathMLToString (const ASTNode* node)
+{
+  SBMLNamespaces sbmlns;
+  return writeMathMLWithNamespaceToString(node, &sbmlns);
+}
+
 LIBSBML_EXTERN
 std::string
 writeMathMLToStdString (const ASTNode* node)
 {
+  SBMLNamespaces sbmlns;
+  return writeMathMLToStdString(node, &sbmlns);
+}
+
+LIBSBML_EXTERN
+std::string
+writeMathMLToStdString(const ASTNode* node, SBMLNamespaces* sbmlns)
+{
+  if (node == NULL || sbmlns == NULL) return "";
+
   ostringstream   os;
   XMLOutputStream stream(os);
 
-  if (node != NULL)
+  if (node != NULL && sbmlns != NULL)
   {
-    writeMathML(node, stream);
+    writeMathML(node, stream, sbmlns);
     return os.str();
   }
   else
