@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -49,6 +49,7 @@ LIBSBML_CPP_NAMESPACE_BEGIN
 static const char* URL_TIME  = "http://www.sbml.org/sbml/symbols/time";
 static const char* URL_DELAY = "http://www.sbml.org/sbml/symbols/delay";
 static const char* URL_AVOGADRO = "http://www.sbml.org/sbml/symbols/avogadro";
+static const char* URL_RATE_OF = "http://www.sbml.org/sbml/symbols/rateOf";
 
 
 ASTCSymbol::ASTCSymbol (int type) :
@@ -56,6 +57,7 @@ ASTCSymbol::ASTCSymbol (int type) :
   , mTime      ( NULL )
   , mDelay     ( NULL )
   , mAvogadro  ( NULL )
+  , mRateOf    ( NULL )
   , mIsOther   ( false )
   , mCalcNumChildren ( 0 )
   , mInReadFromApply ( false)
@@ -74,6 +76,10 @@ ASTCSymbol::ASTCSymbol (int type) :
       mAvogadro = new ASTCSymbolAvogadroNode(type);
       this->ASTBase::syncPluginsFrom(mAvogadro);
       break;
+    case AST_FUNCTION_RATE_OF:
+      mRateOf = new ASTCSymbolRateOfNode(type);
+      this->ASTBase::syncPluginsFrom(mRateOf);
+      break;
     default:
       break;
   }
@@ -86,14 +92,12 @@ ASTCSymbol::ASTCSymbol (int type) :
   
 
  
-  /**
-   * Copy constructor
-   */
 ASTCSymbol::ASTCSymbol (const ASTCSymbol& orig):
     ASTBase (orig)
   , mTime      ( NULL )
   , mDelay     ( NULL )
   , mAvogadro  ( NULL )
+  , mRateOf    ( NULL )
   , mIsOther        ( orig.mIsOther )
   , mCalcNumChildren ( orig.mCalcNumChildren )
   , mInReadFromApply ( orig.mInReadFromApply)
@@ -115,10 +119,14 @@ ASTCSymbol::ASTCSymbol (const ASTCSymbol& orig):
     mAvogadro = static_cast<ASTCSymbolAvogadroNode*>
                                 ( orig.mAvogadro->deepCopy() );
   }
+  if ( orig.mRateOf  != NULL)
+  {
+    mRateOf = static_cast<ASTCSymbolRateOfNode*>
+                                ( orig.mRateOf->deepCopy() );
+  }
+
 }
-  /**
-   * Assignment operator for ASTNode.
-   */
+
 ASTCSymbol&
 ASTCSymbol::operator=(const ASTCSymbol& rhs)
 {
@@ -163,17 +171,27 @@ ASTCSymbol::operator=(const ASTCSymbol& rhs)
       mAvogadro = NULL;
     }
 
+    delete mRateOf;
+    if ( rhs.mRateOf  != NULL)
+    {
+      mRateOf = static_cast<ASTCSymbolRateOfNode*>
+                                  ( rhs.mRateOf->deepCopy() );
+    }
+    else
+    {
+      mRateOf = NULL;
+    }
+
   }
   return *this;
 }
-  /**
-   * Destroys this ASTNode, including any child nodes.
-   */
+
 ASTCSymbol::~ASTCSymbol ()
 {
   if (mTime  != NULL) delete mTime;
   if (mDelay  != NULL) delete mDelay;
   if (mAvogadro  != NULL) delete mAvogadro;
+  if (mRateOf  != NULL) delete mRateOf;
 }
 
 int
@@ -204,6 +222,10 @@ ASTCSymbol::addChild(ASTBase * child)
   {
     return mDelay->addChild(child);
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->addChild(child);
+  }
   else
   {
     return LIBSBML_INVALID_OBJECT;
@@ -222,6 +244,10 @@ ASTCSymbol::swapChildren(ASTFunction * that)
   {
     return mDelay->swapChildren(that);
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->swapChildren(that);
+  }
   else
   {
     return LIBSBML_INVALID_OBJECT;
@@ -241,6 +267,10 @@ ASTCSymbol::insertChild(unsigned int n, ASTBase* newChild)
   {
     return mDelay->insertChild(n, newChild);
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->insertChild(n, newChild);
+  }
   else
   {
     return LIBSBML_INVALID_OBJECT;
@@ -260,6 +290,10 @@ ASTCSymbol::prependChild(ASTBase * newChild)
   {
     return mDelay->prependChild(newChild);
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->prependChild(newChild);
+  }
   else
   {
     return LIBSBML_INVALID_OBJECT;
@@ -274,6 +308,10 @@ ASTCSymbol::removeChild(unsigned int n)
   {
     return mDelay->removeChild(n);
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->removeChild(n);
+  }
   else
   {
     return LIBSBML_INVALID_OBJECT;
@@ -293,6 +331,10 @@ ASTCSymbol::replaceChild(unsigned int n, ASTBase* newChild, bool delreplaced)
   {
     return mDelay->replaceChild(n, newChild, delreplaced);
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->replaceChild(n, newChild, delreplaced);
+  }
   else
   {
     return LIBSBML_INVALID_OBJECT;
@@ -307,6 +349,10 @@ ASTCSymbol::getChild (unsigned int n) const
   {
     return mDelay->getChild(n);
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->getChild(n);
+  }
   else
   {
     return NULL;
@@ -320,6 +366,10 @@ ASTCSymbol::getNumChildren() const
   {
     return mDelay->getNumChildren();
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->getNumChildren();
+  }
   else
   {
     return 0;
@@ -344,6 +394,10 @@ ASTCSymbol::setIsChildFlag(bool flag)
   {
     mAvogadro->ASTBase::setIsChildFlag(flag);
   }
+  else if (mRateOf != NULL)
+  {
+    mRateOf->ASTBase::setIsChildFlag(flag);
+  }
 }
 
 
@@ -366,6 +420,10 @@ ASTCSymbol::setClass(std::string className)
     {
       success =  mAvogadro->ASTBase::setClass(className);
     }
+    else if (mRateOf != NULL)
+    {
+      success =  mRateOf->ASTBase::setClass(className);
+    }
   }
 
   return success;
@@ -391,6 +449,10 @@ ASTCSymbol::setId(std::string id)
     {
       success =  mAvogadro->ASTBase::setId(id);
     }
+    else if (mRateOf != NULL)
+    {
+      success =  mRateOf->ASTBase::setId(id);
+    }
   }
 
   return success;
@@ -416,6 +478,10 @@ ASTCSymbol::setStyle(std::string style)
     {
       success =  mAvogadro->ASTBase::setStyle(style);
     }
+    else if (mRateOf != NULL)
+    {
+      success =  mRateOf->ASTBase::setStyle(style);
+    }
   }
 
   return success;
@@ -437,6 +503,10 @@ ASTCSymbol::setParentSBMLObject(SBase* sb)
     {
       success =  mDelay->ASTBase::setParentSBMLObject(sb);
     }
+    else if (mRateOf != NULL)
+    {
+      success =  mRateOf->ASTBase::setParentSBMLObject(sb);
+    }
     else if (mAvogadro != NULL)
     {
       success =  mAvogadro->ASTBase::setParentSBMLObject(sb);
@@ -466,6 +536,10 @@ ASTCSymbol::setUserData(void* userData)
     {
       success =  mAvogadro->ASTBase::setUserData(userData);
     }
+    else if (mRateOf != NULL)
+    {
+      success =  mRateOf->ASTBase::setUserData(userData);
+    }
   }
 
   return success;
@@ -491,6 +565,10 @@ ASTCSymbol::unsetClass()
     {
       success =  mAvogadro->ASTBase::unsetClass();
     }
+    else if (mRateOf != NULL)
+    {
+      success =  mRateOf->ASTBase::unsetClass();
+    }
   }
 
   return success;
@@ -516,6 +594,10 @@ ASTCSymbol::unsetId()
     {
       success =  mAvogadro->ASTBase::unsetId();
     }
+    else if (mRateOf != NULL)
+    {
+      success =  mRateOf->ASTBase::unsetId();
+    }
   }
 
   return success;
@@ -541,6 +623,10 @@ ASTCSymbol::unsetStyle()
     {
       success =  mAvogadro->ASTBase::unsetStyle();
     }
+    else if (mRateOf != NULL)
+    {
+      success =  mRateOf->ASTBase::unsetStyle();
+    }
   }
 
   return success;
@@ -566,6 +652,10 @@ ASTCSymbol::unsetParentSBMLObject()
     {
       success =  mAvogadro->ASTBase::unsetParentSBMLObject();
     }
+    else if (mRateOf != NULL)
+    {
+      success =  mRateOf->ASTBase::unsetParentSBMLObject();
+    }
   }
 
   return success;
@@ -591,6 +681,10 @@ ASTCSymbol::unsetUserData()
     {
       success =  mAvogadro->ASTBase::unsetUserData();
     }
+    else if (mRateOf != NULL)
+    {
+      success =  mRateOf->ASTBase::unsetUserData();
+    }
   }
 
   return success;
@@ -612,6 +706,10 @@ ASTCSymbol::isSetClass() const
   {
     return mAvogadro->ASTBase::isSetClass();
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->ASTBase::isSetClass();
+  }
   else
   {
     return ASTBase::isSetClass();
@@ -634,6 +732,10 @@ ASTCSymbol::isSetId() const
   {
     return mAvogadro->ASTBase::isSetId();
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->ASTBase::isSetId();
+  }
   else
   {
     return ASTBase::isSetId();
@@ -656,6 +758,10 @@ ASTCSymbol::isSetStyle() const
   {
     return mAvogadro->ASTBase::isSetStyle();
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->ASTBase::isSetStyle();
+  }
   else
   {
     return ASTBase::isSetStyle();
@@ -678,6 +784,10 @@ ASTCSymbol::isSetParentSBMLObject() const
   {
     return mAvogadro->ASTBase::isSetParentSBMLObject();
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->ASTBase::isSetParentSBMLObject();
+  }
   else
   {
     return ASTBase::isSetParentSBMLObject();
@@ -700,6 +810,10 @@ ASTCSymbol::isSetUserData() const
   {
     return mAvogadro->ASTBase::isSetUserData();
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->ASTBase::isSetUserData();
+  }
   else
   {
     return ASTBase::isSetUserData();
@@ -722,6 +836,10 @@ ASTCSymbol::getClass() const
   {
     return mAvogadro->ASTBase::getClass();
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->ASTBase::getClass();
+  }
   else
   {
     return ASTBase::getClass();
@@ -744,6 +862,10 @@ ASTCSymbol::getId() const
   {
     return mAvogadro->ASTBase::getId();
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->ASTBase::getId();
+  }
   else
   {
     return ASTBase::getId();
@@ -766,6 +888,10 @@ ASTCSymbol::getStyle() const
   {
     return mAvogadro->ASTBase::getStyle();
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->ASTBase::getStyle();
+  }
   else
   {
     return ASTBase::getStyle();
@@ -788,6 +914,10 @@ ASTCSymbol::getParentSBMLObject() const
   {
     return mAvogadro->ASTBase::getParentSBMLObject();
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->ASTBase::getParentSBMLObject();
+  }
   else
   {
     return ASTBase::getParentSBMLObject();
@@ -810,6 +940,10 @@ ASTCSymbol::getUserData() const
   {
     return mAvogadro->ASTBase::getUserData();
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->ASTBase::getUserData();
+  }
   else
   {
     return ASTBase::getUserData();
@@ -867,6 +1001,10 @@ ASTCSymbol::getName() const
   {
     return mDelay->getName();
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->getName();
+  }
   else if (mAvogadro != NULL)
   {
     return mAvogadro->getName();
@@ -893,6 +1031,10 @@ ASTCSymbol::isSetName() const
   {
     return mAvogadro->isSetName();
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->isSetName();
+  }
   else
   {
     return false;
@@ -915,6 +1057,10 @@ ASTCSymbol::setName(const std::string& name)
   {
     return mAvogadro->setName(name);
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->setName(name);
+  }
   else
   {
     return LIBSBML_INVALID_OBJECT;
@@ -937,6 +1083,10 @@ ASTCSymbol::unsetName()
   {
     return mAvogadro->unsetName();
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->unsetName();
+  }
   else
   {
     return LIBSBML_INVALID_OBJECT;
@@ -972,6 +1122,13 @@ ASTCSymbol::isAvogadro() const
 }
 
 
+bool
+ASTCSymbol::isRateOf() const
+{
+  return (mRateOf != NULL);
+}
+
+
 int 
 ASTCSymbol::setDefinitionURL(const std::string& url)
 {
@@ -987,6 +1144,10 @@ ASTCSymbol::setDefinitionURL(const std::string& url)
   {
     return mAvogadro->setDefinitionURL(url);
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->setDefinitionURL(url);
+  }
   else
   {
     return LIBSBML_INVALID_OBJECT;
@@ -1005,6 +1166,10 @@ ASTCSymbol::setEncoding(const std::string& encoding)
   {
     return mDelay->setEncoding(encoding);
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->setEncoding(encoding);
+  }
   else if (mAvogadro != NULL)
   {
     return mAvogadro->setEncoding(encoding);
@@ -1032,6 +1197,10 @@ ASTCSymbol::getDefinitionURL() const
   {
     return mAvogadro->getDefinitionURL();
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->getDefinitionURL();
+  }
   else
   {
     return emptyString;
@@ -1051,6 +1220,10 @@ ASTCSymbol::getEncoding() const
   {
     return mDelay->getEncoding();
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->getEncoding();
+  }
   else if (mAvogadro != NULL)
   {
     return mAvogadro->getEncoding();
@@ -1074,6 +1247,10 @@ ASTCSymbol::isSetDefinitionURL() const
   {
     return mDelay->isSetDefinitionURL();
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->isSetDefinitionURL();
+  }
   else if (mAvogadro != NULL)
   {
     return mAvogadro->isSetDefinitionURL();
@@ -1101,6 +1278,10 @@ ASTCSymbol::isSetEncoding() const
   {
     return mAvogadro->isSetEncoding();
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->isSetEncoding();
+  }
   else
   {
     return success;
@@ -1137,6 +1318,10 @@ ASTCSymbol::getPlugin(const std::string& package)
   {
     return mAvogadro->getPlugin(package);
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->getPlugin(package);
+  }
   else
   {
     return getPlugin(package);
@@ -1166,6 +1351,10 @@ ASTCSymbol::getPlugin(unsigned int n)
   {
     return mAvogadro->getPlugin(n);
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->getPlugin(n);
+  }
   else
   {
     return getPlugin(n);
@@ -1195,6 +1384,10 @@ ASTCSymbol::isWellFormedNode() const
   {
     return mAvogadro->isWellFormedNode();
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->isWellFormedNode();
+  }
   else
   {
     return ASTBase::isWellFormedNode();
@@ -1213,6 +1406,10 @@ ASTCSymbol::hasCorrectNumberArguments() const
   {
     return mDelay->hasCorrectNumberArguments();
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->hasCorrectNumberArguments();
+  }
   else if (mAvogadro != NULL)
   {
     return mAvogadro->hasCorrectNumberArguments();
@@ -1239,6 +1436,10 @@ ASTCSymbol::getMember() const
   {
     return mAvogadro;
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf;
+  }
   else
   {
     return NULL;
@@ -1253,6 +1454,10 @@ ASTCSymbol::hasCnUnits() const
   {
     return mDelay->hasCnUnits();
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->hasCnUnits();
+  }
   else
   {
     return false;
@@ -1268,6 +1473,10 @@ ASTCSymbol::getUnitsPrefix() const
   {
     return mDelay->getUnitsPrefix();
   }
+  else if (mRateOf != NULL)
+  {
+    return mRateOf->getUnitsPrefix();
+  }
   else
   {
     return ASTBase::getUnitsPrefix();
@@ -1289,6 +1498,16 @@ ASTCSymbol::write(XMLOutputStream& stream) const
   {
     mTime->write(stream);
   }
+  else if (mRateOf != NULL)
+  {
+    // actually for any other csymbol we write it whether it was valid or not
+    //if (stream.getSBMLNamespaces() != NULL
+    //  && stream.getSBMLNamespaces()->getLevel() == 3
+    //  && stream.getSBMLNamespaces()->getVersion() > 1)
+    //{
+      mRateOf->write(stream);
+    //}
+  }
   else if (mIsOther == true)
   {
     // FIX ME
@@ -1383,6 +1602,46 @@ ASTCSymbol::read(XMLInputStream& stream, const std::string& reqd_prefix)
         this->ASTBase::syncMembersAndResetParentsFrom(mTime);
       }
     }
+    else if (url == URL_RATE_OF)
+    {
+      bool allowed = true;
+      if (stream.getSBMLNamespaces() != NULL)
+      {
+        unsigned int level = stream.getSBMLNamespaces()->getLevel();
+        unsigned int vers = stream.getSBMLNamespaces()->getVersion();
+        if (level == 2)
+        {
+          allowed = false;
+        }
+        else if (level == 3 && vers == 1)
+        {
+          allowed = false;
+        }
+      }
+      if (!allowed)
+      {
+        logError(stream, element, BadCsymbolDefinitionURLValue, "The <csymbol> definitionURL '" 
+          + url +"' is not allowed for this level and version of SBML.");
+      }
+
+      mRateOf = new ASTCSymbolRateOfNode();
+      mRateOf->setExpectedNumChildren(getExpectedNumChildren());
+      read = mRateOf->read(stream, reqd_prefix);
+      if (read == true && mRateOf != NULL)
+      {
+        if (!allowed) 
+        {
+        std::string newname = mRateOf->getName();
+        mRateOf->setType(AST_FUNCTION);
+        mRateOf->setName(newname);
+        this->ASTBase::syncMembersAndResetParentsFrom(mRateOf);
+        }
+        else
+        {
+          this->ASTBase::syncMembersAndResetParentsFrom(mRateOf);
+        }
+      }
+    }
     else
     {
       /* HACK TO REPLICATE OLD AST */
@@ -1410,13 +1669,25 @@ ASTCSymbol::read(XMLInputStream& stream, const std::string& reqd_prefix)
         if (read == true && mDelay != NULL)
         {
           std::string name1 = mDelay->getName();
-          mDelay->setType(AST_FUNCTION);
+          if (stream.getSBMLNamespaces() == NULL)
+          {
+            mDelay->setType(AST_CSYMBOL_FUNCTION);
+          }
+          else
+          {
+            mDelay->setType(AST_FUNCTION);
+          }
           mDelay->setName(name1);
           this->ASTBase::syncMembersAndResetParentsFrom(mDelay);
         }
       }
-      logError(stream, element, BadCsymbolDefinitionURLValue, "The <csymbol> definitionURL '" 
-          + url +"' is not allowed for this level and version of SBML.");      
+
+      if (stream.getSBMLNamespaces() != NULL)
+      {
+        // only log error if we are using sbml
+        logError(stream, element, BadCsymbolDefinitionURLValue, "The <csymbol> definitionURL '"
+          + url + "' is not allowed for this level and version of SBML.");
+      }
     }
   }
 
@@ -1459,6 +1730,13 @@ ASTCSymbol::getAvogadro() const
 }
 
 
+ASTCSymbolRateOfNode * 
+ASTCSymbol::getRateOf() const
+{ 
+  return mRateOf; 
+}
+
+
 void
 ASTCSymbol::syncMembersAndTypeFrom(ASTNumber* rhs, int type)
 {
@@ -1494,6 +1772,16 @@ ASTCSymbol::syncMembersAndTypeFrom(ASTNumber* rhs, int type)
     }
     this->ASTBase::syncMembersFrom(mAvogadro);
   }
+  else if (mRateOf != NULL)
+  {
+    mRateOf->ASTBase::syncMembersAndResetParentsFrom(rhs->getMember());
+    mRateOf->setType(type);
+    if (rhs->isSetName() == true)
+    {
+      mRateOf->setName(rhs->getName());
+    }
+    this->ASTBase::syncMembersFrom(mRateOf);
+  }
   else if (mIsOther == true)
   {
   }
@@ -1536,6 +1824,16 @@ ASTCSymbol::syncMembersAndTypeFrom(ASTFunction* rhs, int type)
     }
     this->ASTBase::syncMembersFrom(mAvogadro);
   }
+  else if (mRateOf != NULL)
+  {
+    mRateOf->ASTBase::syncMembersAndResetParentsFrom(rhs->getMember());
+    mRateOf->setType(type);
+    if (rhs->isSetName() == true)
+    {
+      mRateOf->setName(rhs->getName());
+    }
+    this->ASTBase::syncMembersFrom(mRateOf);
+  }
   else if (mIsOther == true)
   {
   }
