@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -266,6 +266,7 @@ ASTNode::ASTNode (int type) :
   else
   {
     bool found = false;
+    if (getNumPlugins() == 0) loadASTPlugins(NULL);
     for (unsigned int i = 0; i < ASTBase::getNumPlugins(); i++)
     {
       if (found == false 
@@ -411,9 +412,6 @@ ASTBase()
 /** @endcond */
 
 
-/*
-   * Copy constructor
-   */
 ASTNode::ASTNode (const ASTNode& orig) :
         ASTBase(orig)
       , mNumber  ( NULL )
@@ -445,10 +443,6 @@ ASTNode::ASTNode (const ASTNode& orig) :
 }
 
 
-/*
- * 
-   * Assignment operator for ASTNode.
-   */
 ASTNode&
 ASTNode::operator=(const ASTNode& rhs)
 {
@@ -1306,6 +1300,7 @@ ASTNode::setType (int type)
   else
   {
     bool found = false;
+    if (getNumPlugins() == 0) loadASTPlugins(NULL);
     for (unsigned int i = 0; i < ASTBase::getNumPlugins(); i++)
     {
       if (found == false)
@@ -1881,6 +1876,52 @@ ASTNode::freeName()
 }
 
 
+/** @cond doxygenLibsbmlInternal */
+bool
+ASTNode::usesL3V2MathConstructs() const
+{
+  bool mathConstructs = false;
+
+  int type = getType();
+  if (type == AST_FUNCTION_RATE_OF ||
+      type == AST_FUNCTION_MIN ||
+      type == AST_FUNCTION_MAX ||
+      type == AST_FUNCTION_REM ||
+      type == AST_FUNCTION_QUOTIENT ||
+      type == AST_LOGICAL_IMPLIES)
+      mathConstructs = true;
+  unsigned int i = 0;
+  while (!mathConstructs && i < getNumChildren())
+  {
+    mathConstructs = getChild(i)->usesL3V2MathConstructs();
+    i++;
+  }
+
+  return mathConstructs;
+}
+/** @endcond */
+
+
+/** @cond doxygenLibsbmlInternal */
+bool
+ASTNode::usesRateOf() const
+{
+  bool mathConstructs = false;
+
+  if (getType() == AST_FUNCTION_RATE_OF)
+      mathConstructs = true;
+  unsigned int i = 0;
+  while (!mathConstructs && i < getNumChildren())
+  {
+    mathConstructs = getChild(i)->usesRateOf();
+    i++;
+  }
+
+  return mathConstructs;
+}
+/** @endcond */
+
+
 /** @cond doxygenLibsbmlInternal */
 bool
 ASTNode::hasCnUnits() const
@@ -2032,6 +2073,24 @@ ASTNode::isConstant() const
 }
 
 
+bool 
+ASTNode::isConstantNumber() const
+{
+  bool valid = false;
+  
+  if (mNumber != NULL)
+  {
+    valid = mNumber->isConstantNumber();
+  }
+  else if (mFunction != NULL)
+  {
+    valid = false;
+  }
+
+  return valid;
+}
+
+
 bool 
 ASTNode::isFunction() const
 {
@@ -2439,7 +2498,10 @@ ASTNode::returnsBoolean (const Model* givenModel /*=NULL*/) const
 
       if (fd != NULL && fd->isSetMath())
       {
-        return fd->getMath()->getRightChild()->returnsBoolean();
+        // when getting the function from a FD need to use getBody();
+//        return fd->getMath()->getRightChild()->returnsBoolean();
+        return (fd->getBody() != NULL ?
+          fd->getBody()->returnsBoolean() : false);
       }
       else
       {
@@ -2767,6 +2829,8 @@ ASTNode::read(XMLInputStream& stream, const std::string& reqd_prefix)
   const string&  name = element.getName();
   if (name == "math")
   {
+    // for attributes we should have the namespace here 
+    
     ASTBase::checkPrefix(stream, reqd_prefix, element);
 
     const XMLToken elem = stream.next();
@@ -2777,8 +2841,26 @@ ASTNode::read(XMLInputStream& stream, const std::string& reqd_prefix)
       return read;
     }
 
+    // for attributes we should have the namespace here 
     stream.skipText();
+ //   ASTBase::loadASTPlugins(NULL);
     read = ASTNode::read(stream, reqd_prefix);
+    // we may have a legitimate read but the next token is not the end of math
+    // we want to tell the user but allow the astnode as-is
+    if (read && !(stream.getErrorLog()->contains(BadMathML)))
+    {
+      stream.skipText();
+      const XMLToken element1 = stream.peek();
+      const string&  newname = element1.getName();
+      if (element1.isEndFor(element) == false)
+      {
+        std::string message = "Unexpected element encountered. The element <" +
+          newname + "> should not be encountered here.";
+        logError(stream, element, InvalidMathElement, message);
+        stream.skipPastEnd(element);
+      }
+
+    }
   }
   else if (isTopLevelMathMLNumberNodeTag(name) == true)
   {
@@ -2873,6 +2955,7 @@ ASTNode::fillListOfNodes(ASTNodePredicate predicate, List* lst) const
   for (c = 0; c < numChildren; c++)
   {
     child = getChild(c);
+    if (child == NULL) continue;
     child->fillListOfNodes(predicate, lst);
   }
 }
@@ -3388,6 +3471,7 @@ ASTNode::unsetUserData()
 ASTBasePlugin* 
 ASTNode::getPlugin(const std::string& package)
 {
+
   if (mNumber != NULL)
   {
     return mNumber->getPlugin(package);
@@ -3433,6 +3517,24 @@ const ASTBasePlugin*
   return const_cast<ASTNode*>(this)->getPlugin(n);
 }
 
+unsigned int
+ASTNode::getNumPlugins() const
+{
+  if (mNumber != NULL)
+  {
+    return mNumber->getNumPlugins();
+  }
+  else if (mFunction != NULL)
+  {
+    return mFunction->getNumPlugins();
+  }
+  else
+  {
+    return ASTBase::getNumPlugins();
+  }
+}
+
+
 unsigned int
 ASTNode::getNumPiece() const
 {
@@ -3701,12 +3803,14 @@ ASTNode::reset()
 {
   if (mNumber != NULL)
   {
+    this->syncMembersOnlyFrom(mNumber);
     delete mNumber;
     mNumber = NULL;
   }
 
   if (mFunction != NULL)
   {
+    this->syncMembersOnlyFrom(mFunction);
     delete mFunction;
     mFunction = NULL;
   }
@@ -3807,7 +3911,7 @@ LIBSBML_EXTERN
 int
 ASTNode_addChild (ASTNode_t *node, ASTNode_t *child)
 {
-	if (node == NULL) return LIBSBML_INVALID_OBJECT;
+  if (node == NULL) return LIBSBML_INVALID_OBJECT;
   return static_cast<ASTNode*>(node)->addChild
                                     ( static_cast<ASTNode*>(child) );
 }
@@ -4075,6 +4179,15 @@ ASTNode_isConstant (const ASTNode_t *node)
 }
 
 
+LIBSBML_EXTERN
+int
+ASTNode_isConstantNumber(const ASTNode_t *node)
+{
+  if (node == NULL) return (int)false;
+  return (int) static_cast<const ASTNode*>(node)->isConstantNumber();
+}
+
+
 LIBSBML_EXTERN
 int
 ASTNode_isFunction (const ASTNode_t *node)
