@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -43,14 +43,8 @@ using namespace std;
 
 /* end doxygen comment */
 
-#if defined(_MSC_VER) || defined(__BORLANDC__)
-#  define isnan(d)  _isnan(d)
-#endif
-
 LIBSBML_CPP_NAMESPACE_BEGIN
 
-
-
 ASTNumber::ASTNumber (int type) :
    ASTBase   (type)
   , mExponential    ( NULL )
@@ -100,13 +94,15 @@ ASTNumber::ASTNumber (int type) :
     default:
       break;
   }
+
+  for (unsigned int i = 0; i < getNumPlugins(); i++)
+  {
+    ASTBase::getPlugin(i)->connectToParent(this);
+  }
 }
   
 
  
-  /**
-   * Copy constructor
-   */
 ASTNumber::ASTNumber (const ASTNumber& orig):
     ASTBase (orig)
       , mExponential    ( NULL )
@@ -154,9 +150,7 @@ ASTNumber::ASTNumber (const ASTNumber& orig):
                                 ( orig.mCSymbol->deepCopy() );
   }
 }
-  /**
-   * Assignment operator for ASTNode.
-   */
+
 ASTNumber&
 ASTNumber::operator=(const ASTNumber& rhs)
 {
@@ -540,6 +534,42 @@ ASTNumber::setUserData(void* userData)
 }
 
 
+void 
+ASTNumber::setIsChildFlag(bool flag)
+{
+  ASTBase::setIsChildFlag(flag);
+
+  if (mExponential != NULL)
+  {
+    mExponential->setIsChildFlag(flag);
+  }
+  else if (mInteger != NULL)
+  {
+    mInteger->setIsChildFlag(flag);
+  }
+  else if (mRational != NULL)
+  {
+    mRational->setIsChildFlag(flag);
+  }
+  else if (mReal != NULL)
+  {
+    mReal->setIsChildFlag(flag);
+  }
+  else if (mCiNumber != NULL)
+  {
+    mCiNumber->setIsChildFlag(flag);
+  }
+  else if (mConstant != NULL)
+  {
+    mConstant->setIsChildFlag(flag);
+  }
+  else if (mCSymbol != NULL)
+  {
+    mCSymbol->setIsChildFlag(flag);
+  }
+}
+
+
 int 
 ASTNumber::unsetClass()
 {
@@ -1688,7 +1718,7 @@ ASTNumber::setValue(double value, long value1)
 int 
 ASTNumber::setValue(double value)
 {
-  if (mExponential == NULL && mReal == NULL)
+  if (mExponential == NULL && mReal == NULL && !(util_isNaN(value) > 0 || util_isInf(value) != 0))
   {
     std::string units = ASTNumber::getUnits();
     reset();
@@ -1697,7 +1727,7 @@ ASTNumber::setValue(double value)
     setType(AST_REAL);
     mReal->ASTBase::syncMembersFrom(this);
   }
-  else if (isnan(value) > 0 || util_isInf(value) != 0)
+  else if ((util_isNaN(value) > 0 || util_isInf(value) != 0) && mConstant == NULL) 
   {
     reset();
     mConstant = new ASTConstantNumberNode(AST_REAL);
@@ -1790,7 +1820,7 @@ ASTNumber::getValue() const
   }
   else
   {
-    return 0;//util_NaN();
+    return ASTBase::getValue();
   }
 
 }
@@ -2415,6 +2445,133 @@ ASTNumber::hasCorrectNumberArguments() const
   }
 }
 
+ASTBasePlugin* 
+ASTNumber::getPlugin(const std::string& package)
+{
+  if (mExponential != NULL)
+  {
+    return mExponential->getPlugin(package);
+  }
+  else if (mInteger != NULL)
+  {
+    return mInteger->getPlugin(package);
+  }
+  else if (mRational != NULL)
+  {
+    return mRational->getPlugin(package);
+  }
+  else if (mReal != NULL)
+  {
+    return mReal->getPlugin(package);
+  }
+  else if (mCiNumber != NULL)
+  {
+    return mCiNumber->getPlugin(package);
+  }
+  else if (mConstant != NULL)
+  {
+    return mConstant->getPlugin(package);
+  }
+  else if (mCSymbol != NULL)
+  {
+    return mCSymbol->getPlugin(package);
+  }
+  else
+  {
+    return ASTBase::getPlugin(package);
+  }
+}
+
+
+const ASTBasePlugin* 
+ASTNumber::getPlugin(const std::string& package) const
+{
+  return const_cast<ASTNumber*>(this)->getPlugin(package);
+}
+
+
+ASTBasePlugin* 
+ASTNumber::getPlugin(unsigned int n)
+{
+  if (mExponential != NULL)
+  {
+    return mExponential->getPlugin(n);
+  }
+  else if (mInteger != NULL)
+  {
+    return mInteger->getPlugin(n);
+  }
+  else if (mRational != NULL)
+  {
+    return mRational->getPlugin(n);
+  }
+  else if (mReal != NULL)
+  {
+    return mReal->getPlugin(n);
+  }
+  else if (mCiNumber != NULL)
+  {
+    return mCiNumber->getPlugin(n);
+  }
+  else if (mConstant != NULL)
+  {
+    return mConstant->getPlugin(n);
+  }
+  else if (mCSymbol != NULL)
+  {
+    return mCSymbol->getPlugin(n);
+  }
+  else
+  {
+    return ASTBase::getPlugin(n);
+  }
+}
+
+
+const ASTBasePlugin* 
+ASTNumber::getPlugin(unsigned int n) const
+{
+  return const_cast<ASTNumber*>(this)->getPlugin(n);
+}
+
+
+unsigned int
+ASTNumber::getNumPlugins() const
+{
+  if (mExponential != NULL)
+  {
+    return mExponential->getNumPlugins();
+  }
+  else if (mInteger != NULL)
+  {
+    return mInteger->getNumPlugins();
+  }
+  else if (mRational != NULL)
+  {
+    return mRational->getNumPlugins();
+  }
+  else if (mReal != NULL)
+  {
+    return mReal->getNumPlugins();
+  }
+  else if (mCiNumber != NULL)
+  {
+    return mCiNumber->getNumPlugins();
+  }
+  else if (mConstant != NULL)
+  {
+    return mConstant->getNumPlugins();
+  }
+  else if (mCSymbol != NULL)
+  {
+    return mCSymbol->getNumPlugins();
+  }
+  else
+  {
+    return ASTBase::getNumPlugins();
+  }
+}
+
 
 void 
 ASTNumber::write(XMLOutputStream& stream) const
@@ -2465,7 +2622,9 @@ ASTNumber::read(XMLInputStream& stream, const std::string& reqd_prefix)
 
   if (isTopLevelMathMLNumberNodeTag(name) == false)
   {
+#if 0
     cout << "[DEBUG] Number::read\nBAD THINGS ARE HAPPENING\n\n";
+#endif
   }
   
   if (name == "cn")
@@ -2510,7 +2669,8 @@ ASTNumber::read(XMLInputStream& stream, const std::string& reqd_prefix)
     }
     else
     {
-      logError(stream, element, DisallowedMathTypeAttributeValue);      
+      logError(stream, element, DisallowedMathTypeAttributeValue, "The <cn> type '" 
+          + type +"' is not allowed for this level and version of SBML."); 
       //for (unsigned int i = 0; i < getNumPlugins(); i++)
       //{
       //  read = getPlugin(i)->read(stream, reqd_prefix);
@@ -2536,7 +2696,16 @@ ASTNumber::read(XMLInputStream& stream, const std::string& reqd_prefix)
     || name == "pi" || name == "exponentiale"
     || name == "notanumber" || name == "infinity")
   {
-    mConstant = new ASTConstantNumberNode();
+    if (name == "true")  
+      mConstant = new ASTConstantNumberNode(AST_CONSTANT_TRUE);
+    else if (name == "false")  
+      mConstant = new ASTConstantNumberNode(AST_CONSTANT_FALSE);
+    else if (name == "pi")  
+      mConstant = new ASTConstantNumberNode(AST_CONSTANT_PI);
+    else if (name == "exponentiale")  
+      mConstant = new ASTConstantNumberNode(AST_CONSTANT_E);
+    else  
+      mConstant = new ASTConstantNumberNode();
     read = mConstant->read(stream, reqd_prefix);
     if (read == true && mConstant != NULL)
     {
@@ -2557,12 +2726,57 @@ ASTNumber::read(XMLInputStream& stream, const std::string& reqd_prefix)
   return read;
 }
 
+
+ASTBase*
+ASTNumber::getMember() const
+{
+  if (mInteger != NULL)
+  {
+    return mInteger;
+  }
+  else if (mRational != NULL)
+  {
+    return mRational;
+  }
+  else if (mReal != NULL)
+  {
+    return mReal;
+  }
+  else if (mExponential != NULL)
+  {
+    return mExponential;
+  }
+  else if (mCiNumber != NULL)
+  {
+    return mCiNumber;
+  }
+  else if (mConstant != NULL)
+  {
+    return mConstant;
+  }
+  else if (mCSymbol != NULL)
+  {
+    return mCSymbol;
+  }
+  else if (mIsOther == true)
+  {
+    return NULL;
+    // FIX ME
+    //getPlugin("qual")->getMath()->write(stream);
+  }
+  else
+  {
+    return NULL;
+  }
+}
+
+
 void
 ASTNumber::syncMembersAndTypeFrom(ASTNumber* rhs, int type)
 {
   if (mInteger != NULL)
   {
-    mInteger->ASTBase::syncMembersAndResetParentsFrom(rhs);
+    mInteger->ASTBase::syncMembersAndResetParentsFrom(rhs->getMember());
     mInteger->setType(type);
     if (rhs->isSetUnits() == true)
     {
@@ -2577,7 +2791,7 @@ ASTNumber::syncMembersAndTypeFrom(ASTNumber* rhs, int type)
   }
   else if (mRational != NULL)
   {
-    mRational->ASTBase::syncMembersAndResetParentsFrom(rhs);
+    mRational->ASTBase::syncMembersAndResetParentsFrom(rhs->getMember());
     mRational->setType(type);
     if (rhs->isSetUnits() == true)
     {
@@ -2596,7 +2810,7 @@ ASTNumber::syncMembersAndTypeFrom(ASTNumber* rhs, int type)
   }
   else if (mReal != NULL)
   {
-    mReal->ASTBase::syncMembersAndResetParentsFrom(rhs);
+    mReal->ASTBase::syncMembersAndResetParentsFrom(rhs->getMember());
     mReal->setType(type);
     if (rhs->isSetUnits() == true)
     {
@@ -2607,11 +2821,17 @@ ASTNumber::syncMembersAndTypeFrom(ASTNumber* rhs, int type)
     {
       mReal->setReal(rhs->getValue());
     }
-    this->ASTBase::syncMembersFrom(mReal);
+    
+    if (rhs->isSetConstantValue())
+    {
+      setValue(rhs->getValue());
+    }
+    else
+      this->ASTBase::syncMembersFrom(mReal);
   }
   else if (mExponential != NULL)
   {
-    mExponential->ASTBase::syncMembersAndResetParentsFrom(rhs);
+    mExponential->ASTBase::syncMembersAndResetParentsFrom(rhs->getMember());
     mExponential->setType(type);
     if (rhs->isSetUnits() == true)
     {
@@ -2630,7 +2850,7 @@ ASTNumber::syncMembersAndTypeFrom(ASTNumber* rhs, int type)
   }
   else if (mCiNumber != NULL)
   {
-    mCiNumber->ASTBase::syncMembersAndResetParentsFrom(rhs);
+    mCiNumber->ASTBase::syncMembersAndResetParentsFrom(rhs->getMember());
     mCiNumber->setType(type);
     if (rhs->isSetName() == true)
     {
@@ -2644,17 +2864,9 @@ ASTNumber::syncMembersAndTypeFrom(ASTNumber* rhs, int type)
   }
   else if (mConstant != NULL)
   {
-    mConstant->ASTBase::syncMembersAndResetParentsFrom(rhs);
+    mConstant->ASTBase::syncMembersAndResetParentsFrom(rhs->getMember());
     mConstant->setType(type);
-    if (rhs->isSetConstantValue() == true)
-    {
-      mConstant->setValue(rhs->getValue());
-    }
-    if (rhs->isSetUnits() == true)
-    {
-      mExponential->setUnits(rhs->getUnits());
-      mExponential->setUnitsPrefix(rhs->getUnitsPrefix());
-    }
+    //}
     this->ASTBase::syncMembersFrom(mConstant);
   }
   else if (mCSymbol != NULL)
@@ -2674,31 +2886,31 @@ ASTNumber::syncMembersAndTypeFrom(ASTFunction* rhs, int type)
 {
   if (mInteger != NULL)
   {
-    mInteger->ASTBase::syncMembersAndResetParentsFrom(rhs);
+    mInteger->ASTBase::syncMembersAndResetParentsFrom(rhs->getMember());
     mInteger->setType(type);
     this->ASTBase::syncMembersFrom(mInteger);
   }
   else if (mRational != NULL)
   {
-    mRational->ASTBase::syncMembersAndResetParentsFrom(rhs);
+    mRational->ASTBase::syncMembersAndResetParentsFrom(rhs->getMember());
     mRational->setType(type);
     this->ASTBase::syncMembersFrom(mRational);
   }
   else if (mReal != NULL)
   {
-    mReal->ASTBase::syncMembersAndResetParentsFrom(rhs);
+    mReal->ASTBase::syncMembersAndResetParentsFrom(rhs->getMember());
     mReal->setType(type);
     this->ASTBase::syncMembersFrom(mReal);
   }
   else if (mExponential != NULL)
   {
-    mExponential->ASTBase::syncMembersAndResetParentsFrom(rhs);
+    mExponential->ASTBase::syncMembersAndResetParentsFrom(rhs->getMember());
     mExponential->setType(type);
     this->ASTBase::syncMembersFrom(mExponential);
   }
   else if (mCiNumber != NULL)
   {
-    mCiNumber->ASTBase::syncMembersAndResetParentsFrom(rhs);
+    mCiNumber->ASTBase::syncMembersAndResetParentsFrom(rhs->getMember());
     mCiNumber->setType(type);
     if (rhs->isSetDefinitionURL() == true)
     {
@@ -2708,7 +2920,7 @@ ASTNumber::syncMembersAndTypeFrom(ASTFunction* rhs, int type)
   }
   else if (mConstant != NULL)
   {
-    mConstant->ASTBase::syncMembersAndResetParentsFrom(rhs);
+    mConstant->ASTBase::syncMembersAndResetParentsFrom(rhs->getMember());
     mConstant->setType(type);
     this->ASTBase::syncMembersFrom(mConstant);
   }
@@ -2729,42 +2941,49 @@ ASTNumber::reset()
 {
   if (mExponential != NULL)
   {
+    this->syncMembersOnlyFrom(mExponential);
     delete mExponential;
     mExponential = NULL;
   }
 
   if (mInteger != NULL)
   {
+    this->syncMembersOnlyFrom(mInteger);
     delete mInteger;
     mInteger = NULL;
   }
 
   if (mRational != NULL)
   {
+    this->syncMembersOnlyFrom(mRational);
     delete mRational;
     mRational = NULL;
   }
 
   if (mReal != NULL)
   {
+    this->syncMembersOnlyFrom(mReal);
     delete mReal;
     mReal = NULL;
   }
 
   if (mCiNumber != NULL)
   {
+    this->syncMembersOnlyFrom(mCiNumber);
     delete mCiNumber;
     mCiNumber = NULL;
   }
 
   if (mConstant != NULL)
   {
+    this->syncMembersOnlyFrom(mConstant);
     delete mConstant;
     mConstant = NULL;
   }
 
   if (mCSymbol != NULL)
   {
+    this->syncMembersOnlyFrom(mCSymbol);
     delete mCSymbol;
     mCSymbol = NULL;
   }
@@ -2775,7 +2994,5 @@ ASTNumber::reset()
 
 
 LIBSBML_CPP_NAMESPACE_END
-
-
 /** @endcond */
 
