@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -36,8 +36,14 @@
 #include <sbml/math/FormulaParser.h>
 #include <sbml/math/ASTTypes.h>
 
+#ifdef _MSC_VER
+#pragma warning( disable: 4311)
+#pragma warning( disable: 4312)
+#endif
 
 /** @cond doxygenLibsbmlInternal */
+
+
 /**
  * The FormulaParser is a Simple Left-to-right Rightmost-derivation (SLR)
  * shift-reduce parser.
@@ -292,6 +298,8 @@ static const StateActionPair_t Action[] =
   {20,  -4},  /* TT_END:    150 */
   {24, -11},  /* TT_END:    151 */
 };
+
+
 /** @endcond */
 
 
@@ -382,6 +390,7 @@ SBML_parseFormula (const char *formula)
 
 
 /** @cond doxygenLibsbmlInternal */
+
 /**
  * @return the action for the current state and token.
  *
@@ -726,4 +735,6 @@ FormulaParser_reduceStackByRule (Stack_t *stack, long rule)
 
   return result;
 }
+
+
 /** @endcond */
