@@ -12,7 +12,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -305,8 +305,8 @@ int getL3Precedence(const ASTNode_t* node)
 
 
 /**
- * @return true (non-zero) if the given child ASTNode should be grouped
- * (with parenthesis), false (0) otherwise.
+ * @return @c 1 (true) if the given child ASTNode should be grouped
+ * (with parenthesis), @c 0 (false) otherwise.
  *
  * A node should be group if it is not an argument to a function and
  * either:
@@ -485,7 +485,9 @@ L3FormulaFormatter_formatFunction (StringBuffer_t *sb, const ASTNode_t *node, co
   case AST_FUNCTION_DELAY:
     StringBuffer_append(sb, "delay");
     break;
-
+  case AST_FUNCTION_RATE_OF:
+    StringBuffer_append(sb, "rateOf");
+    break;
   default:
     FormulaFormatter_formatFunction(sb, node);
     break;
@@ -578,8 +580,8 @@ L3FormulaFormatter_formatReal (StringBuffer_t *sb, const ASTNode_t *node, const
   {
     if (ASTNode_getType(node) == AST_REAL_E)
     {
-      StringBuffer_appendExp(sb, value);
-    }
+	    StringBuffer_appendFullExp(sb, ASTNode_getMantissa(node), ASTNode_getExponent(node), value);
+	  }
     else
     {
       StringBuffer_appendReal(sb, value);
@@ -1050,6 +1052,13 @@ L3FormulaFormatter_isFunction (const ASTNode_t *node,
   case AST_FUNCTION_SINH:
   case AST_FUNCTION_TAN:
   case AST_FUNCTION_TANH:
+  case AST_FUNCTION_MAX:
+  case AST_FUNCTION_MIN:
+  case AST_FUNCTION_QUOTIENT:
+  case AST_FUNCTION_RATE_OF:
+  case AST_FUNCTION_REM:
+  case AST_LOGICAL_IMPLIES:
+      case AST_CSYMBOL_FUNCTION:
   case AST_UNKNOWN:
     return 1;
 
@@ -1061,5 +1070,7 @@ L3FormulaFormatter_isFunction (const ASTNode_t *node,
   assert(0);
   return 1;
 }
+
+
 /** @endcond */
 
