@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -307,48 +307,64 @@ readMathMLFromStringWithNamespaces (const char *xml, XMLNamespaces_t * xmlns)
 
 
 /**
- * @if conly
- * @memberof ASTNode_t
- * @endif
- */
+* @if conly
+* @memberof ASTNode_t
+* @endif
+*/
 LIBSBML_EXTERN
 char *
-writeMathMLToString (const ASTNode* node)
+writeMathMLWithNamespaceToString(const ASTNode_t* node, SBMLNamespaces_t* sbmlns)
 {
   ostringstream   os;
   XMLOutputStream stream(os);
-  SBMLNamespaces sbmlns;
-  //stream.setSBMLNamespaces(&sbmlns);
 
   char * result = NULL;
 
-  if (node != NULL)
-  { 
-    MathML* mathml = new MathML(&sbmlns);
+  if (node != NULL && sbmlns != NULL)
+  {
+    MathML* mathml = new MathML(sbmlns);
     mathml->writeMathML(stream, node);
 
-    result = safe_strdup( os.str().c_str() );
+    result = safe_strdup(os.str().c_str());
     delete mathml;
   }
 
   return result;
 }
 
+LIBSBML_EXTERN
+char *
+writeMathMLToString (const ASTNode* node)
+{
+  SBMLNamespaces sbmlns;
+  return writeMathMLWithNamespaceToString(node, &sbmlns);
+}
+
 LIBSBML_EXTERN
 std::string
 writeMathMLToStdString (const ASTNode* node)
 {
-  if (node == NULL) return "";
-  
+  SBMLNamespaces sbmlns;
+  return writeMathMLToStdString(node, &sbmlns);
+}
+
+LIBSBML_EXTERN
+std::string
+writeMathMLToStdString(const ASTNode* node, SBMLNamespaces* sbmlns)
+{
+  if (node == NULL || sbmlns == NULL) return "";
+
   ostringstream   os;
   XMLOutputStream stream(os);
-  SBMLNamespaces sbmlns;
-  MathML* mathml = new MathML(&sbmlns);
+  MathML* mathml = new MathML(sbmlns);
   mathml->writeMathML(stream, node);
   delete mathml;
 
   return os.str();
+
 }
+
+
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END
