@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -50,7 +50,7 @@ LIBSBML_CPP_NAMESPACE_USE
 #define XML_HEADER     "<?xml version='1.0' encoding='UTF-8'?>\n"
 #define MATHML_HEADER  "<math xmlns='http://www.w3.org/1998/Math/MathML'>\n"
 #define MATHML_HEADER_UNITS  "<math xmlns='http://www.w3.org/1998/Math/MathML'\n"
-#define MATHML_HEADER_UNITS2  " xmlns:sbml='http://www.sbml.org/sbml/level3/version1/core'>\n"
+#define MATHML_HEADER_UNITS2  " xmlns:sbml='http://www.sbml.org/sbml/level3/version2/core'>\n"
 #define MATHML_FOOTER  "</math>"
 
 #define wrapXML(s)     XML_HEADER s
@@ -387,6 +387,135 @@ START_TEST (test_element_csymbol_delay_5)
 END_TEST
 
 
+START_TEST (test_element_csymbol_rateof_1)
+{
+  const char* s = wrapMathML
+  (
+    "<csymbol encoding='text' "
+    "definitionURL='http://www.sbml.org/sbml/symbols/rateOf'> rateOf </csymbol>"
+  );
+
+
+  N = readMathMLFromString(s);
+
+  fail_unless( N != NULL );
+
+  fail_unless( N->getType() == AST_FUNCTION_RATE_OF );
+  fail_unless( !strcmp(N->getName(), "rateOf") );
+  fail_unless( N->getNumChildren() == 0       );
+}
+END_TEST
+
+
+START_TEST (test_element_csymbol_rateof_2)
+{
+  const char* s = wrapMathML
+  (
+    "<apply>"
+    "  <csymbol encoding='text' definitionURL='http://www.sbml.org/sbml/"
+    "symbols/rateOf'> my_delay </csymbol>"
+    "  <ci> x </ci>"
+    "  <cn> 0.1 </cn>"
+    "</apply>\n"
+  );
+
+
+
+  N = readMathMLFromString(s);
+  fail_unless( N->getType() == AST_FUNCTION_RATE_OF);
+  fail_unless( !strcmp(N->getName(), "my_delay"));
+  fail_unless( N->getNumChildren() == 2);
+
+  fail_unless( N != NULL );
+
+  //F = SBML_formulaToString(N);
+  //fail_unless( !strcmp(F, "my_delay(x, 0.1)") );
+}
+END_TEST
+
+
+START_TEST (test_element_csymbol_rateof_3)
+{
+  const char* s = wrapMathML
+  (
+    "<apply>"
+    "  <power/>"
+    "  <apply>"
+    "    <csymbol encoding='text' definitionURL='http://www.sbml.org/sbml/"
+    "symbols/rateOf'> delay </csymbol>"
+    "    <ci> P </ci>"
+    "  </apply>\n"
+    "  <ci> q </ci>"
+    "</apply>\n"
+  );
+
+
+
+  N = readMathMLFromString(s);
+
+  fail_unless( N != NULL );
+
+  //F = SBML_formulaToString(N);
+  //fail_unless( !strcmp(F, "pow(delay(P, delta_t), q)") );
+}
+END_TEST
+
+
+START_TEST (test_element_csymbol_rateof_4)
+{
+  const char* s = wrapMathML
+  (
+    "<apply>"
+    "  <csymbol encoding='text' style='d' definitionURL='http://www.sbml.org/sbml/"
+    "symbols/rateOf'> my_delay </csymbol>"
+    "  <ci> x </ci>"
+    "  <cn> 0.1 </cn>"
+    "</apply>\n"
+  );
+
+
+
+  N = readMathMLFromString(s);
+
+  fail_unless( N != NULL );
+  fail_unless( N->getType() == AST_FUNCTION_RATE_OF);
+  fail_unless( !strcmp(N->getName(), "my_delay"));
+  fail_unless( N->getNumChildren() == 2);
+  fail_unless( N->getStyle() == "d");
+
+  //F = SBML_formulaToString(N);
+  //fail_unless( !strcmp(F, "my_delay(x, 0.1)") );
+}
+END_TEST
+
+
+START_TEST (test_element_csymbol_rateof_5)
+{
+  const char* s = wrapMathML
+  (
+    "<apply>"
+    "  <csymbol encoding='text' style='d' definitionURL='http://www.sbml.org/sbml/"
+    "symbols/rateOf'> my_delay </csymbol>"
+    "  <ci> x </ci>"
+    "</apply>\n"
+  );
+
+
+
+  N = readMathMLFromString(s);
+
+  fail_unless( N != NULL );
+  fail_unless( N->getType() == AST_FUNCTION_RATE_OF);
+  fail_unless( !strcmp(N->getName(), "my_delay"));
+  fail_unless( N->getNumChildren() == 1);
+  fail_unless( N->getStyle() == "d");
+
+  //F = SBML_formulaToString(N);
+  //fail_unless( !strcmp(F, "my_delay(x, 0.1)") );
+}
+END_TEST
+
+
 START_TEST (test_element_constants_true)
 {
   const char* s = wrapMathML("<true/>");
@@ -1982,6 +2111,101 @@ START_TEST (test_element_xor)
 END_TEST
 
 
+START_TEST (test_element_max)
+{
+  const char* s = wrapMathML
+  (
+    "<apply> <max/> <ci>a</ci> <ci>b</ci> </apply>"
+  );
+
+
+  N = readMathMLFromString(s);
+
+  fail_unless( N != NULL );
+
+  //F =SBML_formulaToString(N);
+
+  //fail_unless( !strcmp(F, "max(a, b)") );
+}
+END_TEST
+
+
+START_TEST (test_element_min)
+{
+  const char* s = wrapMathML
+  (
+    "<apply> <min/> <ci>a</ci> <ci>b</ci> </apply>"
+  );
+
+
+  N = readMathMLFromString(s);
+
+  fail_unless( N != NULL );
+
+  //F =SBML_formulaToString(N);
+
+  //fail_unless( !strcmp(F, "min(a, b)") );
+}
+END_TEST
+
+
+START_TEST (test_element_quotient)
+{
+  const char* s = wrapMathML
+  (
+    "<apply> <quotient/> <ci>a</ci> <ci>b</ci> </apply>"
+  );
+
+
+  N = readMathMLFromString(s);
+
+  fail_unless( N != NULL );
+
+  //F =SBML_formulaToString(N);
+
+  //fail_unless( !strcmp(F, "quotient(a, b)") );
+}
+END_TEST
+
+
+START_TEST (test_element_rem)
+{
+  const char* s = wrapMathML
+  (
+    "<apply> <rem/> <ci>a</ci> <ci>b</ci> </apply>"
+  );
+
+
+  N = readMathMLFromString(s);
+
+  fail_unless( N != NULL );
+
+  //F =SBML_formulaToString(N);
+
+  //fail_unless( !strcmp(F, "rem(a, b)") );
+}
+END_TEST
+
+
+START_TEST (test_element_implies)
+{
+  const char* s = wrapMathML
+  (
+    "<apply> <implies/> <ci>a</ci> <ci>b</ci> <ci>b</ci> <ci>a</ci> </apply>"
+  );
+
+
+  N = readMathMLFromString(s);
+
+  fail_unless( N != NULL );
+
+  //F =SBML_formulaToString(N);
+
+  //fail_unless( !strcmp(F, "implies(a, b, b, a)") );
+}
+END_TEST
+
+
 START_TEST (test_element_semantics)
 {
   const char* s = wrapMathML
@@ -2908,6 +3132,12 @@ create_suite_NewReadMathML ()
   tcase_add_test( tcase, test_element_csymbol_delay_4           );
   tcase_add_test( tcase, test_element_csymbol_delay_5           );
 
+  tcase_add_test( tcase, test_element_csymbol_rateof_1           );
+  tcase_add_test( tcase, test_element_csymbol_rateof_2           );
+  tcase_add_test( tcase, test_element_csymbol_rateof_3           );
+  tcase_add_test( tcase, test_element_csymbol_rateof_4           );
+  tcase_add_test( tcase, test_element_csymbol_rateof_5           );
+
   tcase_add_test( tcase, test_element_constants_true            );
   tcase_add_test( tcase, test_element_constants_false           );
   tcase_add_test( tcase, test_element_constants_notanumber      );
@@ -2986,6 +3216,12 @@ create_suite_NewReadMathML ()
   tcase_add_test( tcase, test_element_tanh                      );
   tcase_add_test( tcase, test_element_xor                       );
 
+  tcase_add_test( tcase, test_element_max                       );
+  tcase_add_test( tcase, test_element_min                       );
+  tcase_add_test( tcase, test_element_quotient                  );
+  tcase_add_test( tcase, test_element_rem                       );
+  tcase_add_test( tcase, test_element_implies                   );
+
   tcase_add_test( tcase, test_element_semantics                 );
   tcase_add_test( tcase, test_element_semantics_URL             );
   tcase_add_test( tcase, test_element_semantics_annotation      );
