@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -44,6 +44,25 @@
 #include <check.h>
 
 LIBSBML_CPP_NAMESPACE_USE
+#define XML_HEADER    "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
+#define MATHML_HEADER "<math xmlns=\"http://www.w3.org/1998/Math/MathML\">\n"
+#define MATHML_FOOTER "</math>"
+
+#define wrapMathML(s)   XML_HEADER MATHML_HEADER s MATHML_FOOTER
+
+
+
+static bool
+equals(const char* expected, const char* actual)
+{
+  if (!strcmp(expected, actual)) return true;
+
+  printf("\nStrings are not equal:\n");
+  printf("Expected:\n[%s]\n", expected);
+  printf("Actual:\n[%s]\n", actual);
+
+  return false;
+}
 
 BEGIN_C_DECLS
 
@@ -140,9 +159,11 @@ START_TEST (test_read_MathML_1)
   ASTNode *child1 = fd1_math->getRightChild();
   fail_unless (child1->getType() == AST_CONSTANT_TRUE, NULL);
   fail_unless (child1->getNumChildren() == 0, NULL);
+
   math = SBML_formulaToString(child1);
   fail_unless (!strcmp(math, "true"), NULL);
   safe_free(math);
+
   //fail_unless( child1->containsVariable("c") == false );
   //fail_unless( child1->containsVariable("x") == false );
 
@@ -228,6 +249,39 @@ START_TEST (test_read_MathML_1)
 }
 END_TEST
 
+START_TEST(test_read_MathML_fromStream)
+{
+  const char* expected = wrapMathML
+    (
+      "  <apply>\n"
+      "    <divide/>\n"
+      "    <ci> LacIbNormalized </ci>\n"
+      "    <apply>\n"
+      "      <csymbol encoding=\"text\" definitionURL=\"http://sed-ml.org/#max\"> max </csymbol>\n"
+      "      <ci> LacIbNormalized </ci>\n"
+      "    </apply>\n"
+      "  </apply>\n"
+      );
+  std::string filename(TestDataDirectory);
+  filename += "non_sbml_symbol.xml";
+
+  XMLErrorLog log;
+  XMLInputStream stream(filename.c_str(), true, "", &log);
+  fail_unless(stream.getSBMLNamespaces() == NULL);
+  ASTNode* node = readMathML(stream);
+
+  std::string result = writeMathMLToStdString(node);
+
+  fail_unless(node != NULL);
+  fail_unless(log.getNumErrors() == 0);
+
+  fail_unless(equals(expected, result.c_str()));
+
+  
+  delete node;
+
+}
+END_TEST
 
 Suite *
 create_suite_TestReadFromFile1 (void)
@@ -237,6 +291,7 @@ create_suite_TestReadFromFile1 (void)
 
 
   tcase_add_test(tcase, test_read_MathML_1);
+  tcase_add_test(tcase, test_read_MathML_fromStream);
 
   suite_add_tcase(suite, tcase);
 
