@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -59,8 +59,8 @@ LIBSBML_CPP_NAMESPACE_USE
 #define XML_HEADER    "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n"
 #define MATHML_HEADER "<math xmlns=\"http://www.w3.org/1998/Math/MathML\">\n"
 #define MATHML_HEADER_UNITS  "<math xmlns=\"http://www.w3.org/1998/Math/MathML\""
-#define MATHML_HEADER_UNITS2  " xmlns:sbml=\"http://www.sbml.org/sbml/level3/version1/core\">\n"
-#define MATHML_HEADER_UNITS_ALT  " xmlns:foo=\"http://www.sbml.org/sbml/level3/version1/core\">\n"
+#define MATHML_HEADER_UNITS2  " xmlns:sbml=\"http://www.sbml.org/sbml/level3/version2/core\">\n"
+#define MATHML_HEADER_UNITS_ALT  " xmlns:foo=\"http://www.sbml.org/sbml/level3/version2/core\">\n"
 #define MATHML_FOOTER "</math>"
 
 #define wrapMathML(s)   XML_HEADER MATHML_HEADER s MATHML_FOOTER
@@ -325,6 +325,27 @@ START_TEST (test_MathMLFormatter_csymbol_delay)
 END_TEST
 
 
+START_TEST (test_MathMLFormatter_csymbol_rateof)
+{
+  //const char* expected = wrapMathML
+  //(
+  //  "  <apply>\n"
+  //  "    <csymbol encoding=\"text\" definitionURL=\"http://www.sbml.org/sbml/"
+  //  "symbols/rateOf\"> my_rateof </csymbol>\n"
+  //  "    <ci> x </ci>\n"
+  //  "  </apply>\n"
+  //);
+
+  //N = SBML_parseFormula("rateof(x)");
+  //N->setName("my_rateof");
+
+  //S = writeMathMLToString(N);
+
+  //fail_unless( equals(expected, S) );
+}
+END_TEST
+
+
 START_TEST (test_MathMLFormatter_csymbol_time)
 {
   const char* expected = wrapMathML
@@ -397,6 +418,7 @@ END_TEST
 
 START_TEST (test_MathMLFormatter_constant_infinity_neg)
 {
+#ifndef LIBSBML_USE_LEGACY_MATH
   const char* expected = wrapMathML
   (
     "  <apply>\n"
@@ -404,6 +426,12 @@ START_TEST (test_MathMLFormatter_constant_infinity_neg)
     "    <infinity/>\n"
     "  </apply>\n"
   );
+#else
+  const char* expected = wrapMathML
+  (
+    "  <apply> <minus/> <infinity/> </apply>\n"
+  );
+#endif
 
   N = new ASTNode;
   N->setValue( - numeric_limits<double>::infinity() );
@@ -975,7 +1003,12 @@ END_TEST
 
 START_TEST (test_MathMLFormatter_apply_cn_units)
 {
-  const char *expected = wrapMathMLUnits("  <apply>\n    <divide/>\n    <cn sbml:units=\"mole\" type=\"integer\"> 3 </cn>\n    <cn sbml:units=\"dimensionless\" type=\"integer\"> 4 </cn>\n  </apply>\n");
+  const char *expected = wrapMathMLUnits(
+    "  <apply>\n"
+    "    <divide/>\n"
+    "    <cn sbml:units=\"mole\" type=\"integer\"> 3 </cn>\n"
+    "    <cn sbml:units=\"dimensionless\" type=\"integer\"> 4 </cn>\n"
+    "  </apply>\n");
 
   N = SBML_parseL3Formula("3 mole / 4 dimensionless");
   //N->setUnits("mole");
@@ -990,7 +1023,12 @@ END_TEST
 
 START_TEST (test_MathMLFormatter_apply_cn_units_old)
 {
-  const char *expected = wrapMathMLUnits("  <apply>\n    <divide/>\n    <cn sbml:units=\"mole\" type=\"integer\"> 3 </cn>\n    <cn sbml:units=\"dimensionless\" type=\"integer\"> 4 </cn>\n  </apply>\n");
+  const char *expected = wrapMathMLUnits(
+    "  <apply>\n"
+    "    <divide/>\n"
+    "    <cn sbml:units=\"mole\" type=\"integer\"> 3 </cn>\n"
+    "    <cn sbml:units=\"dimensionless\" type=\"integer\"> 4 </cn>\n"
+    "  </apply>\n");
 
   N = SBML_parseFormula("3 / 4");
   N->getChild(0)->setUnits("mole");
@@ -1107,6 +1145,7 @@ create_suite_WriteMathML ()
 
   tcase_add_test( tcase, test_MathMLFormatter_ci                    );
   tcase_add_test( tcase, test_MathMLFormatter_csymbol_delay         );
+  tcase_add_test( tcase, test_MathMLFormatter_csymbol_rateof        );
   tcase_add_test( tcase, test_MathMLFormatter_csymbol_time          );
   tcase_add_test( tcase, test_MathMLFormatter_constant_true         );
   tcase_add_test( tcase, test_MathMLFormatter_constant_false        );
