@@ -8,7 +8,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -1329,7 +1329,7 @@ void ArraysASTPlugin::visitPackageInfixSyntax ( const ASTNode *parent,
 
 int ArraysASTPlugin::checkNumArguments(const ASTNode* function, std::stringstream& error) const
 {
-  if (function->getType() != AST_ORIGINATES_IN_PACKAGE) return 0;
+  if (function->ASTBase::getType() != AST_ORIGINATES_IN_PACKAGE) return 0;
   if (function->getPackageName() != "arrays") return 0;
   const ArraysASTPlugin* aap = static_cast<const ArraysASTPlugin*>(function->getPlugin("arrays"));
   string product = "";
