@@ -762,10 +762,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 Index_t *
-Index_create(unsigned int level = ArraysExtension::getDefaultLevel(),
-             unsigned int version = ArraysExtension::getDefaultVersion(),
-             unsigned int pkgVersion =
-               ArraysExtension::getDefaultPackageVersion());
+Index_create(unsigned int level,
+             unsigned int version,
+             unsigned int pkgVersion);
 
 
 /**
