@@ -8,7 +8,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -222,6 +222,13 @@ CompModelPlugin::getListOfSubmodels () const
 }
 
 
+ListOfSubmodels*
+CompModelPlugin::getListOfSubmodels()
+{
+  return &mListOfSubmodels;
+}
+
+
 Submodel*
 CompModelPlugin::removeSubmodel(unsigned int index)
 {
@@ -308,10 +315,20 @@ CompModelPlugin::createSubmodel ()
 
 
 /*
- * Returns the listofports object that holds all ports.
- */ 
+ * Returns the ListOfPorts from this CompModelPlugin.
+ */
 const ListOfPorts*
-CompModelPlugin::getListOfPorts () const
+CompModelPlugin::getListOfPorts() const
+{
+  return &mListOfPorts;
+}
+
+
+/*
+ * Returns the ListOfPorts from this CompModelPlugin.
+ */
+ListOfPorts*
+CompModelPlugin::getListOfPorts()
 {
   return &mListOfPorts;
 }
@@ -1106,7 +1123,7 @@ void CompModelPlugin::renameIDs(List* allElements, const string& prefix)
   for (unsigned long el=0; el < allElements->getSize(); ++el) 
   {
     SBase* element = static_cast<SBase*>(allElements->get((unsigned int)el));
-    string id = element->getId();
+    string id = element->getIdAttribute();
     string metaid = element->getMetaId();
     
     // if a custom prefix transformer was specified, use it, other wise
@@ -1119,7 +1136,7 @@ void CompModelPlugin::renameIDs(List* allElements, const string& prefix)
     if (element->getTypeCode() == SBML_LOCAL_PARAMETER) {
       element->setId(id); //Change it back.  This would perhaps be better served by overriding 'prependStringToAllIdentifiers' but hey.
     }
-    string newid = element->getId();
+    string newid = element->getIdAttribute();
     string newmetaid = element->getMetaId();
     if (id != newid) {
       int type = element->getTypeCode();
@@ -1318,6 +1335,7 @@ int CompModelPlugin::performReplacementsAndConversions()
 }
 /** @endcond */
 
+/** @cond doxygenLibsbmlInternal */
 int CompModelPlugin::removeCollectedElements(set<SBase*>* removed, set<SBase*>* toremove)
 {
   while (toremove->size() > 0) {
@@ -1336,6 +1354,7 @@ int CompModelPlugin::removeCollectedElements(set<SBase*>* removed, set<SBase*>*
   }
   return LIBSBML_OPERATION_SUCCESS;
 }
+/** @endcond */
 
   
 /** @cond doxygenLibsbmlInternal */
@@ -1396,15 +1415,167 @@ CompModelPlugin::getRemovedSet()
 /** @endcond */
 
 #endif /* __cplusplus */
-/** @cond doxygenIgnored */
+
+
+/*
+ * Creates a new Submodel_t object, adds it to this CompModelPlugin_t object
+ * and returns the Submodel_t object created.
+ */
 LIBSBML_EXTERN
-Submodel_t *
-CompModelPlugin_createSubmodel(CompModelPlugin_t * modelPlug)
+Submodel_t*
+CompModelPlugin_createSubmodel(CompModelPlugin_t* cmp)
 {
-  return modelPlug->createSubmodel();
+  return (cmp != NULL) ? cmp->createSubmodel() : NULL;
 }
-/** @endcond */
+
+
+/*
+ * Returns a ListOf_t * containing Submodel_t objects from this
+ * CompModelPlugin_t.
+ */
+LIBSBML_EXTERN
+ListOf_t*
+CompModelPlugin_getListOfSubmodels(CompModelPlugin_t* cmp)
+{
+  return (cmp != NULL) ? cmp->getListOfSubmodels() : NULL;
+}
+
+
+/*
+ * Get a Submodel_t from the CompModelPlugin_t.
+ */
+LIBSBML_EXTERN
+Submodel_t*
+CompModelPlugin_getSubmodel(CompModelPlugin_t* cmp, unsigned int n)
+{
+  return (cmp != NULL) ? cmp->getSubmodel(n) : NULL;
+}
+
+
+/*
+ * Get a Submodel_t from the CompModelPlugin_t based on its identifier.
+ */
+LIBSBML_EXTERN
+Submodel_t*
+CompModelPlugin_getSubmodelById(CompModelPlugin_t* cmp, const char *sid)
+{
+  return (cmp != NULL && sid != NULL) ? cmp->getSubmodel(sid) : NULL;
+}
+
+
+/*
+ * Adds a copy of the given Submodel_t to this CompModelPlugin_t.
+ */
+LIBSBML_EXTERN
+int
+CompModelPlugin_addSubmodel(CompModelPlugin_t* cmp, const Submodel_t* s)
+{
+  return (cmp != NULL) ? cmp->addSubmodel(s) : LIBSBML_INVALID_OBJECT;
+}
+
+
+/*
+ * Get the number of Submodel_t objects in this CompModelPlugin_t.
+ */
+LIBSBML_EXTERN
+unsigned int
+CompModelPlugin_getNumSubmodels(CompModelPlugin_t* cmp)
+{
+  return (cmp != NULL) ? cmp->getNumSubmodels() : SBML_INT_MAX;
+}
+
+
+/*
+ * Removes the nth Submodel_t from this CompModelPlugin_t and returns a pointer
+ * to it.
+ */
+LIBSBML_EXTERN
+Submodel_t*
+CompModelPlugin_removeSubmodel(CompModelPlugin_t* cmp, unsigned int n)
+{
+  return (cmp != NULL) ? cmp->removeSubmodel(n) : NULL;
+}
+
+
+/*
+ * Returns a ListOf_t * containing Port_t objects from this CompModelPlugin_t.
+ */
+LIBSBML_EXTERN
+ListOf_t*
+CompModelPlugin_getListOfPorts(CompModelPlugin_t* cmp)
+{
+  return (cmp != NULL) ? cmp->getListOfPorts() : NULL;
+}
+
+
+/*
+ * Get a Port_t from the CompModelPlugin_t.
+ */
+LIBSBML_EXTERN
+Port_t*
+CompModelPlugin_getPort(CompModelPlugin_t* cmp, unsigned int n)
+{
+  return (cmp != NULL) ? cmp->getPort(n) : NULL;
+}
+
+
+/*
+ * Get a Port_t from the CompModelPlugin_t based on its identifier.
+ */
+LIBSBML_EXTERN
+Port_t*
+CompModelPlugin_getPortById(CompModelPlugin_t* cmp, const char *sid)
+{
+  return (cmp != NULL && sid != NULL) ? cmp->getPort(sid) : NULL;
+}
+
+
+/*
+ * Adds a copy of the given Port_t to this CompModelPlugin_t.
+ */
+LIBSBML_EXTERN
+int
+CompModelPlugin_addPort(CompModelPlugin_t* cmp, const Port_t* p)
+{
+  return (cmp != NULL) ? cmp->addPort(p) : LIBSBML_INVALID_OBJECT;
+}
+
+
+/*
+ * Get the number of Port_t objects in this CompModelPlugin_t.
+ */
+LIBSBML_EXTERN
+unsigned int
+CompModelPlugin_getNumPorts(CompModelPlugin_t* cmp)
+{
+  return (cmp != NULL) ? cmp->getNumPorts() : SBML_INT_MAX;
+}
+
+
+/*
+ * Creates a new Port_t object, adds it to this CompModelPlugin_t object and
+ * returns the Port_t object created.
+ */
+LIBSBML_EXTERN
+Port_t*
+CompModelPlugin_createPort(CompModelPlugin_t* cmp)
+{
+  return (cmp != NULL) ? cmp->createPort() : NULL;
+}
+
+
+/*
+ * Removes the nth Port_t from this CompModelPlugin_t and returns a pointer to
+ * it.
+ */
+LIBSBML_EXTERN
+Port_t*
+CompModelPlugin_removePort(CompModelPlugin_t* cmp, unsigned int n)
+{
+  return (cmp != NULL) ? cmp->removePort(n) : NULL;
+}
+
+
 
 
 LIBSBML_CPP_NAMESPACE_END
-
