@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -45,16 +45,16 @@ LIBSBML_CPP_NAMESPACE_BEGIN
 
 Port::Port (unsigned int level, unsigned int version, unsigned int pkgVersion) 
   : SBaseRef (level,version, pkgVersion)
-  , mId("")
-  , mName("")
+//  , mId("")
+//  , mName("")
 {
 }
 
 
 Port::Port(CompPkgNamespaces* compns)
   : SBaseRef(compns, true)
-  , mId("")
-  , mName("")
+//  , mId("")
+//  , mName("")
 {
   loadPlugins(compns);
 }
