@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2015 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -121,14 +121,15 @@ ExtModelReferenceCycles::addAllReferences(const SBMLDocument* doc,
     mDocumentsHandled.append(location);
 
 
-    SBMLResolverRegistry& registry = SBMLResolverRegistry::getInstance();
+//    SBMLResolverRegistry& registry = SBMLResolverRegistry::getInstance();
 
     for (unsigned int i = 0; i < docPlug->getNumExternalModelDefinitions(); i++)
     {
       string uri = docPlug->getExternalModelDefinition(i)->getSource();
 
-      SBMLDocument* newDoc = registry.resolve(uri, locationURI);
-      registry.addOwnedSBMLDocument(newDoc);
+      SBMLDocument* newDoc = const_cast<CompSBMLDocumentPlugin*>(docPlug)->getSBMLDocumentFromURI(uri);
+//      SBMLDocument* newDoc = registry.resolve(uri, locationURI);
+ //     registry.addOwnedSBMLDocument(newDoc);
 
       addAllReferences(newDoc, uri);
     }
