@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -49,8 +49,8 @@ LIBSBML_CPP_NAMESPACE_BEGIN
  */
 DistribInput::DistribInput (unsigned int level, unsigned int version, unsigned int pkgVersion)
   : SBase(level, version)
-   ,mId ("")
-   ,mName ("")
+////   ,mId ("")
+////   ,mName ("")
    ,mIndex (SBML_INT_MAX)
    ,mIsSetIndex (false)
 {
@@ -67,8 +67,8 @@ DistribInput::DistribInput (unsigned int level, unsigned int version, unsigned i
  */
 DistribInput::DistribInput (DistribPkgNamespaces* distribns)
   : SBase(distribns)
-   ,mId ("")
-   ,mName ("")
+////   ,mId ("")
+////   ,mName ("")
    ,mIndex (SBML_INT_MAX)
    ,mIsSetIndex (false)
 {
@@ -88,8 +88,8 @@ DistribInput::DistribInput (DistribPkgNamespaces* distribns)
  */
 DistribInput::DistribInput (const DistribInput& orig)
   : SBase(orig)
-  , mId  ( orig.mId)
-  , mName  ( orig.mName)
+//  , mId  ( orig.mId)
+//  , mName  ( orig.mName)
   , mIndex  ( orig.mIndex)
   , mIsSetIndex  ( orig.mIsSetIndex)
 {
