@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -50,8 +50,8 @@ SpatialComponent::SpatialComponent (unsigned int level, unsigned int version, un
   : SBase(level, version)
   , mSpatialIndex (SPATIALKIND_UNKNOWN)
   , mVariable ("")
-  , mId ("")
-  , mName ("")
+////  , mId ("")
+////  , mName ("")
 {
   // set an SBMLNamespaces derived object of this package
   setSBMLNamespacesAndOwn(new DynPkgNamespaces(level, version, pkgVersion));
@@ -65,8 +65,8 @@ SpatialComponent::SpatialComponent (DynPkgNamespaces* dynns)
   : SBase(dynns)
   , mSpatialIndex (SPATIALKIND_UNKNOWN)
   , mVariable ("")
-  , mId ("")
-  , mName ("")
+////  , mId ("")
+////  , mName ("")
 {
   // set the element namespace of this object
   setElementNamespace(dynns->getURI());
@@ -83,8 +83,8 @@ SpatialComponent::SpatialComponent (const SpatialComponent& orig)
   : SBase(orig)
   , mSpatialIndex  ( orig.mSpatialIndex)
   , mVariable  ( orig.mVariable)
-  , mId  ( orig.mId)
-  , mName  ( orig.mName)
+//  , mId  ( orig.mId)
+//  , mName  ( orig.mName)
 {
 }
 
