@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -63,8 +63,8 @@ protected:
 
   SpatialKind_t   mSpatialIndex;
   std::string   mVariable;
-  std::string   mId;
-  std::string   mName;
+////  std::string   mId;
+////  std::string   mName;
 
 
 public:
