@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -391,7 +391,7 @@ FbcModelPlugin::addExpectedAttributes(ExpectedAttributes& attributes)
 }
 
 
-  /** @endcond doxygenLibsbmlInternal */
+  /** @endcond */
 
 
 /** @cond doxygenLibsbmlInternal */
@@ -621,7 +621,7 @@ FbcModelPlugin::readAttributes (const XMLAttributes& attributes,
 }
 
 
-  /** @endcond doxygenLibsbmlInternal */
+  /** @endcond */
 
 
   /** @cond doxygenLibsbmlInternal */
@@ -675,7 +675,7 @@ FbcModelPlugin::writeAttributes (XMLOutputStream& stream) const
 }
 
 
-  /** @endcond doxygenLibsbmlInternal */
+  /** @endcond */
 
 
 //---------------------------------------------------------------
@@ -798,10 +798,7 @@ const FluxBound*
 *
 * @param bound the FluxBound object to be added to the list of FluxBounds.
 *
-* @return integer value indicating success/failure of the
-* function.  @if clike The value is drawn from the
-* enumeration #OperationReturnValues_t. @endif The possible values
-* returned by this function are:
+* @copydetails doc_returns_success_code
 * @li LIBSBML_OPERATION_SUCCESS
 */ 
 int 
@@ -829,10 +826,8 @@ int
   }
   else
   {
-    mBounds.append(bound);
+    return mBounds.append(bound);
   }
-
-  return LIBSBML_OPERATION_SUCCESS;
 }
 
 
@@ -877,7 +872,7 @@ FluxBound*
 * The caller owns the returned object and is responsible for
 *  deleting it.
 *
-* @param n the index of the FluxBound object to remove
+* @param n the index of the FluxBound object to remove.
 *
 * @return the FluxBound object removed.  As mentioned above, the 
 * caller owns the returned object. @c NULL is returned if the 
@@ -897,7 +892,7 @@ FluxBound*
 * The caller owns the returned object and is responsible for
 * deleting it.
 *
-* @param sid the id attribute of the FluxBound object to remove
+* @param sid the id attribute of the FluxBound object to remove.
 *
 * @return the FluxBound object removed.  As mentioned above, the 
 * caller owns the returned object. @c NULL is returned if the 
@@ -1049,14 +1044,11 @@ FbcModelPlugin::getObjective(const std::string& sid) const
 
 
 /*
- * Adds a copy the given "Objective" to this FbcModelPlugin.
+ * Adds a copy the given Objective to this FbcModelPlugin.
  *
- * @param o; the Objective object to add
+ * @param o the Objective object to add.
  *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
- * returned by this function are:
+ * @copydetails doc_returns_success_code
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
  */
@@ -1079,10 +1071,13 @@ FbcModelPlugin::addObjective(const Objective* o)
   {
     return LIBSBML_VERSION_MISMATCH;
   }
+  else if (getPackageVersion() != o->getPackageVersion())
+  {
+    return LIBSBML_PKG_VERSION_MISMATCH;
+  }
   else
   {
-    mObjectives.append(o);
-    return LIBSBML_OPERATION_SUCCESS;
+    return mObjectives.append(o);
   }
 }
 
@@ -1100,7 +1095,7 @@ FbcModelPlugin::getNumObjectives() const
 
 
 /*
- * Creates a new Objective object, adds it to this FbcModelPlugins
+ * Creates a new Objective object, adds it to this FbcModelPlugin's
  * FbcModelPlugin and returns the Objective object created. 
  *
  * @return a new Objective object instance
@@ -1229,14 +1224,11 @@ FbcModelPlugin::getGeneProduct(const std::string& sid) const
 
 
 /*
- * Adds a copy the given "GeneProduct" to this FbcModelPlugin.
+ * Adds a copy the given GeneProduct to this FbcModelPlugin.
  *
- * @param gp; the GeneProduct object to add
+ * @param gp the GeneProduct object to add.
  *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
- * returned by this function are:
+   * @copydetails doc_returns_success_code
  * @li LIBSBML_OPERATION_SUCCESS
  * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
  */
@@ -1259,10 +1251,13 @@ FbcModelPlugin::addGeneProduct(const GeneProduct* gp)
   {
     return LIBSBML_VERSION_MISMATCH;
   }
+  else if (getPackageVersion() != gp->getPackageVersion())
+  {
+    return LIBSBML_PKG_VERSION_MISMATCH;
+  }
   else
   {
-    mGeneProducts.append(gp);
-    return LIBSBML_OPERATION_SUCCESS;
+    return mGeneProducts.append(gp);
   }
 }
 
@@ -1280,7 +1275,7 @@ FbcModelPlugin::getNumGeneProducts() const
 
 
 /*
- * Creates a new GeneProduct object, adds it to this FbcModelPlugins
+ * Creates a new GeneProduct object, adds it to this FbcModelPlugin's
  * FbcModelPlugin and returns the GeneProduct object created. 
  *
  * @return a new GeneProduct object instance
@@ -1356,10 +1351,11 @@ FbcModelPlugin::getActiveObjectiveId() const
 /* 
  * Unsets the active objective.
  */  
-void 
+int 
 FbcModelPlugin::unsetActiveObjectiveId()
 {
   mObjectives.unsetActiveObjective();
+  return LIBSBML_OPERATION_SUCCESS;
 }
 
 /*
@@ -1453,10 +1449,7 @@ const GeneAssociation*
 *
 * @param association the GeneAssociation object to be added to the list of GeneAssociations.
 *
-* @return integer value indicating success/failure of the
-* function.  @if clike The value is drawn from the
-* enumeration #OperationReturnValues_t. @endif The possible values
-* returned by this function are:
+* @copydetails doc_returns_success_code
 * @li LIBSBML_OPERATION_SUCCESS
 */ 
 int 
@@ -1484,10 +1477,8 @@ int
   }
   else
   {
-    mAssociations.append(association);
+    return mAssociations.append(association);
   }
-
-  return LIBSBML_OPERATION_SUCCESS;
 }
 
 /*
@@ -1530,7 +1521,7 @@ GeneAssociation*
 * The caller owns the returned object and is responsible for
 *  deleting it.
 *
-* @param n the index of the GeneAssociation object to remove
+* @param n the index of the GeneAssociation object to remove.
 *
 * @return the GeneAssociation object removed.  As mentioned above, the 
 * caller owns the returned object. @c NULL is returned if the 
@@ -1549,7 +1540,7 @@ GeneAssociation*
 * The caller owns the returned object and is responsible for
 * deleting it.
 *
-* @param sid the id attribute of the GeneAssociation object to remove
+* @param sid the id attribute of the GeneAssociation object to remove.
 *
 * @return the GeneAssociation object removed.  As mentioned above, the 
 * caller owns the returned object. @c NULL is returned if the 
@@ -1580,7 +1571,7 @@ int
 /*
  * Sets the parent SBMLDocument of this SBML object.
  *
- * @param d the SBMLDocument object to use
+ * @param d the SBMLDocument object to use.
  */
 void
 FbcModelPlugin::setSBMLDocument(SBMLDocument* d)
@@ -1646,8 +1637,397 @@ FbcModelPlugin::enablePackageInternal(const std::string& pkgURI,
   }
 }
 /** @endcond */
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this FbcModelPlugin.
+ */
+int
+FbcModelPlugin::getAttribute(const std::string& attributeName,
+                             bool& value) const
+{
+  int return_value = SBasePlugin::getAttribute(attributeName, value);
+
+  if (return_value == LIBSBML_OPERATION_SUCCESS)
+  {
+    return return_value;
+  }
+
+  if (attributeName == "strict")
+  {
+    value = getStrict();
+    return_value = LIBSBML_OPERATION_SUCCESS;
+  }
+
+  return return_value;
+}
+
+/** @endcond */
+
+
 
 /** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this FbcModelPlugin.
+ */
+int
+FbcModelPlugin::getAttribute(const std::string& attributeName,
+                             int& value) const
+{
+  int return_value = SBasePlugin::getAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this FbcModelPlugin.
+ */
+int
+FbcModelPlugin::getAttribute(const std::string& attributeName,
+                             double& value) const
+{
+  int return_value = SBasePlugin::getAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this FbcModelPlugin.
+ */
+int
+FbcModelPlugin::getAttribute(const std::string& attributeName,
+                             unsigned int& value) const
+{
+  int return_value = SBasePlugin::getAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this FbcModelPlugin.
+ */
+int
+FbcModelPlugin::getAttribute(const std::string& attributeName,
+                             std::string& value) const
+{
+  int return_value = SBasePlugin::getAttribute(attributeName, value);
+
+  if (attributeName == "activeObjective")
+  {
+    value = getActiveObjectiveId();
+    return_value = LIBSBML_OPERATION_SUCCESS;
+  }
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this FbcModelPlugin.
+ */
+int
+FbcModelPlugin::getAttribute(const std::string& attributeName,
+                             const char* value) const
+{
+  int return_value = SBasePlugin::getAttribute(attributeName, value);
+
+  if (attributeName == "activeObjective")
+  {
+    value = getActiveObjectiveId().c_str();
+    return_value = LIBSBML_OPERATION_SUCCESS;
+  }
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Predicate returning @c true if this FbcModelPlugin's attribute
+ * "attributeName" is set.
+ */
+bool
+FbcModelPlugin::isSetAttribute(const std::string& attributeName) const
+{
+  bool value = SBasePlugin::isSetAttribute(attributeName);
+
+  if (attributeName == "strict")
+  {
+    value = isSetStrict();
+  }
+  else if (attributeName == "activeObjective")
+  {
+    value = (getActiveObjectiveId().empty() == false);
+  }
+
+  return value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this FbcModelPlugin.
+ */
+int
+FbcModelPlugin::setAttribute(const std::string& attributeName, bool value)
+{
+  int return_value = SBasePlugin::setAttribute(attributeName, value);
+
+  if (attributeName == "strict")
+  {
+    return_value = setStrict(value);
+  }
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this FbcModelPlugin.
+ */
+int
+FbcModelPlugin::setAttribute(const std::string& attributeName, int value)
+{
+  int return_value = SBasePlugin::setAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this FbcModelPlugin.
+ */
+int
+FbcModelPlugin::setAttribute(const std::string& attributeName, double value)
+{
+  int return_value = SBasePlugin::setAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this FbcModelPlugin.
+ */
+int
+FbcModelPlugin::setAttribute(const std::string& attributeName,
+                             unsigned int value)
+{
+  int return_value = SBasePlugin::setAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this FbcModelPlugin.
+ */
+int
+FbcModelPlugin::setAttribute(const std::string& attributeName,
+                             const std::string& value)
+{
+  int return_value = SBasePlugin::setAttribute(attributeName, value);
+
+  if (attributeName == "activeObjective")
+  {
+    return_value = setActiveObjectiveId(value);
+  }
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this FbcModelPlugin.
+ */
+int
+FbcModelPlugin::setAttribute(const std::string& attributeName,
+                             const char* value)
+{
+  int return_value = SBasePlugin::setAttribute(attributeName, value);
+
+  if (attributeName == "activeObjective")
+  {
+    return_value = setActiveObjectiveId(value);
+  }
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Unsets the value of the "attributeName" attribute of this FbcModelPlugin.
+ */
+int
+FbcModelPlugin::unsetAttribute(const std::string& attributeName)
+{
+  int value = SBasePlugin::unsetAttribute(attributeName);
+
+  if (attributeName == "strict")
+  {
+    value = unsetStrict();
+  }
+  if (attributeName == "activeObjective")
+  {
+    value = unsetActiveObjectiveId();
+  }
+
+  return value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Creates and returns an new "elementName" object in this FbcModelPlugin.
+ */
+SBase*
+FbcModelPlugin::createChildObject(const std::string& elementName)
+{
+  SBase* obj = NULL;
+
+  if (elementName == "objective")
+  {
+    return createObjective();
+  }
+  else if (elementName == "fluxBound")
+  {
+    return createFluxBound();
+  }
+  else if (elementName == "geneProduct")
+  {
+    return createGeneProduct();
+  }
+
+  return obj;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Returns the number of "elementName" in this FbcModelPlugin.
+ */
+unsigned int
+FbcModelPlugin::getNumObjects(const std::string& elementName)
+{
+  unsigned int n = 0;
+
+  if (elementName == "objective")
+  {
+    return getNumObjectives();
+  }
+  else if (elementName == "fluxBound")
+  {
+    return getNumFluxBounds();
+  }
+  else if (elementName == "geneProduct")
+  {
+    return getNumGeneProducts();
+  }
+
+  return n;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Returns the nth object of "objectName" in this FbcModelPlugin.
+ */
+SBase*
+FbcModelPlugin::getObject(const std::string& elementName, unsigned int index)
+{
+  SBase* obj = NULL;
+
+  if (elementName == "objective")
+  {
+    return getObjective(index);
+  }
+  else if (elementName == "fluxBound")
+  {
+    return getFluxBound(index);
+  }
+  else if (elementName == "geneProduct")
+  {
+    return getGeneProduct(index);
+  }
+
+  return obj;
+}
+
+/** @endcond */
+
+
+/** @cond doxygenLibsbmlInternal */
+
 /*
  * Accept the SBMLVisitor.
  */
