@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -39,6 +39,55 @@ using namespace std;
 LIBSBML_CPP_NAMESPACE_BEGIN
 #ifdef __cplusplus
 
+
+bool
+isWellFormedChemicalFormula(const std::string& chemicalFormula)
+{
+  size_t index = 0;
+  size_t sizeStr = chemicalFormula.size();
+  char c = chemicalFormula[index];
+  bool valid = true;
+
+  // first must be a capital letter
+  if (isupper(c) == 0)
+  {
+    valid = false;
+    return valid;
+  }
+  
+  if (sizeStr == 1)
+  { 
+    return valid;
+  }
+
+  index++;
+  bool prevNum = false;
+  while (valid && index < sizeStr)
+  {
+    c = chemicalFormula[index];
+
+    // if it is a letter it should be
+    // upper if it follows a nume
+    if (isalpha(c) != 0)
+    {
+      if (prevNum)
+      {
+        if (isupper(c) == 0)
+        { 
+          valid = false;
+        }
+      }
+      prevNum = false;
+    }
+    else
+    {
+      prevNum = true;
+    }
+
+    index++;
+  }
+  return valid;
+}
 static void
 parseChemicalFormula(std::string& chemicalFormula, 
                      SBMLErrorLog& errLog, unsigned int packageVersion, 
@@ -239,7 +288,7 @@ FbcSpeciesPlugin::addExpectedAttributes(ExpectedAttributes& attributes)
 }
 
 
-  /** @endcond doxygenLibsbmlInternal */
+  /** @endcond */
 
 
   /** @cond doxygenLibsbmlInternal */
@@ -296,7 +345,7 @@ FbcSpeciesPlugin::readAttributes (const XMLAttributes& attributes,
 }
 
 
-  /** @endcond doxygenLibsbmlInternal */
+  /** @endcond */
 
 
   /** @cond doxygenLibsbmlInternal */
@@ -318,7 +367,7 @@ FbcSpeciesPlugin::writeAttributes (XMLOutputStream& stream) const
 }
 
 
-  /** @endcond doxygenLibsbmlInternal */
+  /** @endcond */
 
 
 //---------------------------------------------------------------
@@ -327,15 +376,6 @@ FbcSpeciesPlugin::writeAttributes (XMLOutputStream& stream) const
 //
 //---------------------------------------------------------------
 
-List*
-FbcSpeciesPlugin::getAllElements(ElementFilter*)
-{
-  List* ret = new List();
-
-  return ret;
-}
-
-
 /*
  * Returns the value of the "charge" attribute of this FbcSpeciesPlugin.
  */
@@ -394,10 +434,18 @@ FbcSpeciesPlugin::setCharge(int charge)
 int
 FbcSpeciesPlugin::setChemicalFormula(const std::string& chemicalFormula)
 {
+  if (isWellFormedChemicalFormula(chemicalFormula))
   {
     mChemicalFormula = chemicalFormula;
     return LIBSBML_OPERATION_SUCCESS;
   }
+  else
+  {
+    // since not setting an invalid formula would be a change 
+    // in behaviour I set it anyway
+    mChemicalFormula = chemicalFormula;
+    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
+  }
 }
 
 
@@ -494,6 +542,319 @@ FbcSpeciesPlugin::accept(SBMLVisitor&) const
 /** @endcond */
 
 
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this FbcSpeciesPlugin.
+ */
+int
+FbcSpeciesPlugin::getAttribute(const std::string& attributeName,
+                               bool& value) const
+{
+  int return_value = SBasePlugin::getAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this FbcSpeciesPlugin.
+ */
+int
+FbcSpeciesPlugin::getAttribute(const std::string& attributeName,
+                               int& value) const
+{
+  int return_value = SBasePlugin::getAttribute(attributeName, value);
+
+  if (return_value == LIBSBML_OPERATION_SUCCESS)
+  {
+    return return_value;
+  }
+
+  if (attributeName == "charge")
+  {
+    value = getCharge();
+    return_value = LIBSBML_OPERATION_SUCCESS;
+  }
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this FbcSpeciesPlugin.
+ */
+int
+FbcSpeciesPlugin::getAttribute(const std::string& attributeName,
+                               double& value) const
+{
+  int return_value = SBasePlugin::getAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this FbcSpeciesPlugin.
+ */
+int
+FbcSpeciesPlugin::getAttribute(const std::string& attributeName,
+                               unsigned int& value) const
+{
+  int return_value = SBasePlugin::getAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this FbcSpeciesPlugin.
+ */
+int
+FbcSpeciesPlugin::getAttribute(const std::string& attributeName,
+                               std::string& value) const
+{
+  int return_value = SBasePlugin::getAttribute(attributeName, value);
+
+  if (return_value == LIBSBML_OPERATION_SUCCESS)
+  {
+    return return_value;
+  }
+
+  if (attributeName == "chemicalFormula")
+  {
+    value = getChemicalFormula();
+    return_value = LIBSBML_OPERATION_SUCCESS;
+  }
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this FbcSpeciesPlugin.
+ */
+int
+FbcSpeciesPlugin::getAttribute(const std::string& attributeName,
+                               const char* value) const
+{
+  int return_value = SBasePlugin::getAttribute(attributeName, value);
+
+  if (return_value == LIBSBML_OPERATION_SUCCESS)
+  {
+    return return_value;
+  }
+
+  if (attributeName == "chemicalFormula")
+  {
+    value = getChemicalFormula().c_str();
+    return_value = LIBSBML_OPERATION_SUCCESS;
+  }
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Predicate returning @c true if this FbcSpeciesPlugin's attribute
+ * "attributeName" is set.
+ */
+bool
+FbcSpeciesPlugin::isSetAttribute(const std::string& attributeName) const
+{
+  bool value = SBasePlugin::isSetAttribute(attributeName);
+
+  if (attributeName == "charge")
+  {
+    value = isSetCharge();
+  }
+  else if (attributeName == "chemicalFormula")
+  {
+    value = isSetChemicalFormula();
+  }
+
+  return value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this FbcSpeciesPlugin.
+ */
+int
+FbcSpeciesPlugin::setAttribute(const std::string& attributeName, bool value)
+{
+  int return_value = SBasePlugin::setAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this FbcSpeciesPlugin.
+ */
+int
+FbcSpeciesPlugin::setAttribute(const std::string& attributeName, int value)
+{
+  int return_value = SBasePlugin::setAttribute(attributeName, value);
+
+  if (attributeName == "charge")
+  {
+    return_value = setCharge(value);
+  }
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this FbcSpeciesPlugin.
+ */
+int
+FbcSpeciesPlugin::setAttribute(const std::string& attributeName, double value)
+{
+  int return_value = SBasePlugin::setAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this FbcSpeciesPlugin.
+ */
+int
+FbcSpeciesPlugin::setAttribute(const std::string& attributeName,
+                               unsigned int value)
+{
+  int return_value = SBasePlugin::setAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this FbcSpeciesPlugin.
+ */
+int
+FbcSpeciesPlugin::setAttribute(const std::string& attributeName,
+                               const std::string& value)
+{
+  int return_value = SBasePlugin::setAttribute(attributeName, value);
+
+  if (attributeName == "chemicalFormula")
+  {
+    return_value = setChemicalFormula(value);
+  }
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this FbcSpeciesPlugin.
+ */
+int
+FbcSpeciesPlugin::setAttribute(const std::string& attributeName,
+                               const char* value)
+{
+  int return_value = SBasePlugin::setAttribute(attributeName, value);
+
+  if (attributeName == "chemicalFormula")
+  {
+    return_value = setChemicalFormula(value);
+  }
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Unsets the value of the "attributeName" attribute of this FbcSpeciesPlugin.
+ */
+int
+FbcSpeciesPlugin::unsetAttribute(const std::string& attributeName)
+{
+  int value = SBasePlugin::unsetAttribute(attributeName);
+
+  if (attributeName == "charge")
+  {
+    value = unsetCharge();
+  }
+  else if (attributeName == "chemicalFormula")
+  {
+    value = unsetChemicalFormula();
+  }
+
+  return value;
+}
+
+/** @endcond */
+
+
 
 #endif /* __cplusplus */
 /** @cond doxygenIgnored */
