@@ -36,7 +36,6 @@
 #include <sbml/packages/fbc/validator/FbcSBMLError.h>
 #include <sbml/util/ElementFilter.h>
 
-#include <sbml/packages/fbc/sbml/FbcAnd.h>
 #include <sbml/packages/fbc/sbml/FbcOr.h>
 #include <sbml/packages/fbc/sbml/GeneProductRef.h>
 
@@ -45,6 +44,8 @@
 using namespace std;
 
 
+#ifdef __cplusplus
+
 LIBSBML_CPP_NAMESPACE_BEGIN
 
 
@@ -212,15 +213,6 @@ FbcAnd::getAssociation(const std::string& sid) const
 
 /*
  * Adds a copy the given "FbcAssociation" to this FbcAnd.
- *
- * @param fa; the FbcAssociation object to add
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
  */
 int
 FbcAnd::addAssociation(const FbcAssociation* fa)
@@ -966,6 +958,9 @@ FbcAnd::writeAttributes (XMLOutputStream& stream) const
   /** @endcond doxygenLibsbmlInternal */
 
 
+#endif /* __cplusplus */
+
+
 LIBSBML_EXTERN
 FbcAnd_t *
 FbcAnd_create(unsigned int level, unsigned int version,
@@ -986,7 +981,7 @@ FbcAnd_free(FbcAnd_t * fa)
 
 LIBSBML_EXTERN
 FbcAnd_t *
-FbcAnd_clone(FbcAnd_t * fa)
+FbcAnd_clone(const FbcAnd_t * fa)
 {
   if (fa != NULL)
   {
@@ -1001,7 +996,7 @@ FbcAnd_clone(FbcAnd_t * fa)
 
 LIBSBML_EXTERN
 int
-FbcAnd_addAssociation(FbcAnd_t * fa, FbcAssociation_t * a)
+FbcAnd_addAssociation(FbcAnd_t * fa, const FbcAssociation_t * a)
 {
   return  (fa != NULL) ? fa->addAssociation(a) : LIBSBML_INVALID_OBJECT;
 }
@@ -1085,8 +1080,8 @@ FbcAnd_hasRequiredElements(const FbcAnd_t * fa)
 }
 
 
-
-
 LIBSBML_CPP_NAMESPACE_END
 
 
+
+
