@@ -40,6 +40,8 @@
 using namespace std;
 
 
+#ifdef __cplusplus
+
 LIBSBML_CPP_NAMESPACE_BEGIN
 
 
@@ -1517,4 +1519,7 @@ ListOfGeneProducts_removeById(ListOf_t * lo, const char * sid)
 
 LIBSBML_CPP_NAMESPACE_END
 
+#endif /* __cplusplus */
+
+
 
