@@ -56,8 +56,6 @@ Member::Member(unsigned int level,
                unsigned int version,
                unsigned int pkgVersion)
   : SBase(level, version)
-//  , mId ("")
-//  , mName ("")
   , mIdRef ("")
   , mMetaIdRef ("")
 {
@@ -70,8 +68,6 @@ Member::Member(unsigned int level,
  */
 Member::Member(GroupsPkgNamespaces *groupsns)
   : SBase(groupsns)
-//  , mId ("")
-//  , mName ("")
   , mIdRef ("")
   , mMetaIdRef ("")
 {
@@ -85,8 +81,6 @@ Member::Member(GroupsPkgNamespaces *groupsns)
  */
 Member::Member(const Member& orig)
   : SBase( orig )
-  //, mId ( orig.mId )
-  //, mName ( orig.mName )
   , mIdRef ( orig.mIdRef )
   , mMetaIdRef ( orig.mMetaIdRef )
 {
@@ -102,8 +96,6 @@ Member::operator=(const Member& rhs)
   if (&rhs != this)
   {
     SBase::operator=(rhs);
-    mId = rhs.mId;
-    mName = rhs.mName;
     mIdRef = rhs.mIdRef;
     mMetaIdRef = rhs.mMetaIdRef;
   }
@@ -255,8 +247,15 @@ Member::setIdRef(const std::string& idRef)
 int
 Member::setMetaIdRef(const std::string& metaIdRef)
 {
-  mMetaIdRef = metaIdRef;
-  return LIBSBML_OPERATION_SUCCESS;
+  if (!(SyntaxChecker::isValidXMLID(metaIdRef)))
+  {
+    return LIBSBML_INVALID_ATTRIBUTE_VALUE;
+  }
+  else
+  {
+    mMetaIdRef = metaIdRef;
+    return LIBSBML_OPERATION_SUCCESS;
+  }
 }
 
 
@@ -448,6 +447,369 @@ Member::enablePackageInternal(const std::string& pkgURI,
 
 
 
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this Member.
+ */
+int
+Member::getAttribute(const std::string& attributeName, bool& value) const
+{
+  int return_value = SBase::getAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this Member.
+ */
+int
+Member::getAttribute(const std::string& attributeName, int& value) const
+{
+  int return_value = SBase::getAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this Member.
+ */
+int
+Member::getAttribute(const std::string& attributeName, double& value) const
+{
+  int return_value = SBase::getAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this Member.
+ */
+int
+Member::getAttribute(const std::string& attributeName,
+                     unsigned int& value) const
+{
+  int return_value = SBase::getAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this Member.
+ */
+int
+Member::getAttribute(const std::string& attributeName,
+                     std::string& value) const
+{
+  int return_value = SBase::getAttribute(attributeName, value);
+
+  if (return_value == LIBSBML_OPERATION_SUCCESS)
+  {
+    return return_value;
+  }
+
+  if (attributeName == "id")
+  {
+    value = getId();
+    return_value = LIBSBML_OPERATION_SUCCESS;
+  }
+  else if (attributeName == "name")
+  {
+    value = getName();
+    return_value = LIBSBML_OPERATION_SUCCESS;
+  }
+  else if (attributeName == "idRef")
+  {
+    value = getIdRef();
+    return_value = LIBSBML_OPERATION_SUCCESS;
+  }
+  else if (attributeName == "metaIdRef")
+  {
+    value = getMetaIdRef();
+    return_value = LIBSBML_OPERATION_SUCCESS;
+  }
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Gets the value of the "attributeName" attribute of this Member.
+ */
+int
+Member::getAttribute(const std::string& attributeName,
+                     const char* value) const
+{
+  int return_value = SBase::getAttribute(attributeName, value);
+
+  if (return_value == LIBSBML_OPERATION_SUCCESS)
+  {
+    return return_value;
+  }
+
+  if (attributeName == "id")
+  {
+    value = getId().c_str();
+    return_value = LIBSBML_OPERATION_SUCCESS;
+  }
+  else if (attributeName == "name")
+  {
+    value = getName().c_str();
+    return_value = LIBSBML_OPERATION_SUCCESS;
+  }
+  else if (attributeName == "idRef")
+  {
+    value = getIdRef().c_str();
+    return_value = LIBSBML_OPERATION_SUCCESS;
+  }
+  else if (attributeName == "metaIdRef")
+  {
+    value = getMetaIdRef().c_str();
+    return_value = LIBSBML_OPERATION_SUCCESS;
+  }
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Predicate returning @c true if this Member's attribute "attributeName" is
+ * set.
+ */
+bool
+Member::isSetAttribute(const std::string& attributeName) const
+{
+  bool value = SBase::isSetAttribute(attributeName);
+
+  if (attributeName == "id")
+  {
+    value = isSetId();
+  }
+  else if (attributeName == "name")
+  {
+    value = isSetName();
+  }
+  else if (attributeName == "idRef")
+  {
+    value = isSetIdRef();
+  }
+  else if (attributeName == "metaIdRef")
+  {
+    value = isSetMetaIdRef();
+  }
+
+  return value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this Member.
+ */
+int
+Member::setAttribute(const std::string& attributeName, bool value)
+{
+  int return_value = SBase::setAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this Member.
+ */
+int
+Member::setAttribute(const std::string& attributeName, int value)
+{
+  int return_value = SBase::setAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this Member.
+ */
+int
+Member::setAttribute(const std::string& attributeName, double value)
+{
+  int return_value = SBase::setAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this Member.
+ */
+int
+Member::setAttribute(const std::string& attributeName, unsigned int value)
+{
+  int return_value = SBase::setAttribute(attributeName, value);
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this Member.
+ */
+int
+Member::setAttribute(const std::string& attributeName,
+                     const std::string& value)
+{
+  int return_value = SBase::setAttribute(attributeName, value);
+
+  if (attributeName == "id")
+  {
+    return_value = setId(value);
+  }
+  else if (attributeName == "name")
+  {
+    return_value = setName(value);
+  }
+  else if (attributeName == "idRef")
+  {
+    return_value = setIdRef(value);
+  }
+  else if (attributeName == "metaIdRef")
+  {
+    return_value = setMetaIdRef(value);
+  }
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Sets the value of the "attributeName" attribute of this Member.
+ */
+int
+Member::setAttribute(const std::string& attributeName, const char* value)
+{
+  int return_value = SBase::setAttribute(attributeName, value);
+
+  if (attributeName == "id")
+  {
+    return_value = setId(value);
+  }
+  else if (attributeName == "name")
+  {
+    return_value = setName(value);
+  }
+  else if (attributeName == "idRef")
+  {
+    return_value = setIdRef(value);
+  }
+  else if (attributeName == "metaIdRef")
+  {
+    return_value = setMetaIdRef(value);
+  }
+
+  return return_value;
+}
+
+/** @endcond */
+
+
+
+/** @cond doxygenLibsbmlInternal */
+
+/*
+ * Unsets the value of the "attributeName" attribute of this Member.
+ */
+int
+Member::unsetAttribute(const std::string& attributeName)
+{
+  int value = SBase::unsetAttribute(attributeName);
+
+  if (attributeName == "id")
+  {
+    value = unsetId();
+  }
+  else if (attributeName == "name")
+  {
+    value = unsetName();
+  }
+  else if (attributeName == "idRef")
+  {
+    value = unsetIdRef();
+  }
+  else if (attributeName == "metaIdRef")
+  {
+    value = unsetMetaIdRef();
+  }
+
+  return value;
+}
+
+/** @endcond */
+
+
+
 /** @cond doxygenLibsbmlInternal */
 
 /*
@@ -545,10 +907,9 @@ Member::readAttributes(const XMLAttributes& attributes,
     }
     else if (SyntaxChecker::isValidSBMLSId(mId) == false)
     {
-      log->logPackageError("groups", GroupsIdSyntaxRule,
-        pkgVersion, level, version, "The id on the <" 
-        + getElementName() + "> is '" + mId + "', which does not conform to the syntax.", 
-        getLine(), getColumn());
+      log->logPackageError("groups", GroupsIdSyntaxRule, pkgVersion, level,
+        version, "The id on the <" + getElementName() + "> is '" + mId + "',which "
+          "does not conform to the syntax.", getLine(), getColumn());
     }
   }
 
@@ -580,7 +941,7 @@ Member::readAttributes(const XMLAttributes& attributes,
     }
     else if (SyntaxChecker::isValidSBMLSId(mIdRef) == false)
     {
-      std::string msg = "The idRef on the <" + this->getElementName() + "> ";
+      std::string msg = "The idRef attribute on the <" + this->getElementName() + "> ";
       if (this->isSetId()) {
         msg += "with id '" + this->getId() +"' ";
       }
@@ -604,7 +965,7 @@ Member::readAttributes(const XMLAttributes& attributes,
     }
     else if (SyntaxChecker::isValidXMLID(mMetaIdRef) == false)
     {
-      std::string msg = "The metaIdRef on the <" + this->getElementName() + "> ";
+      std::string msg = "The metaIdRef attribute on the <" + this->getElementName() + "> ";
       if (this->isSetId()) {
         msg += "with id '" + this->getId() +"' ";
       }
@@ -733,7 +1094,7 @@ Member_free(Member_t* m)
  * Returns the value of the "id" attribute of this Member_t.
  */
 LIBSBML_EXTERN
-const char *
+char *
 Member_getId(const Member_t * m)
 {
   if (m == NULL)
@@ -749,7 +1110,7 @@ Member_getId(const Member_t * m)
  * Returns the value of the "name" attribute of this Member_t.
  */
 LIBSBML_EXTERN
-const char *
+char *
 Member_getName(const Member_t * m)
 {
   if (m == NULL)
@@ -765,7 +1126,7 @@ Member_getName(const Member_t * m)
  * Returns the value of the "idRef" attribute of this Member_t.
  */
 LIBSBML_EXTERN
-const char *
+char *
 Member_getIdRef(const Member_t * m)
 {
   if (m == NULL)
@@ -781,7 +1142,7 @@ Member_getIdRef(const Member_t * m)
  * Returns the value of the "metaIdRef" attribute of this Member_t.
  */
 LIBSBML_EXTERN
-const char *
+char *
 Member_getMetaIdRef(const Member_t * m)
 {
   if (m == NULL)
@@ -795,7 +1156,7 @@ Member_getMetaIdRef(const Member_t * m)
 
 
 /*
- * Predicate returning @c 1 if this Member_t's "id" attribute is set.
+ * Predicate returning @c 1 (true) if this Member_t's "id" attribute is set.
  */
 LIBSBML_EXTERN
 int
@@ -806,7 +1167,7 @@ Member_isSetId(const Member_t * m)
 
 
 /*
- * Predicate returning @c 1 if this Member_t's "name" attribute is set.
+ * Predicate returning @c 1 (true) if this Member_t's "name" attribute is set.
  */
 LIBSBML_EXTERN
 int
@@ -817,7 +1178,7 @@ Member_isSetName(const Member_t * m)
 
 
 /*
- * Predicate returning @c 1 if this Member_t's "idRef" attribute is set.
+ * Predicate returning @c 1 (true) if this Member_t's "idRef" attribute is set.
  */
 LIBSBML_EXTERN
 int
@@ -828,7 +1189,8 @@ Member_isSetIdRef(const Member_t * m)
 
 
 /*
- * Predicate returning @c 1 if this Member_t's "metaIdRef" attribute is set.
+ * Predicate returning @c 1 (true) if this Member_t's "metaIdRef" attribute is
+ * set.
  */
 LIBSBML_EXTERN
 int
@@ -927,8 +1289,8 @@ Member_unsetMetaIdRef(Member_t * m)
 
 
 /*
- * Predicate returning @c 1 if all the required attributes for this Member_t
- * object have been set.
+ * Predicate returning @c 1 (true) if all the required attributes for this
+ * Member_t object have been set.
  */
 LIBSBML_EXTERN
 int
