@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -71,37 +71,49 @@ public:
   /**
    * Creates a line segment with the given SBML level, version, and package version
    * and both points set to (0.0,0.0,0.0)
-   */ 
+   *
+   * @param level the SBML Level.
+   * @param version the Version within the SBML Level.
+   * @param pkgVersion the version of the package.
+   *
+   * @copydetails doc_note_setting_lv_pkg
+   */
   LineSegment (unsigned int level      = LayoutExtension::getDefaultLevel(),
                unsigned int version    = LayoutExtension::getDefaultVersion(),
                unsigned int pkgVersion = LayoutExtension::getDefaultPackageVersion());
 
   /**
    * Creates a line segment with the LayoutPkgNamespaces and both points set to (0.0,0.0,0.0)
-   */ 
+   *
+   * @copydetails doc_what_are_sbml_package_namespaces
+   *
+   * @param layoutns the LayoutPkgNamespaces object.
+   *
+   * @copydetails doc_note_setting_lv_pkg
+   */
   LineSegment (LayoutPkgNamespaces* layoutns);
 
 
   /**
    * Creates a new line segment with the given 2D coordinates.
-   */ 
-  
+   */
   LineSegment (LayoutPkgNamespaces* layoutns, double x1, double y1, double x2, double y2);
 
   /**
    * Copy constructor.
+   *
+   * @param orig the instance to copy.
    */
   LineSegment(const LineSegment& orig);
 
   /**
    * Creates a new line segment with the given 3D coordinates.
-   */ 
+   */
   LineSegment(LayoutPkgNamespaces* layoutns, double x1, double y1, double z1, double x2, double y2, double z2);
 
   /**
    * Creates a new line segment with the two given points.
-   */ 
-  
+   */
   LineSegment (LayoutPkgNamespaces* layoutns, const Point* start, const Point* end);
 
 
@@ -112,71 +124,69 @@ public:
 
   /**
    * Destructor.
-   */ 
-  
+   */
   virtual ~LineSegment ();
 
   /**
    * Assignment operator
+   *
+   * @param rhs the object whose values are used as the basis of the
+   * assignment.
    */
-  virtual LineSegment& operator=(const LineSegment& orig);
+  virtual LineSegment& operator=(const LineSegment& rhs);
 
 
   /**
    * Returns a List of all child SBase objects, including those nested to an
    * arbitrary depth
    *
-   * @return a List* of pointers to all children objects.
+   * @param filter a pointer to an ElementFilter, which causes the function 
+   * to return only elements that match a particular set of constraints.  
+   * If NULL (the default), the function will return all child objects.
+   *
+   * @return a List of pointers to all children objects.
    */
   virtual List* getAllElements(ElementFilter* filter=NULL);
 
 
   /**
    * Returns the start point of the line.
-   */ 
-  
+   */
   const Point* getStart () const;
 
   /**
    * Returns the start point of the line.
-   */ 
-  
+   */
   Point* getStart ();
 
   /**
    * Initializes the start point with a copy of the given Point object.
    */
-  
   void setStart (const Point* start);
 
   /**
    * Initializes the start point with the given coordinates.
    */
-  
   void setStart (double x, double y, double z = 0.0);
 
   /**
    * Returns the end point of the line.
-   */ 
-  
+   */
   const Point* getEnd () const;
 
   /**
    * Returns the end point of the line.
-   */ 
-  
+   */
   Point* getEnd ();
 
   /**
    * Initializes the end point with a copy of the given Point object.
    */
-  
   void setEnd (const Point* end);
 
   /**
    * Initializes the end point with the given coordinates.
    */
-  
   void setEnd (double x, double y, double z = 0.0);
 
   /** @cond doxygenLibsbmlInternal */
@@ -187,15 +197,14 @@ public:
   /** @endcond */
 
   /**
-   * Does noting since no defaults are defined for LineSegment.
-   */ 
-  
+   * Does nothing since no defaults are defined for LineSegment.
+   */
   void initDefaults ();
 
   /** @cond doxygenLibsbmlInternal */
   /**
    * Subclasses should override this method to write out their contained
-   * SBML objects as XML elements.  Be sure to call your parents
+   * SBML objects as XML elements.  Be sure to call your parent's
    * implementation of this method as well.  For example:
    *
    *   SBase::writeElements(stream);
@@ -211,7 +220,7 @@ public:
    * Returns the XML element name of
    * this SBML object.
    *
-   * @return the string of the name of this element
+   * @return the string of the name of this element.
    */
   virtual const std::string& getElementName () const ;
 
@@ -261,7 +270,7 @@ public:
   /**
    * Sets the parent SBMLDocument of this SBML object.
    *
-   * @param d the SBMLDocument object to use
+   * @param d the SBMLDocument object to use.
    */
   virtual void setSBMLDocument (SBMLDocument* d);
   /** @endcond */
@@ -303,7 +312,7 @@ protected:
    * Create and return an SBML object of this class, if present.
    *
    * @return the SBML object corresponding to next XMLToken in the
-   * XMLInputStream or NULL if the token was not recognized.
+   * XMLInputStream or @c NULL if the token was not recognized.
    */
   virtual SBase*
   createObject (XMLInputStream& stream);
@@ -325,7 +334,7 @@ protected:
   /**
    * Subclasses should override this method to read values from the given
    * XMLAttributes set into their specific fields.  Be sure to call your
-   * parents implementation of this method as well.
+   * parent's implementation of this method as well.
    */
   virtual void readAttributes (const XMLAttributes& attributes, 
                                const ExpectedAttributes& expectedAttributes);
@@ -335,7 +344,7 @@ protected:
   /** @cond doxygenLibsbmlInternal */
   /**
    * Subclasses should override this method to write their XML attributes
-   * to the XMLOutputStream.  Be sure to call your parents implementation
+   * to the XMLOutputStream.  Be sure to call your parent's implementation
    * of this method as well.  For example:
    *
    *   SBase::writeAttributes(stream);
@@ -371,7 +380,12 @@ BEGIN_C_DECLS
 
 
 /**
- * Creates a LineSegment_t and returns the pointer.
+ * Creates a LineSegment_t with the default SBML level, version,
+ * and package version, and both points set to (0.0,0.0,0.0).
+ *
+ * @return A pointer to the created LineSegment_t.
+ *
+ * @copydetails doc_returned_owned_pointer
  *
  * @memberof LineSegment_t
  */
@@ -381,10 +395,15 @@ LineSegment_create (void);
 
 
 /**
- * Creates a LineSegment_t from a template.
+ * Creates a clone of @p temp, or creates a new empty LineSegment if 
+ * @p temp is @c NULL.
  *
- * @param temp The LineSegment_t structure to copy.
+ * @param temp the LineSegment_t structure to copy.
  *
+ * @return the created copy of the LineSegment_t
+ *
+ * @copydetails doc_returned_owned_pointer
+ * 
  * @memberof LineSegment_t
  */
 LIBSBML_EXTERN
@@ -392,10 +411,13 @@ LineSegment_t *
 LineSegment_createFrom (const LineSegment_t *temp);
 
 /**
- * Creates a LineSegment_t with the given points and returns the pointer.
+ * Creates a LineSegment_t with the default SBML level, version, and package 
+ * version, and with the given points and returns the pointer.
  *
- * @param start The Point_t at which the line segment starts
- * @param end   The Point_t at which the line segment ends
+ * @param start the Point_t at which the line segment starts.
+ * @param end   the Point_t at which the line segment ends.
+ *
+ * @copydetails doc_returned_owned_pointer
  *
  * @memberof LineSegment_t
  */
@@ -404,15 +426,17 @@ LineSegment_t *
 LineSegment_createWithPoints (const Point_t *start, const Point_t *end);
 
 /**
- * Creates a LineSegment_t with the given coordinates and returns the
- * pointer.
+ * Creates a LineSegment_t with the default SBML level, version, and package 
+ * version, and with the given coordinates and returns the pointer.
  *
- * @param x1 The value of the x coordinate of the start Point_t.
- * @param y1 The value of the y coordinate of the start Point_t.
- * @param z1 The value of the z coordinate of the start Point_t.
- * @param x2 The value of the x coordinate of the end Point_t.
- * @param y2 The value of the y coordinate of the end Point_t.
- * @param z2 The value of the z coordinate of the end Point_t.
+ * @param x1 the value of the x coordinate of the start Point_t.
+ * @param y1 the value of the y coordinate of the start Point_t.
+ * @param z1 the value of the z coordinate of the start Point_t.
+ * @param x2 the value of the x coordinate of the end Point_t.
+ * @param y2 the value of the y coordinate of the end Point_t.
+ * @param z2 the value of the z coordinate of the end Point_t.
+ *
+ * @copydetails doc_returned_owned_pointer
  *
  * @memberof LineSegment_t
  */
@@ -424,7 +448,7 @@ LineSegment_createWithCoordinates (double x1, double y1, double z1,
 /**
  * Frees the memory for the line segment.
  *
- * @param ls The LineSegment_t structure.
+ * @param ls the LineSegment_t structure.
  *
  * @memberof LineSegment_t
  */
@@ -436,8 +460,8 @@ LineSegment_free (LineSegment_t *ls);
 /**
  * Initializes the start point with a copy of the given Point_t structure.
  *
- * @param ls The LineSegment_t structure.
- * @param start The Point_t at which the line segment starts
+ * @param ls the LineSegment_t structure.
+ * @param start the Point_t at which the line segment starts.
  *
  * @memberof LineSegment_t
  */
@@ -448,8 +472,8 @@ LineSegment_setStart (LineSegment_t *ls, const Point_t *start);
 /**
  * Initializes the end point with a copy of the given Point_t structure.
  *
- * @param ls  The LineSegment_t structure.
- * @param end The Point_t at which the line segment ends
+ * @param ls  the LineSegment_t structure.
+ * @param end the Point_t at which the line segment ends.
  *
  * @memberof LineSegment_t
  */
@@ -461,10 +485,12 @@ LineSegment_setEnd (LineSegment_t *ls, const Point_t *end);
 /**
  * Returns the start point of the line.
  *
- * @param ls The LineSegment_t structure.
+ * @param ls the LineSegment_t structure.
+ *
+ * @copydetails doc_returned_unowned_pointer
  *
  * @memberof LineSegment_t
- */ 
+ */
 LIBSBML_EXTERN
 Point_t *
 LineSegment_getStart (LineSegment_t *ls);
@@ -472,29 +498,34 @@ LineSegment_getStart (LineSegment_t *ls);
 /**
  * Returns the end point of the line.
  *
- * @param ls The LineSegment_t structure.
+ * @param ls the LineSegment_t structure.
+ *
+ * @copydetails doc_returned_unowned_pointer
  *
  * @memberof LineSegment_t
- */ 
+ */
 LIBSBML_EXTERN
 Point_t *
 LineSegment_getEnd (LineSegment_t *ls);
 
 /**
- * Does noting since no defaults are defined for LineSegment_t.
+ * Does nothing since no defaults are defined for LineSegment_t.
  *
- * @param ls The LineSegment_t structure.
+ * @param ls the LineSegment_t structure.
  *
  * @memberof LineSegment_t
- */ 
+ */
 LIBSBML_EXTERN
 void
 LineSegment_initDefaults (LineSegment_t *ls);
 
 /**
- * @return a (deep) copy of this LineSegment_t.
+ * @return a (deep) copy of this LineSegment_t, or @c NULL if 
+ * @p ls is @c NULL.
  *
- * @param ls The LineSegment_t structure.
+ * @param ls the LineSegment_t structure.
+ *
+ * @copydetails doc_returned_owned_pointer
  *
  * @memberof LineSegment_t
  */
