@@ -8,7 +8,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -70,7 +70,6 @@ Suite *create_suite_LayoutCreation        (void);
 Suite *create_suite_LayoutFormatter       (void);
 Suite *create_suite_SBMLHandler           (void);
 Suite *create_suite_LayoutWriting         (void);
-Suite *create_suite_Misc                  (void);
 
 END_C_DECLS
 
@@ -137,7 +136,6 @@ main (void)
   srunner_add_suite( runner, create_suite_LayoutFormatter       () );
   srunner_add_suite( runner, create_suite_SBMLHandler           () );
   srunner_add_suite( runner, create_suite_LayoutWriting         () );
-  /* srunner_add_suite( runner, create_suite_Misc                  () ); */
   
   
 #ifdef TRACE_MEMORY
