@@ -40,6 +40,8 @@
 using namespace std;
 
 
+#ifdef __cplusplus
+
 LIBSBML_CPP_NAMESPACE_BEGIN
 
 
@@ -348,4 +350,6 @@ IntraSpeciesReaction_hasRequiredAttributes(const IntraSpeciesReaction_t * isr)
 
 LIBSBML_CPP_NAMESPACE_END
 
+#endif /*__cplusplus */
+
 
