@@ -35,6 +35,8 @@
 using namespace std;
 
 
+#ifdef __cplusplus
+
 LIBSBML_CPP_NAMESPACE_BEGIN
 
 
@@ -43,9 +45,9 @@ LIBSBML_CPP_NAMESPACE_BEGIN
  */
 SpeciesTypeComponentIndex::SpeciesTypeComponentIndex (unsigned int level, unsigned int version, unsigned int pkgVersion)
   : SBase(level, version)
-   ,mId ("")
+////   ,mId ("")
    ,mComponent ("")
-   ,mIdentifyingParent ("")
+////   ,mIdentifyingParent ("")
 {
   // set an SBMLNamespaces derived object of this package
   setSBMLNamespacesAndOwn(new MultiPkgNamespaces(level, version, pkgVersion));
@@ -57,9 +59,9 @@ SpeciesTypeComponentIndex::SpeciesTypeComponentIndex (unsigned int level, unsign
  */
 SpeciesTypeComponentIndex::SpeciesTypeComponentIndex (MultiPkgNamespaces* multins)
   : SBase(multins)
-   ,mId ("")
+////   ,mId ("")
    ,mComponent ("")
-   ,mIdentifyingParent ("")
+////   ,mIdentifyingParent ("")
 {
   // set the element namespace of this object
   setElementNamespace(multins->getURI());
@@ -74,9 +76,9 @@ SpeciesTypeComponentIndex::SpeciesTypeComponentIndex (MultiPkgNamespaces* multin
  */
 SpeciesTypeComponentIndex::SpeciesTypeComponentIndex (const SpeciesTypeComponentIndex& orig)
   : SBase(orig)
-  , mId  ( orig.mId)
+//  , mId  ( orig.mId)
   , mComponent  ( orig.mComponent)
-  , mIdentifyingParent  ( orig.mIdentifyingParent)
+//  , mIdentifyingParent  ( orig.mIdentifyingParent)
 {
 }
 
@@ -126,6 +128,16 @@ SpeciesTypeComponentIndex::getId() const
 }
 
 
+/*
+ * Returns the value of the "name" attribute of this SpeciesTypeComponentIndex.
+ */
+const std::string&
+SpeciesTypeComponentIndex::getName() const
+{
+  return mName;
+}
+
+
 /*
  * Returns the value of the "component" attribute of this SpeciesTypeComponentIndex.
  */
@@ -156,6 +168,16 @@ SpeciesTypeComponentIndex::isSetId() const
 }
 
 
+/*
+ * Returns true/false if name is set.
+ */
+bool
+SpeciesTypeComponentIndex::isSetName() const
+{
+  return (mName.empty() == false);
+}
+
+
 /*
  * Returns true/false if component is set.
  */
@@ -186,6 +208,17 @@ SpeciesTypeComponentIndex::setId(const std::string& id)
 }
 
 
+/*
+ * Sets name and returns value indicating success.
+ */
+int
+SpeciesTypeComponentIndex::setName(const std::string& name)
+{
+  mName = name;
+  return LIBSBML_OPERATION_SUCCESS;
+}
+
+
 /*
  * Sets component and returns value indicating success.
  */
@@ -241,6 +274,25 @@ SpeciesTypeComponentIndex::unsetId()
 }
 
 
+/*
+ * Unsets name and returns value indicating success.
+ */
+int
+SpeciesTypeComponentIndex::unsetName()
+{
+  mName.erase();
+
+  if (mName.empty() == true)
+  {
+    return LIBSBML_OPERATION_SUCCESS;
+  }
+  else
+  {
+    return LIBSBML_OPERATION_FAILED;
+  }
+}
+
+
 /*
  * Unsets component and returns value indicating success.
  */
@@ -352,7 +404,7 @@ SpeciesTypeComponentIndex::writeElements (XMLOutputStream& stream) const
 }
 
 
-  /** @endcond doxygenLibsbmlInternal */
+  /** @endcond */
 
 
   /** @cond doxygenLibsbmlInternal */
@@ -369,7 +421,7 @@ SpeciesTypeComponentIndex::accept (SBMLVisitor& v) const
 }
 
 
-  /** @endcond doxygenLibsbmlInternal */
+  /** @endcond */
 
 
   /** @cond doxygenLibsbmlInternal */
@@ -384,7 +436,7 @@ SpeciesTypeComponentIndex::setSBMLDocument (SBMLDocument* d)
 }
 
 
-  /** @endcond doxygenLibsbmlInternal */
+  /** @endcond */
 
 
   /** @cond doxygenLibsbmlInternal */
@@ -400,7 +452,7 @@ SpeciesTypeComponentIndex::enablePackageInternal(const std::string& pkgURI,
 }
 
 
-  /** @endcond doxygenLibsbmlInternal */
+  /** @endcond */
 
 
   /** @cond doxygenLibsbmlInternal */
@@ -422,7 +474,7 @@ SpeciesTypeComponentIndex::createObject(XMLInputStream& stream)
 }
 
 
-  /** @endcond doxygenLibsbmlInternal */
+  /** @endcond */
 
 
   /** @cond doxygenLibsbmlInternal */
@@ -436,12 +488,13 @@ SpeciesTypeComponentIndex::addExpectedAttributes(ExpectedAttributes& attributes)
   SBase::addExpectedAttributes(attributes);
 
   attributes.add("id");
+  attributes.add("name");
   attributes.add("component");
   attributes.add("identifyingParent");
 }
 
 
-  /** @endcond doxygenLibsbmlInternal */
+  /** @endcond */
 
 
   /** @cond doxygenLibsbmlInternal */
@@ -553,6 +606,22 @@ SpeciesTypeComponentIndex::readAttributes (const XMLAttributes& attributes,
                    getLine(), getColumn());
   }
 
+   //
+   // name string   ( use = "optional" )
+   //
+   assigned = attributes.readInto("name", mName);
+
+   if (assigned == true)
+   {
+     // check string is not empty
+
+     if (mName.empty() == true)
+     {
+       logEmptyString(mName, getLevel(), getVersion(), "<SpeciesTypeComponentIndex>");
+     }
+   }
+
+
   //
   // component SIdRef   ( use = "required" )
   //
@@ -607,7 +676,7 @@ SpeciesTypeComponentIndex::readAttributes (const XMLAttributes& attributes,
 }
 
 
-  /** @endcond doxygenLibsbmlInternal */
+  /** @endcond */
 
 
   /** @cond doxygenLibsbmlInternal */
@@ -634,7 +703,7 @@ SpeciesTypeComponentIndex::writeAttributes (XMLOutputStream& stream) const
 }
 
 
-  /** @endcond doxygenLibsbmlInternal */
+  /** @endcond */
 
 
 /*
@@ -798,7 +867,7 @@ ListOfSpeciesTypeComponentIndexes::createObject(XMLInputStream& stream)
 }
 
 
-  /** @endcond doxygenLibsbmlInternal */
+  /** @endcond */
 
 
   /** @cond doxygenLibsbmlInternal */
@@ -826,7 +895,7 @@ ListOfSpeciesTypeComponentIndexes::writeXMLNS(XMLOutputStream& stream) const
 }
 
 
-  /** @endcond doxygenLibsbmlInternal */
+  /** @endcond */
 
 
 /**
@@ -885,6 +954,20 @@ SpeciesTypeComponentIndex_getId(SpeciesTypeComponentIndex_t * stci)
 }
 
 
+/**
+ *
+ */
+LIBSBML_EXTERN
+char *
+SpeciesTypeComponentIndex_getName(SpeciesTypeComponentIndex_t * cr)
+{
+  if (cr == NULL)
+    return NULL;
+
+  return cr->getName().empty() ? NULL : safe_strdup(cr->getName().c_str());
+}
+
+
 /**
  * 
  */
@@ -924,6 +1007,17 @@ SpeciesTypeComponentIndex_isSetId(SpeciesTypeComponentIndex_t * stci)
 }
 
 
+/**
+ *
+ */
+LIBSBML_EXTERN
+int
+SpeciesTypeComponentIndex_isSetName(SpeciesTypeComponentIndex_t * cr)
+{
+  return (cr != NULL) ? static_cast<int>(cr->isSetName()) : 0;
+}
+
+
 /**
  * 
  */
@@ -957,6 +1051,17 @@ SpeciesTypeComponentIndex_setId(SpeciesTypeComponentIndex_t * stci, const char *
 }
 
 
+/**
+ *
+ */
+LIBSBML_EXTERN
+int
+SpeciesTypeComponentIndex_setName(SpeciesTypeComponentIndex_t * cr, const char * name)
+{
+  return (cr != NULL) ? cr->setName(name) : LIBSBML_INVALID_OBJECT;
+}
+
+
 /**
  * 
  */
@@ -990,6 +1095,17 @@ SpeciesTypeComponentIndex_unsetId(SpeciesTypeComponentIndex_t * stci)
 }
 
 
+/**
+ *
+ */
+LIBSBML_EXTERN
+int
+SpeciesTypeComponentIndex_unsetName(SpeciesTypeComponentIndex_t * cr)
+{
+  return (cr != NULL) ? cr->unsetName() : LIBSBML_INVALID_OBJECT;
+}
+
+
 /**
  * 
  */
@@ -1055,4 +1171,6 @@ ListOfSpeciesTypeComponentIndexes_removeById(ListOf_t * lo, const char * sid)
 
 LIBSBML_CPP_NAMESPACE_END
 
+#endif /*__cplusplus */
+
 
