@@ -36,6 +36,8 @@
 using namespace std;
 
 
+#ifdef __cplusplus
+
 LIBSBML_CPP_NAMESPACE_BEGIN
 
 
@@ -1284,4 +1286,6 @@ ListOfSpeciesTypeComponentMapInProducts_removeById(ListOf_t * lo, const char * s
 
 LIBSBML_CPP_NAMESPACE_END
 
+#endif /*__cplusplus */
+
 
