@@ -38,6 +38,8 @@
 using namespace std;
 
 
+#ifdef __cplusplus
+
 LIBSBML_CPP_NAMESPACE_BEGIN
 
 /*
@@ -782,3 +784,5 @@ Relation_fromString(const char* s)
 
 LIBSBML_CPP_NAMESPACE_END
 
+#endif /*__cplusplus */
+
