@@ -10,7 +10,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -257,11 +257,6 @@ MultiIdBase::checkId (const SpeciesFeature& x)
   if (x.isSetId()) doCheckId(x.getId(), x);
 }
 
-void
-MultiIdBase::checkId (const SpeciesFeatureChange& x)
-{
-  if (x.isSetId()) doCheckId(x.getId(), x);
-}
 
 void
 MultiIdBase::checkId (const CompartmentReference& x)
@@ -269,12 +264,6 @@ MultiIdBase::checkId (const CompartmentReference& x)
   if (x.isSetId()) doCheckId(x.getId(), x);
 }
 
-//void
-//MultiIdBase::checkId (const SBase& x)
-//{
-//  if (x.isSetSymbol()) doCheckId(x.getSymbol(), x);
-//}
-
 
 /*
  * @return the typename of the given SBase object.
