@@ -10,7 +10,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -176,9 +176,7 @@ protected:
   void checkId (const SubListOfSpeciesFeatures&  x);
   void checkId (const PossibleSpeciesFeatureValue&  x);
   void checkId (const SpeciesFeature&  x);
-  void checkId (const SpeciesFeatureChange&  x);
   void checkId (const CompartmentReference&  x);
-//  void checkId (const SBase&    x);
 
   /**
    * Returns a non-owning character pointer to the typename of the given SBase 
