@@ -125,16 +125,16 @@ const string
 QualCSymbolMathCheck::getMessage (const ASTNode& node, const SBase& object)
 {
 
-  ostringstream msg;
+  ostringstream oss_msg;
 
-  //msg << getPreamble();
+  //oss_msg << getPreamble();
   char * formula = SBML_formulaToString(&node);
-  msg << "The formula '" << formula;
-  msg << "' in the math element of the <" << object.getElementName();
-  msg << "> uses a csymbol.";
+  oss_msg << "The formula '" << formula;
+  oss_msg << "' in the math element of the <" << object.getElementName();
+  oss_msg << "> uses a csymbol.";
   safe_free(formula);
 
-  return msg.str();
+  return oss_msg.str();
 }
 
 LIBSBML_CPP_NAMESPACE_END
