@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -135,6 +135,7 @@ const char* SBML_RENDER_TYPECODE_STRINGS[] =
   , "Point"
   , "Text"
   , "Transformation2D"
+  , "DefaultValues"
 
 };
 
@@ -215,7 +216,7 @@ RenderExtension::getURI(unsigned int sbmlLevel, unsigned int sbmlVersion, unsign
 {
   if (sbmlLevel == 3)
   {
-    if (sbmlVersion == 1)
+    if (sbmlVersion == 1 || sbmlVersion == 2)
     {
       if (pkgVersion == 1)
       {
@@ -343,7 +344,7 @@ const char*
 RenderExtension::getStringFromTypeCode(int typeCode) const
 {
   int min = SBML_RENDER_COLORDEFINITION;
-  int max = SBML_RENDER_TRANSFORMATION2D;
+  int max = SBML_RENDER_DEFAULTS;
 
   if ( typeCode < min || typeCode > max)
   {
