@@ -166,7 +166,7 @@ void
   RenderLayoutPlugin::writeElements (XMLOutputStream& stream) const
 {
   if ( getURI() == RenderExtension::getXmlnsL2() ) return;
-  if (mLocalRenderInformation.size() > 0)
+  if (mLocalRenderInformation.size() > 0 || mLocalRenderInformation.isSetDefaultValues())
     mLocalRenderInformation.write(stream);
 }
 /** @endcond */
