@@ -29,6 +29,7 @@
 #include <sbml/packages/render/extension/RenderListOfLayoutsPlugin.h>
 #include <sbml/packages/layout/common/LayoutExtensionTypes.h>
 #include <sbml/packages/render/util/RenderUtilities.h>
+#include <sbml/packages/render/sbml/GlobalRenderInformation.h>
 #include <sbml/util/ElementFilter.h>
 
 
@@ -188,7 +189,7 @@ void
   RenderListOfLayoutsPlugin::writeElements (XMLOutputStream& stream) const
 {
     if ( getURI() == RenderExtension::getXmlnsL2() ) return;
-  if (mGlobalRenderInformation.size() > 0)
+  if (mGlobalRenderInformation.size() > 0 || mGlobalRenderInformation.isSetDefaultValues())
     mGlobalRenderInformation.write(stream);
 }
 /** @endcond */
