@@ -494,6 +494,7 @@ ColorDefinition::addExpectedAttributes(ExpectedAttributes& attributes)
   SBase::addExpectedAttributes(attributes);
 
   attributes.add("id");
+  attributes.add("name");
   attributes.add("value");
 }
 /** @endcond */
@@ -504,6 +505,7 @@ void ColorDefinition::readAttributes (const XMLAttributes& attributes, const Exp
   SBase::readAttributes(attributes,expectedAttributes);
   std::string valueString;
   attributes.readInto("id", mId, getErrorLog(), false, getLine(), getColumn());
+  attributes.readInto("name", mName, getErrorLog(), false, getLine(), getColumn());
   attributes.readInto("value", valueString, getErrorLog(), false, getLine(), getColumn());
   this->setColorValue(valueString);
 }
@@ -542,6 +544,8 @@ void ColorDefinition::writeAttributes (XMLOutputStream& stream) const
 {
   SBase::writeAttributes(stream);
   stream.writeAttribute("id", getPrefix(), this->getId());
+  if (isSetName())
+  stream.writeAttribute("name", getPrefix(), this->getName());
   stream.writeAttribute("value", getPrefix(), this->createValueString());
 }
 /** @endcond */
@@ -875,6 +879,68 @@ int ColorDefinition::unsetId ()
 }
 /** @endcond */
 
+
+/** @cond doxygenLibsbmlInternal */
+/*
+ * Returns the value of the "name" attribute of this ColorDefinition.
+ *
+ * @return the name of the ColorDefinition
+ */
+const std::string& ColorDefinition::getName () const
+{
+    return mName;
+}
+/** @endcond */
+
+
+/** @cond doxygenLibsbmlInternal */
+/*
+ * Predicate returning @c true or @c false depending on whether this
+ * ColorDefinition's "name" attribute has been set.
+ *
+ * @return returns true or false depending on whether the name on the 
+ * ColorDefinition has been set.
+ */
+bool ColorDefinition::isSetName () const
+{
+    return (mName.empty() == false);
+}
+/** @endcond */
+
+/** @cond doxygenLibsbmlInternal */
+/*
+ * Sets the value of the "name" attribute of this ColorDefinition.
+ *
+ * @param name the new name for the ColorDefinition 
+ *
+ * @return status if the operation succeeded
+ */
+int ColorDefinition::setName (const std::string& name)
+{
+    mName = name;
+    return LIBSBML_OPERATION_SUCCESS;
+}
+/** @endcond */
+
+
+/** @cond doxygenLibsbmlInternal */
+/*
+ * Unsets the value of the "name" attribute of this ColorDefinition.
+ */
+int ColorDefinition::unsetName ()
+{
+    mName.erase();
+    if (mName.empty())
+  {
+    return LIBSBML_OPERATION_SUCCESS;
+  }
+  else
+  {
+    return LIBSBML_OPERATION_FAILED;
+  }
+}
+/** @endcond */
+
 /** @cond doxygenLibsbmlInternal */
 /*
  * Returns a pointer to the ColorDefinition with the given index or NULL if
