@@ -369,6 +369,41 @@ public:
    */
   virtual int unsetId ();
 
+
+  /**
+   * Returns the value of the "name" attribute of this ColorDefinition.
+   *
+   * @return the name of the ColorDefinition
+   */
+  const std::string& getName () const;
+
+
+  /**
+   * Predicate returning @c true or @c false depending on whether this
+   * ColorDefinition's "name" attribute has been set.
+   *
+   * @return returns true or false depending on whether the name on the 
+   * ColorDefinition has been set.
+   */
+  bool isSetName () const;
+
+
+  /**
+   * Sets the value of the "name" attribute of this ColorDefinition.
+   *
+   * @param name the new name for the ColorDefinition 
+   *
+   * @return status if the operation succeeded
+   */
+  int setName (const std::string& id);
+
+
+  /**
+   * Unsets the value of the "name" attribute of this ColorDefinition.
+   */
+  virtual int unsetName ();
+
+  
   /** @cond doxygenLibsbmlInternal */
   /* function returns true if component has all the required
    * attributes
