@@ -70,6 +70,8 @@ protected:
   RelAbsVector mRX;
   RelAbsVector mRY;
   static const std::string ELEMENT_NAME;
+  double mRatio;
+  bool mIsSetRatio;
   /** @endcond */
 
 public:
@@ -366,6 +368,47 @@ public:
    */
   void setRadii(const RelAbsVector& rx,const RelAbsVector& ry);
 
+
+  /**
+  * Returns the value of the "ratio" attribute of this Ellipse.
+  *
+  * @return the value of the "ratio" attribute of this Ellipse as a double.
+  */
+  double getRatio() const;
+
+
+  /**
+  * Predicate returning @c true if this Ellipse's "ratio" attribute is set.
+  *
+  * @return @c true if this Ellipse's "ratio" attribute has been set,
+  * otherwise @c false is returned.
+  */
+  bool isSetRatio() const;
+
+
+  /**
+  * Sets the value of the "ratio" attribute of this Ellipse.
+  *
+  * @param ratio double value of the "ratio" attribute to be set.
+  *
+  * @copydetails doc_returns_success_code
+  * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+  * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE,
+  * OperationReturnValues_t}
+  */
+  int setRatio(double ratio);
+
+
+  /**
+  * Unsets the value of the "ratio" attribute of this Ellipse.
+  *
+  * @copydetails doc_returns_success_code
+  * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+  * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+  */
+  int unsetRatio();
+
+
   /** @cond doxygenLibsbmlInternal */
   /**
    * Subclasses should override this method to write out their contained
