@@ -82,7 +82,8 @@ public:
   {
     PAD,
     REFLECT,
-    REPEAT
+    REPEAT, 
+    INVALID
   };
 
 
@@ -394,6 +395,40 @@ public:
   virtual int unsetId ();
 
 
+  /**
+   * Returns the value of the "name" attribute of this GradientBase.
+   *
+   * @return the name of the GradientBase
+   */
+  const std::string& getName () const;
+
+
+  /**
+   * Predicate returning @c true or @c false depending on whether this
+   * GradientBase's "name" attribute has been set.
+   *
+   * @return returns true or false depending on whether the name on the 
+   * GradientBase has been set.
+   */
+  bool isSetName () const;
+
+
+  /**
+   * Sets the value of the "name" attribute of this GradientBase.
+   *
+   * @param name the new name for the GradientBase 
+   *
+   * @return status if the operation succeeded
+   */
+  int setName (const std::string& name);
+
+
+  /**
+   * Unsets the value of the "name" attribute of this GradientBase.
+   */
+  virtual int unsetName ();
+
+
   /**
    * Sets the parent SBML object of this SBML object.
    *
@@ -677,4 +712,19 @@ LIBSBML_CPP_NAMESPACE_END
 
 #endif /* __cplusplus */
 
+LIBSBML_CPP_NAMESPACE_BEGIN
+BEGIN_C_DECLS
+
+LIBSBML_EXTERN
+GradientBase::SPREADMETHOD
+SpreadMethod_fromString(const char* name);
+
+LIBSBML_EXTERN
+const char*
+SpreadMethod_toString(GradientBase::SPREADMETHOD method);
+
+END_C_DECLS
+LIBSBML_CPP_NAMESPACE_END
+
+
 #endif /* GradientBase_H__ */
