@@ -291,6 +291,7 @@ void GraphicalPrimitive2D::writeAttributes (XMLOutputStream& stream) const
             stream.writeAttribute("fill-rule", getPrefix(), "nonzero");
             break;
         case GraphicalPrimitive2D::UNSET:
+        default:
             break;
     }
 }
@@ -322,6 +323,7 @@ void GraphicalPrimitive2D::addGraphicalPrimitive2DAttributes(const GraphicalPrim
             // it is assumed to be inherited.
             att.add("fill-rule","nonzero");
             break;
+        default:
         case GraphicalPrimitive2D::UNSET:
             break;
     }
@@ -375,4 +377,45 @@ bool GraphicalPrimitive2D::isSetFillRule() const
 }
 /** @endcond */
 
+
+const char* FILL_RULE_STRINGS[] =
+{
+  "unset",
+  "nonzero",
+  "evenodd", 
+  "inherit", 
+  "invalid"
+};
+
+
+
+LIBSBML_EXTERN
+GraphicalPrimitive2D::FILL_RULE
+FillRule_fromString(const char* name)
+{
+  if (name != NULL)
+  {
+    const GraphicalPrimitive2D::FILL_RULE  lo = GraphicalPrimitive2D::UNSET;
+    const GraphicalPrimitive2D::FILL_RULE  hi = GraphicalPrimitive2D::INHERIT;
+
+    return (GraphicalPrimitive2D::FILL_RULE)util_bsearchStringsI(FILL_RULE_STRINGS, name, lo, hi);
+  }
+
+  return GraphicalPrimitive2D::UNSET;
+
+}
+
+LIBSBML_EXTERN
+const char*
+FillRule_toString(GraphicalPrimitive2D::FILL_RULE rule)
+{
+  if ((rule < GraphicalPrimitive2D::UNSET) || (rule > GraphicalPrimitive2D::INHERIT))
+  {
+    rule = GraphicalPrimitive2D::INVALID;
+  }
+
+  return FILL_RULE_STRINGS[rule];
+}
+
+
 LIBSBML_CPP_NAMESPACE_END 
