@@ -66,7 +66,8 @@ public:
     UNSET,
     NONZERO,
     EVENODD,
-    INHERIT
+    INHERIT,
+    INVALID
   };
 
 protected:
@@ -249,4 +250,21 @@ LIBSBML_CPP_NAMESPACE_END
 
 #endif /* __cplusplus */
 
+
+
+LIBSBML_CPP_NAMESPACE_BEGIN
+BEGIN_C_DECLS
+
+LIBSBML_EXTERN
+GraphicalPrimitive2D::FILL_RULE
+FillRule_fromString(const char* name);
+
+LIBSBML_EXTERN
+const char*
+FillRule_toString(GraphicalPrimitive2D::FILL_RULE rule);
+
+END_C_DECLS
+LIBSBML_CPP_NAMESPACE_END
+
+
 #endif /* GraphicalPrimitive2D_H__ */
