@@ -59,6 +59,8 @@ protected:
   RelAbsVector mRX;
   RelAbsVector mRY;
   static const std::string ELEMENT_NAME;
+  double mRatio;
+  bool mIsSetRatio;
   /** @endcond */
 
 public:
@@ -164,6 +166,48 @@ public:
   Rectangle(RenderPkgNamespaces* renderns, const std::string& id,const RelAbsVector& x,const RelAbsVector& y,const RelAbsVector& w,const RelAbsVector& h);
 #endif // OMIT_DEPRECATED
 
+
+  /**
+  * Returns the value of the "ratio" attribute of this Rectangle.
+  *
+  * @return the value of the "ratio" attribute of this Rectangle as a double.
+  */
+  double getRatio() const;
+
+
+  /**
+  * Predicate returning @c true if this Rectangle's "ratio" attribute is set.
+  *
+  * @return @c true if this Rectangle's "ratio" attribute has been set,
+  * otherwise @c false is returned.
+  */
+  bool isSetRatio() const;
+
+
+  /**
+  * Sets the value of the "ratio" attribute of this Rectangle.
+  *
+  * @param ratio double value of the "ratio" attribute to be set.
+  *
+  * @copydetails doc_returns_success_code
+  * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+  * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE,
+  * OperationReturnValues_t}
+  */
+  int setRatio(double ratio);
+
+
+  /**
+  * Unsets the value of the "ratio" attribute of this Rectangle.
+  *
+  * @copydetails doc_returns_success_code
+  * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+  * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+  */
+  int unsetRatio();
+
+
+
   /**
    * Sets the position and the size of the Rectangle within the viewport.
    *
