@@ -51,9 +51,12 @@ LIBSBML_CPP_NAMESPACE_BEGIN
  * @param a absolute value
  * @param a relative value in % (50 -> 50%)
  */
-RelAbsVector::RelAbsVector(double a,double r):mAbs(a),mRel(r)
+RelAbsVector::RelAbsVector(double a, double r)
+  : mAbs(a)
+  , mRel(r)
 {
 }
+
 /** @endcond */
 
 /** @cond doxygenLibsbmlInternal */
@@ -62,9 +65,12 @@ RelAbsVector::RelAbsVector(double a,double r):mAbs(a),mRel(r)
  * If the string does not represent a valid value, the relative and the
  * absolute component of the RelAbsVector are set to NaN.
  */
-RelAbsVector::RelAbsVector(const std::string& coordString):mAbs(0.0),mRel(0.0)
+RelAbsVector::RelAbsVector(const std::string& coordString)
+  : mAbs(0.0)
+  , mRel(0.0)
 {
-    setCoordinate(coordString);
+  if (!coordString.empty())
+  setCoordinate(coordString);
 }
 /** @endcond */
 
@@ -333,6 +339,21 @@ RelAbsVector& RelAbsVector::operator=(const RelAbsVector& src)
     }
     return *this;
 }
+bool RelAbsVector::empty() const
+{
+  return ((mAbs == 0.0 || util_isNaN(mAbs)) && (mRel == 0.0 || util_isNaN(mRel)));
+}
+std::string RelAbsVector::toString() const
+{
+  std::stringstream str;
+  str << *this;
+  return str.str();
+}
+void RelAbsVector::erase()
+{
+  mAbs = 0;
+  mRel = 0;
+}
 /** @endcond */
 
 LIBSBML_CPP_NAMESPACE_END 
