@@ -8,7 +8,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -55,8 +55,6 @@ LIBSBML_CPP_NAMESPACE_BEGIN
  */
 RenderInformationBase::RenderInformationBase (unsigned int level, unsigned int version, unsigned int pkgVersion)
   : SBase(level,version)
-  , mId("")
-  , mName ("")
   , mProgramName ("")
   , mProgramVersion ("")
   , mReferenceRenderInformation ("")
@@ -79,8 +77,6 @@ RenderInformationBase::RenderInformationBase (unsigned int level, unsigned int v
  */
 RenderInformationBase::RenderInformationBase (RenderPkgNamespaces* renderns)
   : SBase(renderns)
-  , mId("")
-  , mName ("")
   , mProgramName ("")
   , mProgramVersion ("")
   , mReferenceRenderInformation ("")
@@ -151,11 +147,7 @@ void RenderInformationBase::readAttributes (const XMLAttributes& attributes, con
     attributes.readInto("programName", mProgramName, getErrorLog(), false, getLine(), getColumn());
     attributes.readInto("programVersion", mProgramVersion, getErrorLog(), false, getLine(), getColumn());
     attributes.readInto("referenceRenderInformation", mReferenceRenderInformation, getErrorLog(), false, getLine(), getColumn());
-    if(!attributes.readInto("backgroundColor",mBackgroundColor, getErrorLog(), false, getLine(), getColumn()))
-    {
-        // make white the default background  
-        mBackgroundColor="#FFFFFFFF";
-    }
+    attributes.readInto("backgroundColor", mBackgroundColor, getErrorLog(), false, getLine(), getColumn());
 }
 /** @endcond */
 
@@ -224,12 +216,10 @@ void RenderInformationBase::parseXML(const XMLNode& node)
  */
 RenderInformationBase::RenderInformationBase(RenderPkgNamespaces* renderns, const std::string& id)
   : SBase(renderns)
-  , mId(id)
-  , mName ("")
   , mProgramName ("")
   , mProgramVersion ("")
   , mReferenceRenderInformation ("")
-  , mBackgroundColor("#FFFFFFFF")
+  , mBackgroundColor("")
   , mListOfColorDefinitions(renderns) 
   , mListOfGradientDefinitions(renderns) 
   , mListOfLineEndings(renderns) 
@@ -237,6 +227,7 @@ RenderInformationBase::RenderInformationBase(RenderPkgNamespaces* renderns, cons
 #ifdef DEPRECATION_WARNINGS
     std::cerr << "Warning. RenderInformationBase::RenderInformationBase(const std::string& id) is deprecated." << std::endl;
 #endif // DEPRECATION_WARNINGS
+    setId(id);
         // set the element namespace of this object
   setElementNamespace(renderns->getURI());
 
@@ -331,6 +322,17 @@ void RenderInformationBase::setReferenceRenderInformationId(const std::string& i
 }
 /** @endcond */
 
+bool RenderInformationBase::isSetReferenceRenderInformation() const
+{
+  return !mReferenceRenderInformation.empty();
+}
+
+int RenderInformationBase::unsetReferenceRenderInformation()
+{
+  mReferenceRenderInformation.erase();
+  return LIBSBML_OPERATION_SUCCESS;
+}
+
 /** @cond doxygenLibsbmlInternal */
 /*
  * Returns the number of color definitions.
@@ -1057,7 +1059,8 @@ int RenderInformationBase::addLineEnding(const LineEnding* le)
 void RenderInformationBase::writeAttributes (XMLOutputStream& stream) const
 {
   SBase::writeAttributes(stream);
-  stream.writeAttribute("id", getPrefix(), this->mId);
+  if (isSetId())
+    stream.writeAttribute("id", getPrefix(), this->mId);
   if(this->isSetName())
   {
       stream.writeAttribute("name", getPrefix(), this->mName);
@@ -1125,6 +1128,11 @@ const std::string& RenderInformationBase::getBackgroundColor() const
 }
 /** @endcond */
 
+bool RenderInformationBase::isSetBackgroundColor() const
+{
+  return !mBackgroundColor.empty();
+}
+
 /** @cond doxygenLibsbmlInternal */
 /*
  * Sets the background color to either the id of a color in the list of
@@ -1137,6 +1145,12 @@ void RenderInformationBase::setBackgroundColor(const std::string& bg)
     this->mBackgroundColor=bg;
 }
 
+int RenderInformationBase::unsetBackgroundColor()
+{
+  mBackgroundColor.erase();
+  return LIBSBML_OPERATION_SUCCESS;
+}
+
 /** @cond doxygenLibsbmlInternal */
 /*
  * Returns the value of the "id" attribute of this RenderInformationBase.
