@@ -74,8 +74,6 @@ class LIBSBML_EXTERN RenderInformationBase:public SBase
 {
 protected:
   /** @cond doxygenLibsbmlInternal */
-////  std::string mId;
-////  std::string mName;
   std::string mProgramName;
   std::string mProgramVersion;
   std::string mReferenceRenderInformation;
@@ -111,7 +109,7 @@ protected:
    * This method should never be called by the user. It is only used to read render 
    * information from annotations.
    *
-   * @param node the XMLNode object reference that describes the RenderInfromationBase
+   * @param node the XMLNode object reference that describes the RenderinformationBase
    * object to be instantiated.
    */
   void parseXML(const XMLNode& pNode); 
@@ -168,7 +166,7 @@ public:
   /**
    * Sets the name of the program that created the render information.
    *
-   * @param name the name of the programm
+   * @param name the name of the program
    */
   void setProgramName(const std::string& name);
 
@@ -188,28 +186,50 @@ public:
 
   /**
    * Returns the id of the referenced render information object.
-   * RenderInfromation objects can reference other render information objects
+   * Renderinformation objects can reference other render information objects
    * and information that is not found in the current render information is then
    * expected to be in the referenced render information object.
    *
    * Global render information objects can only reference other global 
    * render information objects, local render information objects can reference other local
    * render information objects from the same list of local render information or other
-   * global render infromation.
+   * global render information.
    *
-   * @return the id of the referenced render infromation object.
+   * @return the id of the referenced render information object.
    */
   const std::string& getReferenceRenderInformationId() const;
 
   /**
    * Sets the id of the referenced render information object.
-   * The user has to make sure that render infromation referencing 
+   * The user has to make sure that render information referencing 
    * does not create loops.
    *
-   * @param id the id of the referenced render infromation
+   * @param id the id of the referenced render information
    */
   void setReferenceRenderInformationId(const std::string& id);
 
+  /**
+  * Predicate returning @c true if this RenderInformationBase's
+  * "referenceRenderInformation" attribute is set.
+  *
+  * @return @c true if this RenderInformationBase's
+  * "referenceRenderInformation" attribute has been set, otherwise @c false is
+  * returned.
+  */
+  bool isSetReferenceRenderInformation() const;
+
+
+  /**
+  * Unsets the value of the "referenceRenderInformation" attribute of this
+  * RenderInformationBase.
+  *
+  * @copydetails doc_returns_success_code
+  * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+  * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+  */
+  int unsetReferenceRenderInformation();
+
+
   /**
    * Returns the number of color definitions.
    *
@@ -593,6 +613,15 @@ public:
    */
   const std::string& getBackgroundColor() const;
 
+  /**
+  * Predicate returning @c true if this RenderInformationBase's
+  * "backgroundColor" attribute is set.
+  *
+  * @return @c true if this RenderInformationBase's "backgroundColor"
+  * attribute has been set, otherwise @c false is returned.
+  */
+  bool isSetBackgroundColor() const;
+
   /**
    * Sets the background color to either the id of a color in the list of
    * color definitions, or a color value.
@@ -601,6 +630,17 @@ public:
    */
   void setBackgroundColor(const std::string& bg);
 
+  /**
+  * Unsets the value of the "backgroundColor" attribute of this
+  * RenderInformationBase.
+  *
+  * @copydetails doc_returns_success_code
+  * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+  * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+  */
+  int unsetBackgroundColor();
+
+
   /**
    * Returns the value of the "id" attribute of this RenderInformationBase.
    *
@@ -659,7 +699,7 @@ public:
    *
    * @return status if the operation succeeded
    */
-  int setName (const std::string& id);
+  int setName (const std::string& name);
 
 
   /**
@@ -735,7 +775,7 @@ protected:
 
   /** @cond doxygenLibsbmlInternal */
   /**
-   * Reads in RenderInfromationBase specific attributes from the given XMLAttributes object.
+   * Reads in RenderinformationBase specific attributes from the given XMLAttributes object.
    */
   virtual void readAttributes (const XMLAttributes& attributes, const ExpectedAttributes& expectedAttributes);
   /** @endcond */
