@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2016 jointly by the following organizations:
+ * Copyright (C) 2013-2017 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -47,8 +47,8 @@ LIBSBML_CPP_NAMESPACE_BEGIN
  */
 ChangedMath::ChangedMath (unsigned int level, unsigned int version, unsigned int pkgVersion)
   : SBase(level, version)
-   ,mId ("")
-   ,mName ("")
+////   ,mId ("")
+////   ,mName ("")
    ,mChangedBy ("")
    ,mViableWithoutChange (false)
    ,mIsSetViableWithoutChange (false)
@@ -63,8 +63,8 @@ ChangedMath::ChangedMath (unsigned int level, unsigned int version, unsigned int
  */
 ChangedMath::ChangedMath (ReqPkgNamespaces* reqns)
   : SBase(reqns)
-   ,mId ("")
-   ,mName ("")
+////   ,mId ("")
+////   ,mName ("")
    ,mChangedBy ("")
    ,mViableWithoutChange (false)
    ,mIsSetViableWithoutChange (false)
@@ -82,8 +82,8 @@ ChangedMath::ChangedMath (ReqPkgNamespaces* reqns)
  */
 ChangedMath::ChangedMath (const ChangedMath& orig)
   : SBase(orig)
-  , mId  ( orig.mId)
-  , mName  ( orig.mName)
+//  , mId  ( orig.mId)
+//  , mName  ( orig.mName)
   , mChangedBy  ( orig.mChangedBy)
   , mViableWithoutChange  ( orig.mViableWithoutChange)
   , mIsSetViableWithoutChange  ( orig.mIsSetViableWithoutChange)
