@@ -729,13 +729,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 AdjacentDomains_t *
-AdjacentDomains_create(
-                       unsigned int level =
-                         SpatialExtension::getDefaultLevel(),
-                       unsigned int version =
-                         SpatialExtension::getDefaultVersion(),
-                       unsigned int pkgVersion =
-                         SpatialExtension::getDefaultPackageVersion());
+AdjacentDomains_create(unsigned int level,
+                       unsigned int version,
+                       unsigned int pkgVersion);
 
 
 /**
