@@ -886,13 +886,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 AnalyticGeometry_t *
-AnalyticGeometry_create(
-                        unsigned int level =
-                          SpatialExtension::getDefaultLevel(),
-                        unsigned int version =
-                          SpatialExtension::getDefaultVersion(),
-                        unsigned int pkgVersion =
-                          SpatialExtension::getDefaultPackageVersion());
+AnalyticGeometry_create(unsigned int level,
+                        unsigned int version,
+                        unsigned int pkgVersion);
 
 
 /**
