@@ -886,11 +886,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 AnalyticVolume_t *
-AnalyticVolume_create(unsigned int level = SpatialExtension::getDefaultLevel(),
-                      unsigned int version =
-                        SpatialExtension::getDefaultVersion(),
-                      unsigned int pkgVersion =
-                        SpatialExtension::getDefaultPackageVersion());
+AnalyticVolume_create(unsigned int level,
+                      unsigned int version,
+                      unsigned int pkgVersion);
 
 
 /**
