@@ -806,13 +806,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 BoundaryCondition_t *
-BoundaryCondition_create(
-                         unsigned int level =
-                           SpatialExtension::getDefaultLevel(),
-                         unsigned int version =
-                           SpatialExtension::getDefaultVersion(),
-                         unsigned int pkgVersion =
-                           SpatialExtension::getDefaultPackageVersion());
+BoundaryCondition_create(unsigned int level,
+                         unsigned int version,
+                         unsigned int pkgVersion);
 
 
 /**
