@@ -1217,31 +1217,91 @@ CSGObject::createObject(XMLInputStream& stream)
 
   if (name == "csgPrimitive")
   {
+    if (mCSGNode != NULL)
+    {
+      getErrorLog()->logPackageError("spatial",
+        SpatialCSGObjectAllowedElements, getPackageVersion(),
+        getLevel(), getVersion());
+
+      delete mCSGNode;
+      mCSGNode = NULL;
+    }
+    
     mCSGNode = new CSGPrimitive(spatialns);
     obj = mCSGNode;
   }
   else if (name == "csgTranslation")
   {
+    if (mCSGNode != NULL)
+    {
+      getErrorLog()->logPackageError("spatial",
+        SpatialCSGObjectAllowedElements, getPackageVersion(),
+        getLevel(), getVersion());
+
+      delete mCSGNode;
+      mCSGNode = NULL;
+    }
+
     mCSGNode = new CSGTranslation(spatialns);
     obj = mCSGNode;
   }
   else if (name == "csgRotation")
   {
+    if (mCSGNode != NULL)
+    {
+      getErrorLog()->logPackageError("spatial",
+        SpatialCSGObjectAllowedElements, getPackageVersion(),
+        getLevel(), getVersion());
+
+      delete mCSGNode;
+      mCSGNode = NULL;
+    }
+
     mCSGNode = new CSGRotation(spatialns);
     obj = mCSGNode;
   }
   else if (name == "csgScale")
   {
+    if (mCSGNode != NULL)
+    {
+      getErrorLog()->logPackageError("spatial",
+        SpatialCSGObjectAllowedElements, getPackageVersion(),
+        getLevel(), getVersion());
+
+      delete mCSGNode;
+      mCSGNode = NULL;
+    }
+
     mCSGNode = new CSGScale(spatialns);
     obj = mCSGNode;
   }
   else if (name == "csgHomogeneousTransformation")
   {
+    if (mCSGNode != NULL)
+    {
+      getErrorLog()->logPackageError("spatial",
+        SpatialCSGObjectAllowedElements, getPackageVersion(),
+        getLevel(), getVersion());
+
+      delete mCSGNode;
+      mCSGNode = NULL;
+    }
+
     mCSGNode = new CSGHomogeneousTransformation(spatialns);
     obj = mCSGNode;
   }
   else if (name == "csgSetOperator")
   {
+    if (mCSGNode != NULL)
+    {
+      getErrorLog()->logPackageError("spatial",
+        SpatialCSGObjectAllowedElements, getPackageVersion(),
+        getLevel(), getVersion());
+
+      delete mCSGNode;
+      mCSGNode = NULL;
+    }
+
     mCSGNode = new CSGSetOperator(spatialns);
     obj = mCSGNode;
   }
