@@ -953,10 +953,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 CSGObject_t *
-CSGObject_create(unsigned int level = SpatialExtension::getDefaultLevel(),
-                 unsigned int version = SpatialExtension::getDefaultVersion(),
-                 unsigned int pkgVersion =
-                   SpatialExtension::getDefaultPackageVersion());
+CSGObject_create(unsigned int level,
+                 unsigned int version,
+                 unsigned int pkgVersion);
 
 
 /**
