@@ -669,11 +669,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 CSGPrimitive_t *
-CSGPrimitive_create(unsigned int level = SpatialExtension::getDefaultLevel(),
-                    unsigned int version =
-                      SpatialExtension::getDefaultVersion(),
-                    unsigned int pkgVersion =
-                      SpatialExtension::getDefaultPackageVersion());
+CSGPrimitive_create(unsigned int level,
+                    unsigned int version,
+                    unsigned int pkgVersion);
 
 
 /**
