@@ -783,11 +783,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 CSGRotation_t *
-CSGRotation_create(unsigned int level = SpatialExtension::getDefaultLevel(),
-                   unsigned int version =
-                     SpatialExtension::getDefaultVersion(),
-                   unsigned int pkgVersion =
-                     SpatialExtension::getDefaultPackageVersion());
+CSGRotation_create(unsigned int level,
+                   unsigned int version,
+                   unsigned int pkgVersion);
 
 
 /**
