@@ -726,10 +726,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 CSGScale_t *
-CSGScale_create(unsigned int level = SpatialExtension::getDefaultLevel(),
-                unsigned int version = SpatialExtension::getDefaultVersion(),
-                unsigned int pkgVersion =
-                  SpatialExtension::getDefaultPackageVersion());
+CSGScale_create(unsigned int level,
+                unsigned int version,
+                unsigned int pkgVersion);
 
 
 /**
