@@ -734,11 +734,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 CSGTranslation_t *
-CSGTranslation_create(unsigned int level = SpatialExtension::getDefaultLevel(),
-                      unsigned int version =
-                        SpatialExtension::getDefaultVersion(),
-                      unsigned int pkgVersion =
-                        SpatialExtension::getDefaultPackageVersion());
+CSGTranslation_create(unsigned int level,
+                      unsigned int version,
+                      unsigned int pkgVersion);
 
 
 /**
