@@ -748,13 +748,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 CompartmentMapping_t *
-CompartmentMapping_create(
-                          unsigned int level =
-                            SpatialExtension::getDefaultLevel(),
-                          unsigned int version =
-                            SpatialExtension::getDefaultVersion(),
-                          unsigned int pkgVersion =
-                            SpatialExtension::getDefaultPackageVersion());
+CompartmentMapping_create(unsigned int level,
+                          unsigned int version,
+                          unsigned int pkgVersion);
 
 
 /**
