@@ -1016,13 +1016,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 CoordinateComponent_t *
-CoordinateComponent_create(
-                           unsigned int level =
-                             SpatialExtension::getDefaultLevel(),
-                           unsigned int version =
-                             SpatialExtension::getDefaultVersion(),
-                           unsigned int pkgVersion =
-                             SpatialExtension::getDefaultPackageVersion());
+CoordinateComponent_create(unsigned int level,
+                           unsigned int version,
+                           unsigned int pkgVersion);
 
 
 /**
