@@ -869,13 +869,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 DiffusionCoefficient_t *
-DiffusionCoefficient_create(
-                            unsigned int level =
-                              SpatialExtension::getDefaultLevel(),
-                            unsigned int version =
-                              SpatialExtension::getDefaultVersion(),
-                            unsigned int pkgVersion =
-                              SpatialExtension::getDefaultPackageVersion());
+DiffusionCoefficient_create(unsigned int level,
+                            unsigned int version,
+                            unsigned int pkgVersion);
 
 
 /**
