@@ -897,10 +897,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 Domain_t *
-Domain_create(unsigned int level = SpatialExtension::getDefaultLevel(),
-              unsigned int version = SpatialExtension::getDefaultVersion(),
-              unsigned int pkgVersion =
-                SpatialExtension::getDefaultPackageVersion());
+Domain_create(unsigned int level,
+              unsigned int version,
+              unsigned int pkgVersion);
 
 
 /**
