@@ -1764,10 +1764,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 Geometry_t *
-Geometry_create(unsigned int level = SpatialExtension::getDefaultLevel(),
-                unsigned int version = SpatialExtension::getDefaultVersion(),
-                unsigned int pkgVersion =
-                  SpatialExtension::getDefaultPackageVersion());
+Geometry_create(unsigned int level,
+                unsigned int version,
+                unsigned int pkgVersion);
 
 
 /**
