@@ -1026,11 +1026,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 MixedGeometry_t *
-MixedGeometry_create(unsigned int level = SpatialExtension::getDefaultLevel(),
-                     unsigned int version =
-                       SpatialExtension::getDefaultVersion(),
-                     unsigned int pkgVersion =
-                       SpatialExtension::getDefaultPackageVersion());
+MixedGeometry_create(unsigned int level,
+                     unsigned int version,
+                     unsigned int pkgVersion);
 
 
 /**
