@@ -967,13 +967,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 ParametricGeometry_t *
-ParametricGeometry_create(
-                          unsigned int level =
-                            SpatialExtension::getDefaultLevel(),
-                          unsigned int version =
-                            SpatialExtension::getDefaultVersion(),
-                          unsigned int pkgVersion =
-                            SpatialExtension::getDefaultPackageVersion());
+ParametricGeometry_create(unsigned int level,
+                          unsigned int version,
+                          unsigned int pkgVersion);
 
 
 /**
