@@ -1010,13 +1010,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 ParametricObject_t *
-ParametricObject_create(
-                        unsigned int level =
-                          SpatialExtension::getDefaultLevel(),
-                        unsigned int version =
-                          SpatialExtension::getDefaultVersion(),
-                        unsigned int pkgVersion =
-                          SpatialExtension::getDefaultPackageVersion());
+ParametricObject_create(unsigned int level,
+                        unsigned int version,
+                        unsigned int pkgVersion);
 
 
 /**
