@@ -1133,11 +1133,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 SampledField_t *
-SampledField_create(unsigned int level = SpatialExtension::getDefaultLevel(),
-                    unsigned int version =
-                      SpatialExtension::getDefaultVersion(),
-                    unsigned int pkgVersion =
-                      SpatialExtension::getDefaultPackageVersion());
+SampledField_create(unsigned int level,
+                    unsigned int version,
+                    unsigned int pkgVersion);
 
 
 /**
