@@ -955,13 +955,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 SampledFieldGeometry_t *
-SampledFieldGeometry_create(
-                            unsigned int level =
-                              SpatialExtension::getDefaultLevel(),
-                            unsigned int version =
-                              SpatialExtension::getDefaultVersion(),
-                            unsigned int pkgVersion =
-                              SpatialExtension::getDefaultPackageVersion());
+SampledFieldGeometry_create(unsigned int level,
+                            unsigned int version,
+                            unsigned int pkgVersion);
 
 
 /**
