@@ -818,11 +818,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 SampledVolume_t *
-SampledVolume_create(unsigned int level = SpatialExtension::getDefaultLevel(),
-                     unsigned int version =
-                       SpatialExtension::getDefaultVersion(),
-                     unsigned int pkgVersion =
-                       SpatialExtension::getDefaultPackageVersion());
+SampledVolume_create(unsigned int level,
+                     unsigned int version,
+                     unsigned int pkgVersion);
 
 
 /**
