@@ -883,11 +883,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 SpatialPoints_t *
-SpatialPoints_create(unsigned int level = SpatialExtension::getDefaultLevel(),
-                     unsigned int version =
-                       SpatialExtension::getDefaultVersion(),
-                     unsigned int pkgVersion =
-                       SpatialExtension::getDefaultPackageVersion());
+SpatialPoints_create(unsigned int level,
+                     unsigned int version,
+                     unsigned int pkgVersion);
 
 
 /**
