@@ -663,13 +663,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 SpatialSymbolReference_t *
-SpatialSymbolReference_create(
-                              unsigned int level =
-                                SpatialExtension::getDefaultLevel(),
-                              unsigned int version =
-                                SpatialExtension::getDefaultVersion(),
-                              unsigned int pkgVersion =
-                                SpatialExtension::getDefaultPackageVersion());
+SpatialSymbolReference_create(unsigned int level,
+                              unsigned int version,
+                              unsigned int pkgVersion);
 
 
 /**
