@@ -745,13 +745,9 @@ BEGIN_C_DECLS
  */
 LIBSBML_EXTERN
 TransformationComponent_t *
-TransformationComponent_create(
-                               unsigned int level =
-                                 SpatialExtension::getDefaultLevel(),
-                               unsigned int version =
-                                 SpatialExtension::getDefaultVersion(),
-                               unsigned int pkgVersion =
-                                 SpatialExtension::getDefaultPackageVersion());
+TransformationComponent_create(unsigned int level,
+                                unsigned int version,
+                                unsigned int pkgVersion);
 
 
 /**
